C
C     PROGRAM MCROBI                                          VERSION 12-90
C******************************************************************************
C     PROGRAM MCROBI TO CONVERT IRDF 640-GROUP DATA TO                        *
C     A FORMATTED LIBRARY FILE IN SAND STRUCTURE OF 640 GROUPS                *
C                                                                             *
C     ALL FILES USE GROUP REPRESENTATION                                      *
C                                                                             *
C                                                                             *
C     AN INPUT FLUENCE FILE IS NEEDED FOR THE CALCULATION OF THE COUNTING     *
C     EVENTS FOR THIS FILE (E.G. OUTPUT FILE FROM THE PROGRAM MSPECT)         *
C     THIS CALCULATION MAY BE CONSIDERED AS A CHECK OF THE PROGRAM            *
C                                                                             *
C     NAMES OF INPUT AND OUTPUT FILES ARE READ FROM TERMINAL OR FROM THE      *
C     INPUT FILE: TAPE5 NAMED 'CON' IN THE OPEN STATEMENT                     *
C                                                                             *
C     INPUT FILES:                                                            *
C     FILE 15:                                                                *
C     IRDF-FILE                                                               *
C     ENERGIES OF IRDF ARE IN EV !                                            *
C     FILE 19 :                                                               *
C     A FILE SIMILAR IN STRUCTURE AS THE ACTIVITY FILE, WITH THE EXCEPTION    *
C     THAT AFTER THE ACTIVITIES THE NUMBER OF COVER MATERIALS SHOULD BE GIVEN *
C     FOLLOWED BY MAT-NUMBERS ETC.                                            *
C     FOR EXAMPLE LOOK AT THE FILE MCROBI.INP OR AT THE EXAMPLE BELOW         *
C                                                                             *
C     FILE 38:                                                                *
C     FLUENCE FILE (E.G. WATT-SPECTRUM AS THE OUTPUT FILE OF MSPECT)          *
C                                                                             *
C     LINE 1: HEADLINE (20A4)                                                 *
C     LINE 2: MODE,MEV (FORMATFREE,SEPARATED BY KOMMA)                        *
C     MODE=0: SPECTRAL POINT FLUENCE VALUES (PER DE)                          *
C     MODE=1: SPECTRAL GROUP FLUENCE VALUES (PER DE)                          *
C     MODE=2: GROUP FLUENCE VALUES                                            *
C NOTE: IN THIS PROGRAM MODE.NE.0 REQUIRED!!!!! *********                     *
C     MEV=0 : ENERGIES IN EV                                                  *
C     MEV=1 : ENERGIES IN MEV                                                 *
C                                                                             *
C     LINE 3: I1,I2,I,(E(I+1)) (FORMATFREE)                                   *
C     I1    : FIRST INDEX  (1)                                                *
C     I2    : LAST INDEX   (640)                                              *
C     I     : NUMBER OF ENERGY VALUES                                         *
C     E(I+1): LAST (RIGHT) ENERGY IN CASE OF GROUP VALUES                     *
C                                                                             *
C     LINE 4 TO LAST LINE: E(I),FLUENCE(I) (FORMATFREE)                       *
C                                                                             *
C                                                                             *
C     OUTPUT FILES:   RESPONSE MATRX FILES = CROSS SECTION FILES              *
C                                                                             *
C     FILE 16:                                                                *
C     RESPONSE MATRIX FILE IN SAND-II STRUCTURE WITH SPECIAL                  *
C     FORMAT WHICH IS ALSO USED IN THE PROGRAMS BY ZIJP AND NOLTHENIUS,       *
C     FILE 17: THE SAME AS FILE 16 BUT UNFORMATTED                            *
C                                                                             *
C                                                                             *
C      THE STRUCTURE OF A LIBRARY IS AS FOLLOWS:
C
C      LINE NO. 1:   MPL  FORMAT(I10)
C
C               MPL: NUMBER OF ENERGY BOUNDARIES, (ONE MORE THAN ENERGY
C
C                    GROUPS)
C
C      NEXT LINES:   MPL ENERGY BOUNDARIES WITH FORMAT(1P8E10.3)
C
C      NEXT LINE:    NC
C               NC:  NUMBER OF COVER MATERIALS IN THE LIBRARY.
C
C
C      NEXT LINES:   NC SETS CONSISTING OF A LINE WITH THE NAME OF THE
C                    COVER MATERIAL (FORMAT(A2)), FOLLOWED BY THE LINES
C                    FOR MPL-1 COVER CROSS SECTIONS (FORMAT(1P8E10.3))
C
C      NEXT LINE:    NL
C
C               NL:  NUMBER OF CROSS SECTION SETS IN THE LIBRARY
C
C      NEXT LINES:   NL BLOCKS CONSISTING OF:
C                    A LINE WITH S,F (FORMAT(2A4,2X,4A4))
C                    S: SHORT NAME OF THE REACTION
C                    F: 16 LETTER NAME OF THE REACTION
C      A LINE WITH   CLAM, CN1, CN2, MAT, MT (FORMAT(1PE10.3, 2A4, 2X, 2I10)
C                    CLAM: DECAY CONSTANT OF THE ACTIVATED ISOTOPE (NOT
C                    USED IN THESE PROGRAMS)
C                    CN1,CN2: NAME OF THE ISOTOPE
C                    MAT,MT:  ENDF-NUMBERS.
C
C                    NOTE: THIS LINE IS ONLY USED BY THE REACTOR CODE
C                    UNC33, FOR BONNER SPHERES THESE LINE CONTAINS DUMMY
C                    VARIABLES.
C      THE LINES WITH MPL-1 CROSS SECTIONS
C                    (FORMAT(1P8E10.3)) FOLLOW.
C
C      THE BINARY CROSS SECTION FILE CREATED FROM THE FORMATTED BY THE
C      PROGRAM UMSBIB HAS THE SAME STRUCTURE.
C
C
C      IN ADDITION TO THE CROSS SECTIONS OF THE REACTIONS IN FILE 19
C      THE PROGRAM ALSO PROVIDES SOME PSEUDO CROSS SECTIONS, WHICH MAY
C      BE USED FOR THE CALCULATION OF PSEUDO REACTION RATES:
C
C
C      SHORT NAME    16-CHARACTER
C                     NAME
C
C      PHI-THER      PHI-THERMAL*****           ENERGIES E < 0.563E-6 MEV
C      PHI-INT*      PHI-INTERMEDIATE           0.563E-6 < E < 1.05 MEV
C      PHI-0.1*      PHI < 0.1 MEV **           E > 0.1 MEV
C      PHI-1.0*      PHI < 1.0 MEV **           E > 1.0 MEV
C      PHI-TOT*      PHI-TOTAL ******           TOTAL FLUX
C      < E > **      MEAN ENERGY <E>*
C      TO 0.5EV      THERM TO 0.5 EV            E < 0.5 EV
C      5E-7 E-3      0.5 EV TO 1  KEV           5.0E-7 MEV < E < 1.0E-3 MEV
C      E-3  E-1      1  KEV TO 100KEV           1.0E-3 MEV < E < 0.1 MEV
C      0.1  1.0      100KEV TO 1.0MEV           0.1 MEV < E < 1.0 MEV
C      1.0  5.0      1.0MEV TO 5.0MEV           1.0 MEV < E < 5.0 MEV
C      FROM 5.0      5.0MEV TO 20 MEV           5.0 MEV < E
C      1/V*          1/V RESPONSE FKT
C
C      YOU MAY LOOK AT THE CURVES BY TYPING: PLOT
C      PLOT USES THE FILE CREATED BY THE SUBROUTINE PLBILD
C****************************************************************************
C
C      EXAMPLE OF THE INPUT FILE 19 :
C      MAT NUMBERS ARE FROM IRDF-90 AND IRDF-85
C      THE 50 REACTIONS REACTIONS ARE FOLLOWED BY 3 COVER REACTIONS
C      FIRST COLUMN IS THE FIRST STAR IN THE FIRST LINE
C      CONTENTS OF THE FILE:
C------------------------------------------------------------------------
C  **** CREATING MS640 FROM IRDF-90.MTZ WITH PROGRAM MCROBI
C     51
C  LI6AT                           325  105            LI6(N,T)
C  LI6A                           6424  207            LI6(N,A)
C  B10A                            525  107            B10(N,A)
C  F192                            925   16            F19(N,2N)
C  MG24P                          1225  103            MG24(N,P)
C  AL27P                          1325  103            AL27(N,P)MG27
C  AL27A                          1325  107            AL27(N,A)NA24
C  P31P                           1525  103            P31(N,P)
C  S32P                           1625  103            S32(N,P)
C  SC45G                          2125  102            SC45(N,G)SC46
C  TI46P                          2225  103            TI46(N,P)SC46
C  TI47P                          2228  103            TI47(N,P)SC47
C  TI48NP                         2231   28            TI48(N,NP)
C  TI48P                          2231  103            TI48(N,P)SC48
C  CR522                          2431   16            CR52(N,2N)
C  MN552                          2525   16            MN55(N,2N)MN54
C  FE54P                          2625  103            FE54(N,P)MN54
C  FE56P                          2631  103            FE56(N,P)MN56
C  FE58G                          2637  102            FE58(N,G)FE59
C  CO592                          2724   16            CO59(N,2N)CO58
C  CO59G                          2725  102            CO59(N,G)CO60
C  CO59A                          2725  107            CO59(N,A)MN56
C  NI582                          2825   16            NI58(N,2N)NI57
C  NI58P                          2825  103            NI58(N,P)CO58
C  NI60P                          2831  103            NI60(N,P)CO60
C  CU632                          2925   16            CU63(N,2N)
C  CU63G                          2925  102            CU63(N,G)CU64
C  CU63A                          2925  107            CU63(N,A)CO60
C  CU652                          2931   16            CU65(N,2N)
C  ZN64P                          3025  103            ZN64P
C  Y892                           3925   16            Y89(N,2N)
C  ZR902                          4025   16            ZR90(N,2N)
C  NB932                          4125   16            NB93(N,2N)
C  NB93N                          4125   51            NB93(N,N')
C  RH103N                         4525   51            RH103(N,N')
C  IN115N                         4931   51            IN115(N,N)IN115
C  IN115G                         6437  102            IN115(N,G)IN116
C  I1272                          6438   16            I127(N,2N)
C  AU1962                         7924   16            AU197(N,2N)
C  AU197G                         7925  102            AU197(N,G)AU198
C  TH232F                         9040   18            TH232F
C  TH232G                         9040  102            TH232G
C  U235F                          9228   18            U235(N,F)F.P.
C  U238F                          9237   18            U238(N,F)F.P.
C  U238G                          9237  102            U238(N,G)
C  NP237F                         6337   18            NP237(N,F)F.P.
C  PU239F                         9437   18            PU239(N,F)F.P.
C  ST-D-AST                       8000  800            STEEL-DISPL. ASTM
C  ST-D-EUR                       8001  801            STEEL-DISPL. EUR
C  CR-D-EUR                       8002  800            DAMAGE XSECT EUR
C  NI-D-EUR                       8003  800            DAMAGE XSECT EUR
C      3
C  B   525   1
C  CD 4800   1
C  GD 6400   1
C
C***************************************************************************
C  EXAMPLE OF THE INPUT FILE TAPE 5 :
C
C  MCROBI.PR1                   COMMENT PRINTER FILE
C  IRDF-90.MTZ                          THAT IS THE IRDF-FILE
C  IRDF.FMT                             OUTPUT FORMATTED LIBRARY
C  MSPECT.OUT                           FOR CALCULATION OF INTEGRAL VALUES
C  MCROBI.DAT                           INPUT FILE CONNECTING NAMES AND MATS
C  IRDF.BIN                             BINARY OUTPUT LIBRARY
C  1.0                                  FACTOR  FOR THE CROSS SECTIONS
C
C****************************************************************************
C***************************************************************************
C
      DIMENSION EX(641),EL(641)
     *,SIGCOV(10,641),SIG(70,641),FLUSS1(641),FLUSS(641)
     *,XPLOT(641),YPLOT(641),SIGPLO(641),MT(70),MAT(70),NBT(60),INT(60)
     *,FELD(641),MTC(10),MATC(10)
C
      CHARACTER*4 A(20),BLANK,HEAD(20),CN1,CN2
      CHARACTER*8 BK1(70),BK3(13)
      CHARACTER*16 BK2(70),BK4(13)
      CHARACTER*20 TEXT,COM
      CHARACTER*2 NAMCOV(10)
      CHARACTER*20 LISTE3,LISTE4
      LOGICAL*1 OD
C
      DATA BLANK /'    '/,BK3/
     *'PHI-THER','PHI-INT*','PHI-0.1*','PHI-1.0*','PHI-TOT*',
     *'< E > **','        ','TO 0.5EV','5E-7 E-3','E-3  E-1',
     *'0.1  1.0','1.0  5.0','FROM 5.0'/
     *BK4/'PHI-THERMAL*****','PHI-INTERMEDIATE',
     *'PHI < 0.1 MEV **','PHI < 1.0 MEV **',
     *'PHI-TOTAL ******','MEAN ENERGY <E>*','                ',
     *'THERM TO 0.5 EV ','0.5 EV TO 1  KEV','1  KEV TO 100KEV',
     *'100KEV TO 1.0MEV','1.0MEV TO 5.0MEV','5.0MEV TO 20 MEV'/
      DATA CN1/'    '/,CN2/'    '/
      BK3(7)='1/V*'
      BK4(7)='1/V RESPONSE FKT'
C
C
C     OPEN INPUT AND OUTPUT FILES
      CALL FILEIN(LISTE3,LISTE4)
      WRITE(*,7223)
 7223 FORMAT('  GIVE FACTOR FOR MULTIPLICATION WITH ALL'/
     *' CROSS SECTIONS IN THE BINARY OUTPUT FILE'/)
      READ(5,*) FACT
      WRITE(6,7224) FACT
 7224 FORMAT(' '/' ALL CROSS SECTIONS IN THE BINARY OUTPUT FILE ARE',
     1' MULTIPLIED WITH ',1P,E11.5/)
C
      DO 9 I=1,60
      MAT(I)=0
   9  MT(I)=0
      DO 10 I=1,20
   10 A(I)=BLANK
C
C FILL EL(641) WITH SAND ENERGIES
      MPL1=641
      KG1=640
      CALL ETAB(EL,MPL1)
C READ FLUENCE VALUES FROM FILE 38
C READ HEADLINE FROM FILE 38
      READ(38,3728,ERR=5729,END=5729) HEAD
 3728 FORMAT(20A4)
 5729 WRITE(6,5730) HEAD
 5730 FORMAT(' '/' HEADLINE FLUENCE FILE 38:'/' ',20A4/)
      READ(38,*) MODE,MEV
C
C     MODE=0 MEANS SPECTRAL POINT VALUES
      IF(MODE.NE.0) GOTO 141
      WRITE(6,142) MODE
  142 FORMAT(' NO GROUP VALUES ON FILE 38, MODE=',I4)
      STOP
  141 READ(38,*) I1,I2,KG,EDUM
      MPL=KG+1
      IF(MEV.EQ.0) EDUM=EDUM*1.0E-6
      EX(MPL)=EDUM
      DO 39 I=1,KG
C
      READ(38,*) EX(I),FLUSS(I)
C CONVERT TO MEV
C
      IF(MEV.EQ.0)  EX(I)=EX(I)*1.0E-6
      XPLOT(I)=EX(I)
      IF(MODE.EQ.1.AND.MEV.EQ.0) FLUSS(I)=FLUSS(I)*1.0E6
      IF (MODE.EQ.1) FLUSS1(I)=FLUSS(I)
      IF(MODE.EQ.2) FLUSS1(I)=FLUSS1(I)/(EX(I+1)-EX(I))
      YPLOT(I)=FLUSS1(I)
  39  CONTINUE
      MEV=1
      XPLOT(MPL)=EX(MPL)
      COM(1:20)='INPUT FLUX PER DLNE '
      TEXT(1:20)=LISTE3
      CALL PLBILD(XPLOT,YPLOT,SIGPLO,MPL,-2,1,1,1.0,1,TEXT,COM,MEV)
C
C NOW FLUENCE VALUES ARE READ IN
C ENERGY UNIT IS MEV !
C
C NOW IN FLUSS1 ARE SPECTRAL GROUP FLUENCE VALUES
C
      EDUM=0.0
      SUM=0.0
C NORMALIZE OUTPUT SPECTRUM TO 1.0
      DO 4923 I=1,KG1
 4923 SUM=SUM+FLUSS1(I)*(EL(I+1)-EL(I))
      WRITE(6,2775) SUM
 2775 FORMAT(' NORM OF INPUT FLUENCE: ',1P,E12.5)
      SUM1=0.0
      DO 3923 I=1,KG1
      FLUSS1(I)=FLUSS1(I)/SUM
      SUM1=SUM1+FLUSS1(I)*(EL(I+1)-EL(I))
 3923 CONTINUE
C
 3924 FORMAT(' ',1P,E12.4,',',' ',2(E12.4,','))
      WRITE(6,2276) SUM1
 2276 FORMAT(' '/' NORMALIZED TO NORM OF OUTPUT FLUENCE :',1P,E12.4)
C
C READ MAT AND MT VALUES FROM THE 'ACTIVITY' FILE
      READ(19,4728) HEAD
 4728 FORMAT(20A4)
      WRITE(6,4729) HEAD
 4729 FORMAT(' '/' HEADLINE ACTIVITY FILE:'/' ',20A4/)
      READ(19,*) NFOHL
      DO 4730 I=1,NFOHL
      READ(19,4731) BK1(I),MAT(I),MT(I),BK2(I)
      WRITE(6,4732) BK1(I),BK2(I),MAT(I),MT(I)
      WRITE(*,4732) BK1(I),BK2(I),MAT(I),MT(I)
 4730 CONTINUE
 4731 FORMAT(A8,21X,I6,1X,I4,12X,A16)
 4732 FORMAT(' ',A8,1X,A16,1X,2I4)
C READ COVER REACTIONS
      WRITE(6,9256)
 9256 FORMAT(' ',' COVER REACTIONS:'/)
      READ(19,*) NCOV
      DO 7256 I=1,NCOV
      READ(19,7258) NAMCOV(I),MATC(I),MTC(I)
      WRITE(6,7259) NAMCOV(I),MATC(I),MTC(I)
 7256 CONTINUE
 7258 FORMAT(A2,1X,I4,1X,I3)
 7259 FORMAT(' ',A2,1X,I4,1X,I4)
C
C READ COVER CROSS SECTIONS
C
      DO 7238 IJK=1,NCOV
      OD=.FALSE.
  31  READ(15,1010,END=7226) MAT1,MF1,MT1
      GOTO 7227
 7226 WRITE(*,7228) MAT1,MF1,MT1
 7228 FORMAT(' END OF FILE ENCOUNTERED WITH MAT.NE.-1'/
     1' MAT=',I4,' MF=',I2,' MT=',I3/
     1' CONTINUED WITH: MAT=-1')
      MAT1=-1
 7227 CONTINUE
      IF(MAT1.EQ.-1) THEN
        IF(OD)  THEN
          WRITE(*,7225) MATC(IJK),MTC(IJK)
 7225     FORMAT(' MAT=',I6,' MT=',I5,' NOT ON TAPE'/
     1' CORRECT INPUT FILE'/)
          STOP
        ELSE
          OD=.TRUE.
          REWIND 15
          GOTO 31
          WRITE(*,*) 'END OF FILE ENCOUNTERED TAPE 15, REWIND TAPE'
        END  IF
      END IF
      IF(MATC(IJK).NE.MAT1) GOTO 31
      WRITE(*,3001) MATC(IJK)
   32 READ(15,1010) MAT1,MF1,MT1
      IF(MAT1.EQ.-1) GOTO  7227
      IF(MT1.NE.MTC(IJK)) GOTO 32
      IF(MATC(IJK).NE.MAT1) GOTO 31
      IF(MF1.NE.3) GOTO 31
      BACKSPACE 15
      READ(15,1910) AWR,MAT1,MF1,MT1
      WRITE(*,3002) MT1
      READ(15,1011) NR,NP
      READ(15,1012) (NBT(N),INT(N),N=1,NR)
      WRITE(*,3003) NP,NR
      READ(15,1013,END=3788) (EX(I1),FELD(I1),I1=1,NP)
 3788 CONTINUE
      WRITE(*,3004) NP
C
      I5=0
      NMATZ=641-NP
      DO 5403 I1=1,KG1
      XHILF=0.0
      IF(I1.LE.NMATZ) GOTO 5403
      I5=I5+1
      XHILF=FELD(I5)
 5403 SIGCOV(IJK,I1)=XHILF
C
 7238 CONTINUE
      REWIND 15
C
      DO 6238 IJK=1,NFOHL
      OD=.FALSE.
   1  READ(15,1010,END=8226) MAT1,MF1,MT1
 1010 FORMAT(66X,I4,I2,I3)
      GOTO 8227
 8226 WRITE(*,7228) MAT1,MF1,MT1
      MAT1=-1
 8227 CONTINUE
      IF(MAT1.EQ.-1) THEN
        IF(OD)  THEN
          WRITE(*,7225) MAT(IJK),MT(IJK)
          STOP
        ELSE
          OD=.TRUE.
          REWIND 15
          GOTO 1
          WRITE(*,*) 'END OF FILE ENCOUNTERED TAPE 15, REWIND TAPE'
          END  IF
      END IF
      IF(MAT(IJK).NE.MAT1) GOTO 1
      WRITE(*,3001) MAT(IJK)
 3001 FORMAT(' ','FOUND: MAT=',I4)
    2 READ(15,1010) MAT1,MF1,MT1
 1910 FORMAT(11X,E11.4,44X,I4,I2,I3)
      IF(MAT1.EQ.-1)  GOTO 8227
      IF(MT1.NE.MT(IJK)) GOTO 2
      IF(MAT(IJK).NE.MAT1) GOTO 1
      IF(MF1.NE.3) GOTO 1
      BACKSPACE 15
      READ(15,1910) AWR,MAT1,MF1,MT1
      WRITE(*,3002) MT1
 3002 FORMAT(' ','FOUND: MT=',I4)
      READ(15,1011) NR,NP
 1011 FORMAT(44X,2I11)
      READ(15,1012) (NBT(N),INT(N),N=1,NR)
 1012 FORMAT(6I11)
      WRITE(*,3003) NP,NR
 3003 FORMAT(' ','NUMBER OF POINTS NP=',I5,'    INTERVALS :',I4)
      READ(15,1013,END=788) (EX(I1),FELD(I1),I1=1,NP)
  788 CONTINUE
      WRITE(*,3004) NP
 3004 FORMAT(' ','DATA ARE READ IN  , NP=',I5)
 1013 FORMAT(6E11.4)
      NL=NFOHL
      NLINP=NL
C
C CONVERT EV READ IN ENERGIES TO MEV     (IMPORTANT ! **************)
      I5=0
      NMATZ=641-NP
      DO 3403 I1=1,KG1
      XHILF=0.0
      IF(I1.LE.NMATZ) GOTO 3403
      I5=I5+1
      XHILF=FELD(I5)
      EL(I1)=EX(I5)*1.0E-6
 3403 SIG(IJK,I1)=XHILF
C
 6238 CONTINUE
C
C
C FILL ADDITIONAL RESPONSE FUNCTIONS
      DO 1125 I=1,7
      I1=NL+I
      BK1(I1)=BK3(I)
      BK2(I1)=BK4(I)
      DO 132 KK=1,KG
      SIG(I1,KK)=1.0
      GOTO(126,127,128,129,130,131,1311) I
  126 CONTINUE
C PHI THERMAL
      XHH1=0.563E-6
      IF(EL(KK).LE.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(XHH1-EL(KK))
     */(EL(KK+1)-EL(KK))
      IF(EL(KK).GT.XHH1) SIG(I1,KK)=0.0
      GOTO 132
  127 CONTINUE
C PHI-INT
      XHH1=0.563E-6
      XHH2=1.05
      SIG(I1,KK)=0.0
      IF(EL(KK).LE.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LE.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LE.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 132
  128 CONTINUE
C PHI-0.1
      SIG(I1,KK)=0.0
      IF(EL(KK).LE.0.1.AND.EL(KK+1).GT.0.1) SIG(I1,KK)=(EL(KK+1)-0.1)/
     *(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.0.1) SIG(I1,KK)=1.0
      GOTO 132
  129 CONTINUE
C PHI-1.0
      SIG(I1,KK)=0.0
      IF(EL(KK).LE.1.0.AND.EL(KK+1).GT.1.0) SIG(I1,KK)=(EL(KK+1)-1.0)/
     *(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.1.0) SIG(I1,KK)=1.0
      GOTO 132
  130 CONTINUE
C PHI-TOT
      GOTO 132
C MEAN ENERGY
  131 SIG(I1,KK)=0.5*(EL(KK+1)+EL(KK))
      GOTO 132
C 1/V CROSS SECTION
 1311 SIG(I1,KK)=2.*(SQRT(EL(KK+1))-SQRT(EL(KK)))/(EL(KK+1)-EL(KK))
  132 CONTINUE
 1125 CONTINUE
C
C FILL ADDITIONAL RESPONSE FUNCTIONS
      ISPR=0
      DO 3125 I=8,13
      ISPR=ISPR+1
      I1=NL+I
      BK1(I1)=BK3(I)
      BK2(I1)=BK4(I)
      DO 332 KK=1,KG
      SIG(I1,KK)=1.0
      GOTO(326,327,328,329,330,331) ISPR
  326 CONTINUE
      XHH1=0.5E-6
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(XHH1-EL(KK))
     */(EL(KK+1)-EL(KK))
      IF(EL(KK).GT.XHH1) SIG(I1,KK)=0.0
      GOTO 332
  327 CONTINUE
      XHH1=0.5E-6
      XHH2=1.0E-3
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  328 CONTINUE
      XHH1=1.0E-3
      XHH2=1.0E-1
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  329 CONTINUE
      XHH1=1.0E-1
      XHH2=1.0
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  330 CONTINUE
      XHH1=1.0
      XHH2=5.0
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  331 CONTINUE
      XHH1=5.0
      XHH2=20.0
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
  332 CONTINUE
 3125 CONTINUE
C
C OUTPUT IN FILE 16
      M=KG1
C*************************************************************
C
C
C     MPL1 = NUMBER OF ENERGY POINTS
C     M    = NUMBER OF ENERGY GROUPS
C
   80 FORMAT (I10)
      WRITE (6,120) MPL1,M
  120 FORMAT (' '/' SAND-STRUCTURE :'/7H MPL1 =,I10/4H M =,I13/)
      WRITE (16,80) MPL1
      WRITE(16,81) (EL(J),J=1,MPL1)
C
      WRITE (17) MPL1
      WRITE(17) (EL(J),J=1,MPL1)
C
C FILL XPLOT
   81 FORMAT (1P,8E10.3)
      WRITE(16,80) NCOV
      WRITE(17) NCOV
C
C     NCOV = NUMBER OF COVER MATERIALS
      DO 751 I1=1,NCOV
      WRITE(16,752) NAMCOV(I1)
      WRITE(17) NAMCOV(I1)
  752 FORMAT(A2)
      IPPOI=0
      IPPOI2=0
      DO 893 I2=1,M
      IF(SIGCOV(I1,I2).GT.1.0E-10.AND.IPPOI2.EQ.0) IPPOI2=1
      IF(IPPOI2.EQ.1) THEN
      IPPOI=IPPOI+1
      XPLOT(IPPOI)=EL(I2)
      XPLOT(IPPOI+1)=EL(I2+1)
      YPLOT(IPPOI)=SIGCOV(I1,I2)
      SIGPLO(IPPOI)=SIGCOV(I1,I2)
      END IF
 893  CONTINUE
      LAY=2
      IF(IPPOI.EQ.M) LAY=4
      IPPOI=IPPOI+1
      COM(1:20)='COVER CROSS SECTION '
      TEXT(1:2)=NAMCOV(I1)
      TEXT(3:20)='                  '
      MBILD=1
      CALL PLBILD(XPLOT,YPLOT,SIGPLO,IPPOI,LAY,1,1,1.0,MBILD,TEXT,COM
     *,1)
      WRITE(16,753) (SIGCOV(I1,I2),I2=1,M)
      WRITE(17) (SIGCOV(I1,I2),I2=1,M)
  753 FORMAT(1P,8E10.3)
  751 CONTINUE
C
      NL=NL+13
      WRITE(16,80) NL
      WRITE(17) NL
C
C     NL = NUMBER OF CROSS SECTION SETS IN THE LIBRARY
C
      WRITE (6,124) NL
  124 FORMAT (' ------------------------------------'/' NL =',I5/
     *' ------------------------------------')
C
      DO 231 N=1,NL
C
      WRITE(16,83) BK1(N),BK2(N)
      WRITE(17) BK1(N),BK2(N)
   83 FORMAT (A8,2X,A16)
      WRITE (6,125) N,BK1(N),BK2(N)
  125 FORMAT (I5,5X,A8,2X,A16)
      CLAM=0.0
      MAT1=MAT(N)
      MT1=MT(N)
      WRITE(16,84) CLAM,MAT1,MT1
      WRITE(17) CLAM,CN1,CN2,MAT1,MT1
C
C     CLAM = DECAY CONSTANT (LAMBDA) IN S**-1
C     CN1  = NAME OF THE ISOTOPE FOR WHICH THE DECAY CONSTANT IS GIVEN,
C            FIRST PART
C     CN2  = CONTINUATION OF THE NAME
C     MAT  = MATERIAL NUMBER IN THE ORIGINAL LIBRARY
C            OF THE ENDF/B-V FORMAT
C     MT   = REACTION NUMBER IN THE ORIGINAL LIBRARY
C            OF THE ENDF/B-V FORMAT
C
   84 FORMAT (1P,E10.3,8X,2X,2I10)
C
C
C PRINT THE REACTION EVENTS
      SUM1=0.0
      SUM=0.0
      DO 7856 J=1,M
 7856 SUM=SUM+FLUSS1(J)*SIG(N,J)*(EL(J+1)-EL(J))
      WRITE(6,7857) SUM
 7857 FORMAT(' REACTION EVENTS:  ',1P,E12.4/' ',5('------------')/)
C
      WRITE(16,81) (SIG(N,J),J=1,M)
      WRITE(17) (SIG(N,J),J=1,M)
C FILL YPLOT
C
      IPPOI=0
      IPPOI2=0
      DO 793 J=1,M
      IF(SIG(N,J).GT.1.0E-10.AND.IPPOI2.EQ.0) IPPOI2=1
      IF(IPPOI2.EQ.1) THEN
        IPPOI=IPPOI+1
        XPLOT(IPPOI)=EL(J)
        XPLOT(IPPOI+1)=EL(J+1)
        YPLOT(IPPOI)=SIG(N,J)
        SIGPLO(IPPOI)=SIG(N,J)
      END IF
 793  CONTINUE
      LAY=2
      IF(IPPOI.EQ.M) LAY=4
      IPPOI=IPPOI+1
      WRITE(COM,6881) MAT1,MT1
 6881 FORMAT('MAT=',I4,' MT=',I3,'     ')
      TEXT(1:8)=BK1(N)
      TEXT(9:20)='            '
      MBILD=1
      CALL PLBILD(XPLOT,YPLOT,SIGPLO,IPPOI,LAY,1,1,1.0,MBILD,TEXT,COM
     *,MEV)
  231 CONTINUE
      STOP
      END
C**************************************************************
C*********************************************************************
      SUBROUTINE ETAB(EL,MPL1)
      DIMENSION ENUL(45),EL(MPL1)
      DATA ENUL/1.,1.05,1.1,1.15,1.2,1.275,1.35,1.425,1.5,1.6,1.7,
     11.8,1.9,2.,2.1,2.2,2.3,2.4,2.55,2.7,2.8,3.,3.2,3.4,3.6,3.8,4.,
     24.25,4.5,4.75,5.,5.25,5.5,5.75,6.,6.3,6.6,6.9,7.2,7.6,8.,8.4,
     38.8,9.2,9.6/
      J=0
      DO 12  I=1,10
      IN=I-5
      P=10.**IN
      DO 12  IK=1,45
      J=J+1
   12 EL(J) = ENUL(IK)*P
      EL(451) = 1.E+6
      DO 24  I=452,641
   24 EL(I) = EL(I-1)+1.E+5
      NEL = 641
      DO 33 I=1,NEL
   33 EL(I)=EL(I)*1.0E-6
      RETURN
      END
C**********************************************************************
C******************************************************************************
      SUBROUTINE FILEIN(LISTE3,LISTE4)
      CHARACTER*20 LISTE,LISTE3,LISTE4,LISTE1
C
      DATA LISTE /'                    '/
C
  501 FORMAT(A20)
      OPEN(5,FILE='CON')
      LISTE1=LISTE
C
      WRITE(*,503)
  503 FORMAT(
     1' GIVE NAME OF PRINTER FILE OR PRINTER IDENTIFICATION (LPT1):'/)
      READ(5,501,ERR=504,END=504) LISTE1
  504 OPEN(6,FILE=LISTE1)
      LISTE1=LISTE
C
      WRITE(6,3000)
 3000 FORMAT(' PROGRAM MCROBI BY MATZKE (VERSION 12-90)'/
     *' THE PROGRAM CREATES A FORMATTED CS-LIBRARY FROM'/
     *' THE IRDF TAPE'//)
C
      LISTE1=LISTE
      LISTE3=LISTE
      LISTE4=LISTE
C
      WRITE(*,5555)
C
 5555 FORMAT(' NAME OF INPUT IRDF FILE ?  '/
     *' E.G. IRDF '/)
      READ(5,7777,END=9911,ERR=9911) LISTE1
 9911 WRITE(6,9912) LISTE1
 9912 FORMAT(' NAME OF INPUT IRDF FILE: '/
     *' FILE 15: ',A20/)
C
      WRITE(*,6666)
 6666 FORMAT(' NAME OF NEW FORMATTED OUTPUT CROSS SECTION FILE?'/)
      READ(5,7777,END=8888,ERR=8888) LISTE4
 7777 FORMAT(A20)
 8888 CONTINUE
      WRITE(6,9913) LISTE4
 9913 FORMAT(' NAME OF OUTPUT FORMATTED CROSS SECTION FILE 16: ',
     *A20//)
C
C
      OPEN(15,FILE=LISTE1,STATUS='OLD',FORM='FORMATTED')
C
      OPEN(16,FILE=LISTE4,STATUS='NEW',FORM='FORMATTED')
C
      LISTE1=LISTE
      LISTE3=LISTE
      LISTE4=LISTE
      WRITE(*,4422)
 4422 FORMAT(' NAME OF INPUT FLUENCE FILE ? GROUP VALUES !         '/
     *' E.G. W1.U35 (ATTENTION ! YOU NEED 640 GROUPS IN THE FILE)'/
     *' THIS FILE IS TAKEN FOR THE CALCULATION OF REACTION RATES'/)
      READ(5,7777,END=4423,ERR=4423) LISTE3
 4423 CONTINUE
      OPEN(38,FILE=LISTE3,STATUS='OLD',FORM='FORMATTED')
C
      WRITE(*,6613)
 6613 FORMAT(' NAME OF INPUT FILE FOR THE REACTION NAMES?'/)
      READ(5,7713,END=8813,ERR=8813) LISTE4
 7713 FORMAT(A20)
 8813 CONTINUE
      WRITE(6,9915) LISTE4
 9915 FORMAT(' NAME OF INPUT FILE FOR THE REACTION NAMES: ',
     *A20//)
C
      OPEN(19,FILE=LISTE4,STATUS='OLD',FORM='FORMATTED')
      WRITE(*,2222)
 2222 FORMAT(' NAME OF FILE 17, OUTPUT BINARY CROSS SECTION FILE ?'/)
      READ(5,2000,END=1132,ERR=1132) LISTE
 2000 FORMAT(A20)
 1132 CONTINUE
      OPEN(17,FILE=LISTE,STATUS='NEW',FORM='UNFORMATTED')
      WRITE(6,8101) LISTE
 8101 FORMAT(' OUTPUT CROSS SECTION BINARY FILE: ',A20)
      RETURN
      END
C****************** FOLLOWING THE ROUTINE PLBILD ******
C****************** FOR SCREEN GRAFICS, WHICH MAY BE REPLACED
C****************** BY A DUMMY ROUTINE
      SUBROUTINE
     *PLBILD(X,Y,SIG,NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV)
C
      CHARACTER*20 TEXT,COM
      LOGICAL OD
      DIMENSION X(NP),Y(NP),SIG(NP)
C IZEIG=0 KEIN BILD
C IZEIG=1 BILD WIRD GEZEIGT, EINGABE ERWARTET
C IZEIG=2 BILD WIRD GEZEIGT UND BLEIBT STEHEN
C
C LAY=0 KEIN NEUER RAHMEN
C LAY=1 LIN-LIN
C    =2 LOG-LIN
C    =3 LIN-LOG
C    =4 LOG-LOG
C LAY NEGATIV: F(E)*E GEPLOTTET
C
C MODIN=1 HISTOGRAMMWERTE ALS EINGABE
C      =2 PUNKTWERTE ALS EINGABE
C
C MODPL=1 HISTOGRAMM
C      =2 LINIE
C      =3 PUNKTE
C MODIN NEGATIV: UNSICHERHEITEN GEPLOTTET
      INQUIRE(UNIT=29,OPENED=OD)
      IF(.NOT.OD) THEN
      OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='OLD',ERR=30)
   30 OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='NEW')
      END IF
      WRITE(29) NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV
C
      WRITE(29) X,Y,SIG
      RETURN
      END
