C***************************************************************************
C     PROGRAM MFITIB                                                       *
C     OLD PROGRAM FITOCO BY H. NOLTHENIUS AND OTHERS                       *
C---------PROGRAM DEVELOPED AT ECN(PETTEN,NETHERLANDS) BY HENK CH.RIEFFE   *
C---------SEPTEMBER 1980  UPDATE MARCH 1981                                *
C     MODIFIED BY M. MATZKE 1987                                           *
C     VERSION 90-11-1                                                      *
C     THE PROGRAM PREPARES A GROUP AVERAGED RESPONSE MATRIX LIBRARY        *
C     IN A WAY DEFINED BY A SWITCH VARIABLE MMODE                          *
C     MMODE=1 : THE NEW COARSE GROUP STRUCTURE IS GIVEN BY FILE 18,        *
C          =2 : THE NEW GROUP STRUCTURE IS EVALUATED FROM THE FINE         *
C               STRUCTURE FILE 51, SO THAT THE GROUP FLUENCE RATE          *
C               FLUX*DE (DE: ENERGY INTERVAL)                              *
C               IN EACH GROUP IS THE SAME, THE NUMBER OF THE NEW           *
C               GROUPS IS ASKED FROM THE INPUT                             *
C     MMODE=3 : THE NEW GROUP STRUCTURE IS EVALUATED SIMILAR AS IN         *
C               THE CASE MMODE=2, BUT NOW THE VALUES FLUX*DE*H(E)          *
C               ARE EQUAL FOR ALL GROUPS.                                  *
C               (H(E): FLUENCE TO DOSIS CONVERSIONFACTOR)                  *
C               OR H(E): ONE OF THE PSEUDO-CROSS SECTIONS IN THE           *
C               BINARY CROSS SECTION FILE                                  *
C                                                                          *
C     MMODE=4 : THE COARSE GROUP STRUCTURE IS CALCULATED HERE              *
C               USING INPUT VALUES ASKED FROM INPUT (SEE BELOW)            *
C                                                                          *
C***************************************************************************
C     SHIELDING AND SELFSHIELDING:
C
C     THE PROGRAM ALLOWS SHIELDING AND SELF-SHIELDING CALCULATIONS
C     FOR FOILS FOR BEAM AND ISOTROPIC INCIDENCE.
C     FOR THE BONNER SPHERE PROBLEM SELFSHIELDING MAKES NO SENSE
C
C     D1  : THICKNESS OF THE COVER IN BARN**-1
C     D2  : THICKNESS OF THE FOIL IN BARN**-1
C     SIG1: COVER CROSS SECTION IN ONE FINE GROUP
C     SIG2: REACTION CROSS SECTION IN ONE FINE GROUP
C
C     FOR EACH FINE STRUCTURE CROSS SECTION GROUP BEFORE CONDENSING
C     A SHIELDING OR SELFSHIELDING FACTOR F(D1,D2) IS CALCULATED.
C     BEAM INCIDENCE:
C               F(D1,D2)=EXP(-SIG1*D1)*(1.-EXP(-SIG2*D2))/(SIG2*D2)
C     ISOTROPIC INCIDENCE:
C               F(D1,D2)=(E3(SIG1*D1)-E3(SIG1*D1+SIG2*D2))/(SIG2*D2)
C               WHERE E3(X) IS THE EXPONENTIAL INTEGRAL DUE TO PLACZEK
C
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
C     INPUT FILES:                                                         *
C     FILE 5 : INPUT FILE CONTAINING ALL INPUT INFORMATION AND THE         *
C              NAMES OF THE FILES. THIS FILE IS NAMED 'CON'                *
C                                                                          *
C     FILE 51:                                                             *
C     FINE GROUP FLUENCE VALUES (DIVIDED BY DE OR NOT)                     *
C     IN THE SPECIAL GROUP FLUENCE FILE FORMAT (SEE PROGRAM MRESBI,        *
C                    OR SEE PROGRAM MCROBI                                 *
C                                                                          *
C     FILE 16:                                                             *
C     REACTION RATE FILE, FROM WHICH THE NAMES OF THE REACTIONS            *
C     ARE READ IN.                                                         *
C     BESIDES THE REACTION NAMES ALSO NAMES OF INTEGRAL QUANTITIES,        *
C     THE SO-CALLED PSEUDO CROSS SECTIONS                                  *
C     FROM THE LIBRARY FILE ARE REQUIRED                                   *
C     SEE EXAMPLE FOR THIS FILE  BELOW                                     *
C                                                                          *
C     FORMAT OF THE ACTIVITY FILE:                                         *
C     LINE 1: HEADLINE                                     20A4            *
C     LINE 2: NR,ISO                                  FORMAT-FREE          *
C             NR   : NUMBER OF REACTIONS                                   *
C             ISO  : ISO=0        : NO SHIELDING                           *
C                    ISO.NE.0     : SHIELDING HAS TO BE TAKEN INTO ACCOUNT *
C                    ISO=1  BEAM INCIDENCE                                 *
C                    ISO=2  ISOTROPIC INCIDENCE OF NEUTRONS                *
C                                                                          *
C                                                                          *
C     LINE 3 TO LINE NR+2:                                                 *
C     NAM1(I),NAM2(I),ACT1(I),SIG1(I),MAT(I),MT(I),NAMCOV(I),THICK(I)      *
C     THICKF(I)                                                            *
C     FORMAT(2A4,E10.3,F10.3,1X,I6,1X,I4,1X,A2,E10.3,1X,E10.3)             *
C                                                                          *
C     NAM1,NAM2:  CHARACTER*4 VALUES FOR THE                               *
C                 NAMES OF THE REACTIONS, THESE NAMES                      *
C                 SHOULD BE FOUND IN THE LIBRARY                           *
C                                                                          *
C     ACT1(I),SIG1(I)*100./ACT1(I):                                        *
C                 (REACTION RATE AND RELATIVE UNCERTAINTY)                 *
C                                                                          *
C     MAT(I),MT(I):                                                        *
C     FOR REACTOR MEASUREMENTS: THE MAT AND MT NUMBER,                     *
C                                                                          *
C     NAMCOV(I):    CHARACTER*2 NAME OF THE SHIELDING MATERIAL,            *
C                   THIS NAME SHOULD BE FOUND IN THE LIBRARY               *
C                                                                          *
C     THICK(I) :    THICKNESS OF THE SHIELDING MATERIAL IN BARN**-1        *
C                                                                          *
C     IF DETECTOR I IS NOT SHIELDED, USE BLANKS FOR NAMCOV(I)              *
C                                                                          *
C     THICKF(I):    THICKNESS OF DETECTOR I IN BARN**-1, IF SELFSHIELDING  *
C                   OF THE DETECTOR I HAS TO BE TAKEN INTO ACCOUNT         *
C                                                                          *
C     IF NO SELFSHIELDING IS NEEDED FOR DETECTOR I, USE BLANKS             *
C                                                                          *
C     NOTE: FOR BONNER SPHERES WITH ISO=0 MAT,MT ETC. IS NOT NEEDED        *
C                                                                          *
C                                                                          *
C     FURTHER LINES: NAMES OF INTEGRAL QUANTITIES                          *
C                                                                          *
C EXAMPLE OF AN ACTIVITY (OR REACTION RATE) FILE:
c (the numbers correspond to irdf-85 mat-numbers)
c (first column is "R" of "REAL...")
C    REAL88 **** PS1 **** ORNL POOLSIDE FAC., POSITION: SIMUL. SURV.
C        9,  1,             comment: beam incidence through GD cover
C    U235F    1.382E-03     8.000   9228   18 GD  3.026e-3
C    CO59G    3.818E-04     4.000   2725  102 GD  3.026e-3
C    SC45G    5.864E-05     4.000   2125  102 GD  3.026e-3
C    FE58G    5.219E-06     4.000   2637  102 GD  3.026e-3
C    NP237F   7.096E-05     8.000   6337   18 GD  3.026e-3
C    NI58P    2.264E-06     4.000   2825  103 GD  3.026e-3
C    FE54P    1.541E-06     4.000   2625  103 GD  3.026e-3
C    TI46P    2.190E-07     4.000   2225  103 GD  3.026e-3
C    CU63A    1.076E-08     4.000   2925  107 GD  3.026e-3
C    10
C    ST-D-AST
C    ST-D-EUR
C    CR-D-EUR
C    NI-D-EUR
C    PHI-INT*
C    PHI-0.1*
C    PHI-1.0*
C    PHI-TOT*
C    NI58P
C    CO59G
C    ST-D-AST
C
C***************************************************************************
c example of an input file 5:
c  mfitibpr.ps1               comment: printers file
c  1                                   input weighting spectrum
c  w1.ps1                              name of input weighting spectrum
c  irdf.bin                            name of input 640 group cross sections
c  cross1.ps1                          name of output formatted cross sections
c  cross1bi.ps1                        name of output UNformatted cross
c  sections act.ps1                    name of input activity file
c  ff1.ps1                             name of coarse output of w1.ps1
c  1                                   group structure from a file
c  f1.ps1                              input group structure file
c***************************************************************************
C     FILE 15:                                                             *
C     BINARY CROSS SECTION FILE IN THE SAND-II FORMAT                      *
C     E. G. OUTPUT FILE OF THE PROGRAM UMSBIB                              *
C                                                                          *
C     FILE 18: (ONLY NEEDED FOR MMODE=1)                                   *
C     COARSE ENERGY STRUCTURE FLUENCE FILE                                 *
C     IN THE SPECIAL GROUP FLUENCE FILE FORMAT (SEE PROGRAM MRESBI)        *
C     OR SEE PROGRAM MCROBI
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ *
C     OUTPUT FILES:                                                        *
C                                                                          *
C     FILE 6:                                                              *
C     PRINTER (LPT1)                                                       *
C                                                                          *
C     FILE 25:                                                             *
C     OUTPUT FORMATTED CROSS SECTION FILE IN THE SAND-II FORMAT            *
C     CONTAINING THE GROUP AVERAGED CROSS SECTIONS (RESPONSE FUNCTIONS)    *
C                                                                          *
C     FILE 26:                                                             *
C     OUTPUT UNFORMATTED CROSS SECTION FILE IN THE SAND-II FORMAT          *
C     CONTAINING THE GROUP AVERAGED CROSS SECTIONS (RESPONSE FUNCTIONS)    *
C                                                                          *
C     FILE 17:                                                             *
C     COARSE GROUP FLUENCE RATE FILE IN THE NEW ENERGY STRUCTURE           *
C                                                                          *
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
C
      LOGICAL OK
      CHARACTER*2 NAMCOV(30),NCOVE(4),BL2
      CHARACTER*4 HEAD(20),S11(2),F11(4),INAMM1(40),INAMM2(40)
     *,IFOIL1,IFOIL2,CHARHI(2)
      CHARACTER*4 CN1,CN2
      CHARACTER*20 LISTE3,LISTE4
      CHARACTER*20 TEXT,COM
C
      DIMENSION SIGSAN(641),ESAND(641),SIGSAI(101),ESAIL(101)
     1,FLUX(641),PHI(101),COVER(4,641),YHILF(641),YHILF1(641)
     1,XPLOT(641),YPLOT(641),XPLOT1(641),THICK(40),YPLOT1(641)
     1,THICKF(40)
C
      DATA NAMCOV/30*'  '/
      BL2=NAMCOV(1)
C OPEN FILES AND ASK FOR MMODE
      CALL FILEIN(MMODE,LISTE3,LISTE4,MFEIN)
      IF(MMODE.NE.3) GOTO 7322
      WRITE(*,7323)
 7323 FORMAT(' GIVE NAME OF WEIGHTING FUNCTION. E.G. DOSE-EQU'/
     *' THE CROSS SECTION OF THIS NAME SHOULD BE ONE OF THE INPUT'/
     *' 2A4-INPUT, ATTENTION ! CAPITAL LETTERS !'/)
      READ(5,7324) CHARHI(1),CHARHI(2)
 7324 FORMAT(2A4)
      WRITE(6,8322) CHARHI(1),CHARHI(2)
 8322 FORMAT(' GROUP STRUCTURE WEIGHTED WITH THE CROSS SECTION OF'/
     *' ',2A4/)
 7322 CONTINUE
C
      IF(MFEIN.EQ.0) GOTO 5299
C MFEIN=1
C READ SPECTRAL FLUENCE VALUES FROM FILE 51 (SAND-STRUCTURE)
      MODE=1
      MEV=1
      INP=51
      CALL READF(KG1,MPL1,ESAND,FLUX,MODE,MEV,INP)
C FINE STRUCTURE VALUES ARE READ IN
 5299 CONTINUE
C
C READ NAMES FROM THE ACTIVITY FILE 16
      READ(16,2400) (HEAD(K1),K1=1,20)
 2400 FORMAT(20A4)
      WRITE(6,2157) (HEAD(K1),K1=1,20)
 2157 FORMAT(' '/' '/' HEAD LINE OF THE ACTIVITY FILE:'/
     *'  ALSO WRITTEN TO FLUENCE FILE 17'/
     *' ',20A4)
      READ(16,*,ERR=161) NR,ISO
C 3344 FORMAT(I5)
 161  DO 2879  I=1,NR
      READ(16,2877,ERR=2879) INAMM1(I),INAMM2(I),XDUM,XDUM,MAT,MT,
     *NAMCOV(I),THICK(I),THICKF(I)
 2877 FORMAT(2A4,E10.3,F10.3,1X,I6,1X,I4,1X,A2,E10.3,1X,E10.3)
 2879 CONTINUE
C
      M=KG1
C
      NR1=NR
C READ DOSIS-NAMES (INTEGRAL VALUES WHICH SHOULD BE CONSIDERED BESIDES
C THE REACTION NAMES
      READ(16,*) NWEI
      NR1=NR+1
      NR2=NR+NWEI
      DO 4879 I=NR1,NR2
 4879 READ(16,2877) INAMM1(I),INAMM2(I)
      NR=NR2
      NF=0
      OK=.TRUE.
C---------READ SAND ENERGIES
C*************************************************************
      READ(15) MPL1
      KG1=MPL1-1
      M=KG1
      READ(15)(ESAND(I),I=1,MPL1)
C---------
C FILL WEIGHTING SPECTRUM FOR MFEIN=0
      IF(MFEIN.EQ.1) GOTO 3311
      SUM=0.0
      DO 3312 I=1,KG1
      FLUX(I)=ALOG(ESAND(I+1)/ESAND(I))/(ESAND(I+1)-ESAND(I))
 3312 SUM=SUM+FLUX(I)
      DO 3313 I=1,KG1
 3313 FLUX(I)=FLUX(I)/SUM
C
 3311 CONTINUE
C---------READING COVER CROSS SECTIONS
      READ(15) NCOV
      NOVER=4+2*NCOV
      IF(NCOV.EQ.0) GOTO 7331
      DO 93 I=1,NCOV
      READ(15) NCOVE(I)
   93 READ(15)(COVER(I,J),J=1,M)
 7331 CONTINUE
      READ(15) NFOIL
      IMIN=NG
      NF=0
      IF(MMODE.NE.4) GOTO 4118
      REWIND 15
      KG=0
      MPL=0
      WRITE(*,4119)
 4119 FORMAT(' ',/' MMODE=4'/
     *' GIVE FIRST INTERVAL VALUES, E1, E2, NUMBER, LIN'/
     *' E1, E2: LEFT AND RIGHT BOUNDARY IN MEV,'/
     *' NUMBER: NUMBER OF GROUPS IN INTERVAL,'/
     *' LIN=0: LINEAR SUBINTERVALS, LIN=1: LOGARITHMIC SUBINTERVALS'/
     *' GIVE E1,E2,NUMBER,LIN'/)
      READ(5,*) ELINK,ERECHT,NUMBER,LINLOG
 4123 CONTINUE
      NUMBE1=NUMBER+1
      DO 4120 I=1,NUMBE1
      IF(LINLOG.EQ.0) ESAIL(I+KG)
     *=ELINK+(I-1)*(ERECHT-ELINK)/NUMBER
      IF(LINLOG.EQ.1) ESAIL(I+KG)=
     *ELINK*EXP((I-1)*ALOG(ERECHT/ELINK)/NUMBER)
 4120 CONTINUE
      KG=KG+NUMBER
      MPL=KG+1
      ELINK=ERECHT
      WRITE(*,4121)
 4121 FORMAT(' GIVE E2,NUMBER,LIN FOR NEXT INTERVAL'/
     *'E2: RIGHT BOUNDARY'/
     *'OR GIVE 0.0,0,0 TO STOP THE INPUT'/)
      READ(5,*,ERR=4122,END=4122) ERECHT,NUMBER,LINLOG
 4122 CONTINUE
      IF(ERECHT.EQ.0.0.AND.NUMBER.EQ.0) GOTO 7504
      GOTO 4123
 4118 CONTINUE
      IF(MMODE.NE.1) GOTO 7503
C READ NEW ENERGIES FORM FILE 18
      MODE=1
      MEV=1
      INP=18
      CALL READF(KG,MPL,ESAIL,PHI,MODE,MEV,INP)
      REWIND 15
      GOTO 7504
 7503 CONTINUE
C*******************
      DO 701 IR=1,NR
      IFOIL1=INAMM1(IR)
      IFOIL2=INAMM2(IR)
C SEARCH THE RESPONSE MATRIX FOR THE NAMES OF FILE 16
      CALL SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
C
      BACKSPACE 15
      BACKSPACE 15
      IF(.NOT.OK) GOTO 701
      READ(15) S11,F11
      READ(15) CLAM,CN1,CN2,MAT,MT
      READ(15)(SIGSAN(I),I=1,M)
      ICOV=0
      IF(MMODE.NE.3) GOTO 701
      IF(IFOIL1.NE.CHARHI(1).AND.IFOIL2.NE.CHARHI(2)) GOTO 701
      DO 706 I=1,M
      YHILF(I)=SIGSAN(I)
  706 CONTINUE
C
  701 CONTINUE
      REWIND 15
C***********************
C NOW YHILF1 IS SET EQUAL TO FLUX*SUM(ALL SIGMA-VALUES))
      DO 708 I=1,M
      IF(MMODE.EQ.2) YHILF1(I)=FLUX(I)
      IF(MMODE.EQ.3) YHILF1(I)=FLUX(I)*YHILF(I)
  708 CONTINUE
C
C CALCULATE ENERGY GROUPS IN COARSE STRUCTURE AND COARSE ENERGY SPECTRUM
      WRITE(*,2756)
 2756 FORMAT(' GIVE NUMBER OF COARSE GROUPS'/)
      READ(5,*) KG
      MPL=KG+1
      CALL FINCOA(ESAND,YHILF1,ESAIL,PHI,MPL1,KG1,MPL,KG)
C NOW ONLY THE NEW GROUP ENERGIES ARE CONSIDERED AS KNOWN
C
 7504 CONTINUE
      WRITE(6,2757) KG
 2757 FORMAT(' '/' KG=',I5,' COARSE GROUPS')

C FIND NEW FLUX VALUES
      CALL INTPOL(ESAND,FLUX,ESAIL,PHI,MPL1,MPL,KG)
C PLOT
      SUM=1.0E25
      DO 944 I=1,M
      IF(FLUX(I).LT.SUM.AND.FLUX(I).GT.0.0) SUM=FLUX(I)
  944 CONTINUE
      DO 943 I=1,M
      XPLOT1(I)=ESAND(I)
      YPLOT(I)=SUM
      IF(FLUX(I).GT.0.0)
     *YPLOT(I)=FLUX(I)
      YPLOT1(I)=YPLOT(I)
  943 CONTINUE
      XPLOT1(MPL1)=ESAND(MPL1)
      TEXT(1:14)='LOG FINE FLUX '
      COM(1:20)='                    '
      CALL PLBILD(XPLOT1,YPLOT,YPLOT1,MPL1,4,1,1,1.0,1,TEXT,COM,1)
      CALL PLBILD(XPLOT1,YPLOT,YPLOT1,MPL1,4,1,1,1.0,0,TEXT,COM,1)
C WRITE COARSE VALUES IN FILE 17
      WRITE(17,2400) HEAD
      MODE=1
      MEV=1
      WRITE(17,5357) MODE,MEV
 5357 FORMAT(' ',2(I4,1H,))
      IL=1
      WRITE(17,8357) IL,KG,KG,ESAIL(MPL)
 8357 FORMAT(' ',3(I4,1H,),1P,E12.4)
      SUM=0.0
      XMIN=1.0E25
C
      DO 7357 I=1,KG
      XHILF=PHI(I)/(ESAIL(I+1)-ESAIL(I))
      IF(XHILF.LT.XMIN.AND.XHILF.GT.0.0) XMIN=XHILF
 7357 SUM=SUM+PHI(I)
C
      DO 7356 I=1,KG
      XPLOT(I)=ESAIL(I)
      XHILF=PHI(I)/(ESAIL(I+1)-ESAIL(I))
      YPLOT(I)=XMIN
      IF(XHILF.GT.0.0)
     *YPLOT(I)=XHILF
      YPLOT1(I)=YPLOT(I)
      EDUM=YPLOT1(I)
 7356 WRITE(17,8356) ESAIL(I),XHILF,EDUM
      XPLOT(MPL)=ESAIL(MPL)
      TEXT(1:14)='LOG COARSE FLU'
      CALL PLBILD(XPLOT,YPLOT,YPLOT1,MPL,0,1,1,1.0,1,TEXT,COM,1)
 8356 FORMAT(' ',3(E12.5,',   '))
      WRITE(6,7359) SUM
 7359 FORMAT(' '/' NORM OF COARSE GROUP SPECTRUM: ',1P,E12.4)
C
C
      M=KG1
      NG=KG
      NR1=NR
      NF=0
      OK=.TRUE.
C---------READ SAND ENERGIES
C*************************************************************
C*************************************************************
      READ(15) MPL1
      KG1=MPL1-1
      READ(15)(ESAND(I),I=1,MPL1)
C---------
C---------
      WRITE(6,8011) (HEAD(I),I=1,20),KG
 8011 FORMAT(' '/' ',20A4//' ','NG=',I5//' ESAIL(I),PHI(I)...'/)
      WRITE(6,1006)(ESAIL(I),PHI(I),I=1,KG)
 1006 FORMAT(' ',10E11.4/)
C
C---------READING COVER CROSS SECTIONS
      READ(15) NCOV
      NOVER=4+2*NCOV
      IF(NCOV.EQ.0) GOTO 4331
      DO 9 I=1,NCOV
      READ(15) NCOVE(I)
    9 READ(15)(COVER(I,J),J=1,M)
 4331 CONTINUE
      READ(15) NFOIL
C---------CALCULATION CROSS SECTION VALUES IN STAYSAIL GROUPS
      WRITE(25,9311) MPL
 9311 FORMAT(I10)
      write(26) mpl
      WRITE(25,9331) (ESAIL(I),I=1,MPL)
 9331 FORMAT(1P,8E10.3)
      WRITE(26) (ESAIL(I),I=1,MPL)
      WRITE(25,9361)
 9361 FORMAT('         0')
      ncovb=0
      write(26) ncovb
      WRITE(25,9311) NR
      WRITE(26) NR
      IMIN=NG
      WRITE(6,3838)
 3838 FORMAT(' '/
     1' INPUT NAMES   SHIELDING  SHIELDING    SELF-SHIELDING'/
     1'               MATERIAL   THICKNESS    THICKNESS'/
     1'                          (PER BARN)   (PER BARN)'/
     1' '/)
      DO 3839 K=1,NR
      IF(ABS(THICK(K)).GT.1.0E-8.OR.ABS(THICKF(K)).GT.1.0E-8) THEN
      WRITE(6,3840) INAMM1(K),INAMM2(K),NAMCOV(K),THICK(K),THICKF(K)
      ELSE
      WRITE(6,3840) INAMM1(K),INAMM2(K),NAMCOV(K)
      END IF
 3839 CONTINUE
 3840 FORMAT('  ',2A4,7X,A2,6X,1P,E12.4,2X,E12.4)
      NF=0
C******************************
      DO 100 IR=1,NR
      WRITE(6,8110)
 8110 FORMAT(' ****************************************************')
      IFOIL1=INAMM1(IR)
      IFOIL2=INAMM2(IR)
      CALL SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
C
      BACKSPACE 15
      BACKSPACE 15
      IF(.NOT.OK) GOTO 100
      READ(15) S11,F11
      READ(15) CLAM,CN1,CN2,MAT,MT
      WRITE(6,8935) IFOIL1,IFOIL2,MAT,MT
 8935 FORMAT(' '/' REACTION: ',2A4,' MAT=',I6,' MT=',I4/)
      READ(15)(SIGSAN(I),I=1,M)
      ICOV=0
      ISELF1=0
      IF(ABS(THICKF(IR)).GT.1.0E-20) ISELF1=1
      DO 8733 KMATZ=1,NCOV
 8733 IF(NAMCOV(IR).EQ.NCOVE(KMATZ)) ICOV=KMATZ
      IF(NAMCOV(IR).NE.BL2.AND.ICOV.EQ.0) WRITE(6,6622) NAMCOV(IR)
 6622 FORMAT(' COVER MATERIAL ',A2,' NOT ON CROSS SECTION FILE,'/
     *' NO COVER ASSUMED'/)
C
      TEXT(1:4)=IFOIL1
      TEXT(5:8)=IFOIL2
      TEXT(9:20)='            '
      SUM1=0.0
      SUM2=0.0
      RESI1=0.0
      RESI2=0.0
      IPPOI=0
      IPPOI2=0
      DO 1021 I=1,M
      RESI1=RESI1+SIGSAN(I)*FLUX(I)*(ESAND(I+1)-ESAND(I))
      IF(SIGSAN(I).GT.1.0E-24.AND.IPPOI2.EQ.0) IPPOI2=1
      IF(IPPOI2.EQ.1) THEN
      IPPOI=IPPOI+1
      XPLOT1(IPPOI)=ESAND(I)
      XPLOT1(IPPOI+1)=ESAND(I+1)
      YPLOT(IPPOI)=SIGSAN(I)
      END IF
      IF (ICOV.EQ.0.AND.ISELF1.EQ.0) GOTO 101
      P1=THICK(IR)*COVER(ICOV,I)
      P2=THICKF(IR)*SIGSAN(I)
      XHILFM=1.0
      CALL E23(ISO,P1,P2,FSHIE,FSELF1,FSELF2)
      XHILFM=FSHIE
      IF(IPPOI2.EQ.1) YPLOT1(IPPOI)=SIGSAN(I)*XHILFM
      SIGSAN(I)=SIGSAN(I)*XHILFM*FLUX(I)
      GOTO 102
  101 SIGSAN(I)=SIGSAN(I)*FLUX(I)
  102 SUM1=SUM1+SIGSAN(I)*(ESAND(I+1)-ESAND(I))
      SUM2=SUM2+FLUX(I)*(ESAND(I+1)-ESAND(I))
      RESI2=SUM1
 1021 CONTINUE
      IPPOI1=IPPOI+1
      IF(ISO.EQ.0) GOTO 3381
      IF(THICK(IR).LT.1.0E-8.AND.THICKF(IR).LT.1.0E-8) GOTO 3381
         IF(ISO.EQ.1) WRITE(6,*) ' BEAM INCIDENCE'
         IF(ISO.EQ.2) WRITE(6,*) ' ISOTROPIC INCIDENCE'
         IF(THICK(IR).GT.1.0E-8) WRITE(6,3385) NAMCOV(IR)
 3385 FORMAT('  SHIELDING BY ',A2/)
         IF(THICKF(IR).GT.1.0E-8) WRITE(6,*) ' FOIL SELF-SHIELDED'
      VER=RESI2/RESI1
      WRITE(6,3382) THICK(IR),THICKF(IR),VER
 3382 FORMAT(' '/
     *' COVER         : THICKNESS OF THE COVER=',1P,E12.5,' PER BARN'/
     *' SELF-SHIELDING: THICKNESS OF THE FOIL =',E12.5,' PER BARN'/
     *' SHIELDING FACTOR: ',E12.4/)
C
 3381 CONTINUE
      SUM1=SUM1/SUM2
C************
      WRITE(6,9222) IFOIL1,IFOIL2,SUM1,SUM2
 9222 FORMAT(1H /1H ,'*** FINE SPECTRUM****  ',2A4/
     *1H ,'<SIG>=',E12.5,'   <PHI>=',E12.4/)
      NGP1=NG+1
      CALL INTPOL(ESAND,SIGSAN,ESAIL,SIGSAI,MPL1,NGP1,NG)
C PLOT
      LAY=2
      IF(IPPOI1.EQ.MPL1) LAY=4
      CALL PLBILD(XPLOT1,YPLOT,YPLOT,IPPOI1,LAY,1,1,1.0,0,TEXT,COM,1)
      IF(ICOV.NE.0.OR.ISELF1.NE.0) THEN
       TEXT(1:8)='SHIELDED'
       CALL PLBILD(XPLOT1,YPLOT1,YPLOT1,IPPOI1,0,1,1,1.0,0,TEXT,COM,1)
      END IF
      SUM1=0.0
      SUM2=0.0
      DO 103 I=1,NG
      SUM1=SUM1+SIGSAI(I)
      SUM2=SUM2+PHI(I)
      SIGSAI(I)=SIGSAI(I)/PHI(I)
  103 CONTINUE
      SUM1=SUM1/SUM2
C************
      WRITE(6,9223) IFOIL1,IFOIL2,SUM1,SUM2
 9223 FORMAT(1H /1H ,'*** COARSE SPECTRUM****  ',2A4/
     *1H ,'<SIG>=',E12.5,'   <PHI>=',E12.4/)
      DO 150 I=1,NG
      ILOW=I
      IF (SIGSAI(I).GT.0)GOTO 151
  150 CONTINUE
      NR1=NR1-1
      WRITE(6,1010)IR
 1010 FORMAT(1H ,'ALL CROSS SECTION VALUES ARE ZERO  REACTION',I5)
      GOTO 100
  151 IMIN=MIN0(IMIN,ILOW)
      WRITE(6,1251)IFOIL1,IFOIL2,F11,MAT,MT
      WRITE(25,1256) S11,F11
 1256 FORMAT(2A4,2X,4A4)
      WRITE(26) S11,F11
      WRITE(25,3228) CLAM,CN1,CN2,MAT,MT
 3228 FORMAT(1P,E10.3,2A4,2X,2I10)
      WRITE(26) CLAM,CN1,CN2,MAT,MT
C     IF(IMODE.EQ.1) WRITE(27,2286) MAT,MT,IFOIL1,IFOIL2
 2286 FORMAT(2I11,2A4)
C *****
 1251 FORMAT(1H /1H ,2A4,2X,4A4,'MAT=',I5,'  MT=',I5)
      WRITE(6,1252)(ESAIL(I),SIGSAI(I),I=1,NG)
 1252 FORMAT(1H ,1P,6E10.3)
      WRITE(25,1261) (SIGSAI(I),I=1,NG)
      WRITE(26) (SIGSAI(I),I=1,NG)
C PLOT
      NGP1=NG+1
      IPPOI=0
      IPPOI2=0
      DO 791 I=1,NG
      IF(SIGSAI(I).GT.1.0E-24.AND.IPPOI2.EQ.0) IPPOI2=1
      IF(IPPOI2.EQ.1) THEN
      IPPOI=IPPOI+1
      XPLOT(IPPOI)=ESAIL(I)
      XPLOT(IPPOI+1)=ESAIL(I+1)
      YPLOT(IPPOI)=SIGSAI(I)
      YPLOT1(IPPOI)=SIGSAI(I)
      END IF
  791 CONTINUE
      IPPOI=IPPOI+1
      TEXT(1:13)='COARSE VALUES'
      CALL PLBILD(XPLOT,YPLOT,YPLOT1,IPPOI,0,1,1,1.0,1,TEXT,COM,1)
C     CALL PLBILD(XPLOT,YPLOT,NGP1,0,1,1)
 1261 FORMAT(1P,8E10.3)
  100 CONTINUE
      SOM=0.
      DO 25 IK=1,NG
   25 SOM=SOM+PHI(IK)
      WRITE(6,26)SOM
   26 FORMAT(1H ,'SPECTRUMINTEGRAL=',E12.5)
      NZERO=0
      IF (NZERO.EQ.0.AND.OK.AND.IMIN.EQ.1) GOTO 200
      NGG=NG+1-IMIN
      WRITE(6,1004)NZERO,NGG
 1000 FORMAT(A4,7E10.3)
 1003 FORMAT(7E10.3)
 1004 FORMAT(1H ,'0 NR. OF GROUPS CONTAIN ZERO VAL.=',I3,/' ','REAL
     *NUMBER OF GROUPS ',I3)
  200 CONTINUE
      NZER=(NZERO+1)*IMIN*(NR+1-NR1)
      IF (.NOT.OK.OR.NZER.NE.1) WRITE(*,1551)
 1551 FORMAT(1H ,'REACTIONS OR GROUPS')
      STOP
      END
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C*******************************************************+
      SUBROUTINE E23(ISO,P1,P2,FSHIE,FSELF1,FSELF2)
      DOUBLE PRECISION F1,F2,PP1,PP2,E2,DBAR,XH1,XH2
      EXTERNAL E2
      DBAR=1.0D-8
      PP1=DBLE(P1)
      PP2=DBLE(P2)
      IF(PP1.GT.40.0D0) PP1=40.0D0
      IF(PP2.GT.40.0D0) PP2=40.0D0
C
      IF(ISO.EQ.1) THEN
C-----BEAM INCIDENCE:
         F1=1.0D0-PP1
         IF(PP1.GT.DBAR) F1=DEXP(-PP1)
         F2=1.0D0-0.5*PP2
         IF(PP2.GT.DBAR) F2=(1.0D0-DEXP(-PP2))/PP2
         FSELF1=SNGL(F1)
         FSELF2=SNGL(F2)
         FSHIE=SNGL(F1*F2)
         RETURN
      ELSE
C-----ISOTROPIC INCIDENCE:
         F1=1.0D0
         F2=1.0D0
         IF(PP2.GT.DBAR.AND.PP1.LE.DBAR) THEN
            F2=0.5*((1.0D0-DEXP(-PP2))/PP2+E2(PP2))
            FSHIE=SNGL(F1*F2)
         END IF
         IF(PP2.GT.DBAR.AND.PP1.GT.DBAR) THEN
            F1=E2(PP1)
            F2=0.5*((1.0D0-DEXP(-PP2))/PP2+E2(PP2))
            XH1=0.5*(DEXP(-PP1)-PP1*E2(PP1))
            XH2=0.5*(DEXP(-PP1-PP2)-(PP1+PP2)*E2(PP1+PP2))
            FSHIE=SNGL((XH1-XH2)/PP2)
          END IF
          IF(PP2.LE.DBAR.AND.PP1.GT.DBAR) THEN
            F1=E2(PP1)
            FSHIE=SNGL(F1*F2)
          END IF
          FSELF1=SNGL(F1)
          FSELF2=SNGL(F2)
          RETURN
      END IF
      END
C**************************************************
      DOUBLE PRECISION FUNCTION E2(Y)
      DOUBLE PRECISION Y,DXHILF
      X=SNGL(Y)
C
      IF(X.GE.1.0) GOTO 4
      XHILF=X*(-0.57721566+X*(0.99999193+X*(-0.24991055+X*(
     10.05519968+X*(-0.00976004+X*0.00107857)))))
      DXHILF=DBLE(XHILF)-Y*DLOG(Y)
      GOTO 5
   4  XHILF=(X*X+2.334733*X+0.250621)/(X*X+3.330657*X+1.681534)
      DXHILF=DBLE(XHILF)*DEXP(-Y)
C DXHILF=E1(X)*X
   5  CONTINUE
C WERT2=E2(X)
      E2=DEXP(-Y)-DXHILF
      RETURN
      END
C************************************************************************
C
      SUBROUTINE INTPOL(E1,F1,E2,F2,MPL1,NGPL1,NG)
      DIMENSION E1(MPL1),F1(MPL1),E2(NGPL1),F2(NG)
      JJ=1
      DO 1 I=1,NG
      IF (E2(I+1).LT.E1(JJ))GOTO 1
      DO 2 J=JJ,MPL1
      IF (E1(J).GT.E2(I))GOTO 3
  2   CONTINUE
  3   LLOW=J-1
      JJ=J
      DO 4 J=JJ,MPL1
      IF (E1(J).GE.E2(I+1))GOTO 5
  4   CONTINUE
  5   JJ=J-1
      LHIGH=J
      LLOW1=LLOW+1
      SOM=0.
      EE1=E1(LLOW)
      DO 8 IL=LLOW1,LHIGH
      S1=F1(IL-1)
      EE2=E1(IL)
      EL=AMAX1(EE1,E2(I))
      EH=AMIN1(EE2,E2(I+1))
      SOM=SOM+S1*(EH-EL)
      EE1=EE2
  8   CONTINUE
      F2(I)=SOM
  1   CONTINUE
      RETURN
      END
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      SUBROUTINE SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
      LOGICAL OK,AGAIN
      CHARACTER*4 IFOIL1,IFOIL2,INF1,INF2,F2(4)
      AGAIN=.TRUE.
      IF(NF.EQ.NFOIL)GO TO 5
    1 READ(15)INF1,INF2,F2
      NF=NF+1
      IF (INF1.EQ.IFOIL1.AND.INF2.EQ.IFOIL2) GOTO 2
      READ(15)
      READ(15)
      IF (NF.LT.NFOIL) GOTO 1
      IF (.NOT.AGAIN) GOTO 4
    5 AGAIN=.FALSE.
      NF=0
      REWIND 15
      DO 3 I=1,NOVER
    3 READ(15)
      GOTO 1
    2 READ(15)
      OK=.TRUE.
      RETURN
  4   OK=.FALSE.
      WRITE(6,1000) IFOIL1,IFOIL2
 1000 FORMAT(1H ,'REACTION ',2A4,'   NOT ON CROSS SECTION FILE')
      RETURN
      END
C***********************************************
      SUBROUTINE FINCOA(ESAND,FLUX,ESAIL,PHI,MPL1,KG1,MPL,KG)
      DIMENSION ESAND(MPL1),FLUX(KG1),ESAIL(MPL),PHI(KG),Y(641)
C NORMALIZE SPECTRUM AND FILL X(I), Y(I)
      SUM1=0.0
      DO 10 I=1,KG1
   10 SUM1=SUM1+FLUX(I)*(ESAND(I+1)-ESAND(I))
      DO 11 I=1,KG1
   11 Y(I)=FLUX(I)*(ESAND(I+1)-ESAND(I))/SUM1
      ESAIL(1)=ESAND(1)
C
      MI=1
      STEP=1.0/FLOAT(KG)
      SUM=0.0
      DO 20 I=1,KG1
      SUM=SUM+Y(I)
      IF(SUM.GE.STEP) GOTO 30
      GOTO 20
  30  SUM=SUM-Y(I)
      EH=ESAND(I)+(STEP-SUM)*(ESAND(I+1)-ESAND(I))/Y(I)
   32 MI=MI+1
      ESAIL(MI)=EH
      PHI(MI-1)=STEP*SUM1
      SUM=Y(I)*(ESAND(I+1)-EH)/(ESAND(I+1)-ESAND(I))
      IF(SUM.GE.STEP) GOTO 31
C     WRITE(6,2000) I,MI,ESAIL(MI),SUM,STEP
C2000 FORMAT(' I,MI,ESAIL(MI),SUM,STEP ',2I5,3(E12.4,2X))
      GOTO 20
  31  EH=EH+STEP*(ESAND(I+1)-EH)/SUM
      GOTO 32
  20  CONTINUE
      WRITE(6,1000) MI,STEP,SUM
 1000 FORMAT(' MI,STEP,SUM ',I5,2(E12.3,2X))
C
      PHI(MI)=PHI(MI-1)
      ESAIL(MPL)=ESAND(MPL1)
      RETURN
      END
C**********************************************************************
      SUBROUTINE FILEIN(MMODE,LISTE3,LISTE4,MFEIN)
      CHARACTER*20 LISTE,LISTE1,LISTE3,LISTE4,list26
      DATA LISTE /'              '/
      LISTE1=LISTE
      LISTE3=LISTE
      LISTE4=LISTE
C
C*************************************************************
  501 FORMAT(A20)
  502 OPEN(5,FILE='CON')
C
      WRITE(*,503)
  503 FORMAT(
     1' GIVE NAME OF PRINTER FILE OR PRINTER IDENTIFICATION (LPT1):'/)
      READ(5,501,ERR=504,END=504) LISTE1
  504 OPEN(6,FILE=LISTE1)
      LISTE1=LISTE
C***************************************************************
      WRITE(6,8098)
 8098 FORMAT(' *************************************************'/' ')
      WRITE(6,8099)
 8099 FORMAT(' PROGRAMM MFITIB (FITOCO BY HENK. CH. RIEFFE)'/
     *' UPDATED 1987 BY MANFRED MATZKE'/' '/' ')
C
      WRITE(*,3384)
 3384 FORMAT(' MFEIN=0 : 1/E WEIGHTING OF CROSS SECTIONS'/
     *' MFEIN=1  RUN WITH INPUT WEIGHTING SPECTRUM '/
     *' GIVE MFEIN'/)
      READ(5,*) MFEIN
C
      IF(MFEIN.EQ.0) WRITE(6,3287)
 3287 FORMAT(' MFEIN=0  (1/E WEIGHTING)'/)
C
      IF(MFEIN.EQ.0) GOTO 3385
      WRITE(*,1222)
 1222 FORMAT(' NAME OF FILE 51, FINE GROUP FLUENCE (WEIGHTING) ?'/)
      READ(5,2000,END=112,ERR=112) LISTE
 2000 FORMAT(A20)
  112 CONTINUE
      LISTE3=LISTE
      OPEN(51,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,8100) LISTE
 8100 FORMAT(' INPUT FINE GROUP FLUENCE FROM FILE:        ',A20)
C***************
 3385 LISTE=LISTE1
      WRITE(*,1227)
 1227 FORMAT(' NAME OF FILE 15, BINARY CROSS SECTION INPUT FILE ?'/
     1'  ( NORMALLY A 640 GROUP RESPONSE MATRIX FILE) '/)
      READ(5,2000,END=117,ERR=117) LISTE
  117 CONTINUE
      OPEN(15,FILE=LISTE,STATUS='OLD',FORM='UNFORMATTED')
      WRITE(6,8107) LISTE
 8107 FORMAT(' BINARY CROSS SECTION INPUT FILE:           ',A20)
C***************
      LISTE=LISTE1
      WRITE(*,1229)
 1229 FORMAT(' NAME OF FILE 25, FORMATTED OUTPUT RESPONSE MATRIX ?'/)
      READ(5,2000,END=119,ERR=119) LISTE
  119 CONTINUE
      OPEN(25,FILE=LISTE,STATUS='NEW',FORM='FORMATTED')
      WRITE(6,8101) LISTE
 8101 FORMAT(' OUTPUT RESPONSE MATRIX FILE:               ',A20)
C***************
      LIST26=LISTE1
      WRITE(*,5229)
 5229 FORMAT(' NAME OF FILE 26, UNFORMATTED OUTPUT RESPONSE MATRIX ?'/)
      READ(5,2000,END=5119,ERR=5119) LIST26
 5119 CONTINUE
      OPEN(26,FILE=LIST26,STATUS='NEW',FORM='UNFORMATTED')
      WRITE(6,5801) LIST26
 5801 FORMAT(' UNFORMATTED OUTPUT RESPONSE MATRIX FILE:   ',A20)
C***************
      LISTE=LISTE1
      WRITE(*,1224)
 1224 FORMAT(' NAME OF FILE 16, ACTIVITY FILE'/
     1'  FOR INPUT OF THE REACTION NAMES  ?'/)
      READ(5,2000,END=114,ERR=114) LISTE
  114 CONTINUE
      OPEN(16,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,8102) LISTE
 8102 FORMAT(' ACTIVITY INPUT FILE:                       ',A20)
C*************
      LISTE=LISTE1
      WRITE(*,1223)
 1223 FORMAT(' NAME OF FILE 17, NEW OUTPUT COARSE GROUP FLUENCE ?'/
     1' (IN THE NEW ENERGY STRUCTURE ) '/)
      READ(5,2000,END=113,ERR=113) LISTE
  113 CONTINUE
      LISTE4=LISTE
      OPEN(17,FILE=LISTE,STATUS='NEW',FORM='FORMATTED')
      WRITE(6,8106) LISTE
 8106 FORMAT(' OUTPUT NEW COARSE GROUP FLUENCE FILE:      ',A20)
C**************
C     C WHICH MODE ?
      WRITE(*,7804)
 7804 FORMAT(' '/
     *' MMODE=1 : THE NEW COARSE GROUP STRUCTURE IS GIVEN BY FILE 18,'/
     *'           THE NAME OF THIS FILE IS ASKED IF MMODE=1'/
     *' MMODE=2 : THE NEW GROUP STRUCTURE IS EVALUATED FROM THE FINE '/
     *'           STRUCTURE FILE 51, SO THAT THE GROUP FLUENCE RATE  '/
     *'           FLUX*DE (DE: ENERGY INTERVAL)                      '/
     *'           IN EACH GROUP IS THE SAME, THE NUMBER OF THE NEW   '/
     *'           GROUPS IS ASKED FROM THE TERMINAL                  '/
     *' MMODE=3 : THE NEW GROUP STRUCTURE IS EVALUATED SIMILAR AS IN '/
     *'           THE CASE MMODE=2, BUT NOW THE VALUES FLUX*DE*H(E)  '/
     *'           (H(E): WEIGHTING FUNCTION (DOSIS CONVERSIONFACTOR) '/
     *'           THE NAME OF H(E) IS ASKED LATER)'/
     *'           ARE EQUAL FOR ALL GROUPS. '/
     *' MMODE=4 : THE COARSE GROUP STRUCTURE IS CALCULATED BY INPUT '/
     *'           VALUES ASKED FROM TERMINAL'/
     *' GIVE MMODE !'/)
      READ(5,*) MMODE
      WRITE(6,7433) MMODE
 7433 FORMAT(' MMODE=',I4/)
      IF(MMODE.NE.1) RETURN
      LISTE=LISTE1
      WRITE(*,1423)
 1423 FORMAT(' NAME OF FILE 18, OLD FLUENCE FILE FOR ENERGIES ?'/
     1' (FOR THE NEW ENERGY STRUCTURE ) '/)
      READ(5,2000,END=413,ERR=413) LISTE
  413 CONTINUE
      OPEN(18,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,8146) LISTE
 8146 FORMAT(' ENERGIES FROM FILE 18:   ',A20)
      RETURN
      END
C************************************************************
      SUBROUTINE READF(KG,MPL,EL,FLUX,MODE,MEV,INP)
      CHARACTER*4 HEAD(20)
      DIMENSION EL(MPL),FLUX(KG)
C
      READ(INP,2783,END=2784,ERR=2784) HEAD
 2783 FORMAT(20A4)
 2784 WRITE(6,2785) INP,HEAD
 2785 FORMAT(' '/' HEADLINE INPUT FILE ',I3,' :'/' ',20A4/)
      READ(INP,*) MODE1,MEV1
      IF(MODE.NE.0) GOTO 8838
      WRITE(6,8839) INP,MODE
 8839 FORMAT(' NO GROUP FLUENCE VALUES IN FILE ',I4,' , MODE=',I4)
      STOP
 8838 READ(INP,*) IL,IH,KG,EDUM
      MPL=KG+1
      EL(MPL)=EDUM
      IF(MEV1.EQ.0.AND.MEV.EQ.1) EL(MPL)=EL(MPL)*1.0E-6
      IF(MEV1.EQ.1.AND.MEV.EQ.0) EL(MPL)=EL(MPL)*1.0E+6
C
      DO 8840 I=1,KG
      READ(INP,*) EL(I),FLUX(I)
      IF(MEV1.EQ.0.AND.MEV.EQ.1) EL(I)=EL(I)*1.0E-6
      IF(MEV1.EQ.1.AND.MEV.EQ.0) EL(I)=EL(I)*1.0E+6
 8840 CONTINUE
      IF(MODE1.EQ.MODE) RETURN
C
      DO 8841 I=1,KG
C CONVERT TO AVERAGE GROUP FLUENCE VALUES:
      IF(MODE.EQ.1.AND.MODE1.EQ.2)
     *FLUX(I)=FLUX(I)/(EL(I+1)-EL(I))
      IF(MODE.EQ.2.AND.MODE1.EQ.1)
     *FLUX(I)=FLUX(I)*(EL(I+1)-EL(I))
 8841 CONTINUE
      RETURN
      END
C****************** FOLLOWING THE ROUTINE PLBILD ******
C****************** FOR SCREEN GRAFICS, WHICH MAY BE REPLACED
C****************** BY A DUMMY ROUTINE
      SUBROUTINE
     *PLBILD(X,Y,SIG,NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV)
C
      CHARACTER*20 TEXT,COM
      LOGICAL OD
      DIMENSION X(NP),Y(NP),SIG(NP)
C IZEIG=0 KEIN BILD
C IZEIG=1 BILD WIRD GEZEIGT, EINGABE ERWARTET
C IZEIG=2 BILD WIRD GEZEIGT UND BLEIBT STEHEN
C
C LAY=0 KEIN NEUER RAHMEN
C LAY=1 LIN-LIN
C    =2 LOG-LIN
C    =3 LIN-LOG
C    =4 LOG-LOG
C LAY NEGATIV: F(E)*E GEPLOTTET
C
C MODIN=1 HISTOGRAMMWERTE ALS EINGABE
C      =2 PUNKTWERTE ALS EINGABE
C
C MODPL=1 HISTOGRAMM
C      =2 LINIE
C      =3 PUNKTE
C MODIN NEGATIV: UNSICHERHEITEN GEPLOTTET
      INQUIRE(UNIT=29,OPENED=OD)
      IF(.NOT.OD) THEN
      OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='OLD',ERR=30)
   30 OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='NEW')
      END IF
      WRITE(29) NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV
C
      WRITE(29) X,Y,SIG
      RETURN
      END
