C$LARGE
C***********************************************************************
C PROGRAM MIEKEB (MONTE CARLO CODE FOR DOSE ESTIMATION  BY M.MATZKE )
C VERSION 4.88
C THE PROGRAM CALCULATES A MONTE CARLO SOLUTION OF THE FEW CHANNEL
C UNFOLDING PROBLEM
C
C INPUT FILES:
C       5  : TERMINAL (FILE IS NAMED CON)
C FILE 20  : ACTIVITIES (REACTION RATES)
C FILE 15  : BINARY RESPONSE FUNCTIONS (CROSS SECTIONS)
C            IN SAND-II FORMAT E.G.OUTPUT FROM UMSBIB
C      14  : FLUENCE FILE IN THE SPECIAL FORMAT
C            (OPTIONAL, DEPENDING ON ANSWERS GIVEN TO TERMINAL QUESTIONS)
C
C OUTPUT FILES:
C FILE  6  : TERMINAL OR PRINTER (NAME IS ASKED DURING RUN)
C FILE 14  : FLUENCE FILE IN THE SPECIAL FORMAT (FLUENCE PER DE)
C
C INPUT FROM FILE 5:
C NAMES OF THE FILES
C DECISION NEW OR OLD FLUENCE FILE
C EPS   : ITERATION LIMIT OF SAND-II RUN, THE PROGRAM STOPS IF
C         CHI**2/KA IS LESS THAN EPS (KA: NUMBER OF REACTIONS)
C MSAN3 : MAXIMUM NUMBER OF ITERATIONS, IF EPS IS NOT REACHED
C IDR   : EACH IDR-TH ITERATION CH**2 IS PRINTED
C MODP  :=1   FLUENCE PER DLN(E) IS PLOTTED ON SCREEN
C        =2   LOG( FLUENCE PER DE) IS PLOTTED ON SCREEN
C
C
C THE ORGANISATION OF THE PROGRAM IS SIMILAR TO MSITER
C
C THE PROGRAM USES A SUBROUTINE PLBILD TOGETHER WITH THE
C SCREEN SOFTWARE.
C
C
C USERS WITHOUT SCREEN SOFTWARE SHOULD INCLUDE A DUMMY ROUTINE
C PLBILD
C
C************************************************************************
C
C
      CHARACTER*4 HEADA(20),IREAC(30,2),KK3(19,2)
      CHARACTER*20 LISTE,LISTE1
      REAL*8 RR(100,100)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(16,100)
      DATA LISTE/'              '/
C
      LISTE1=LISTE
      OPEN(5,FILE='CON')
      WRITE(*,771)
  771 FORMAT(' GIVE NAME OF PRINTER FILE OR LPT1'/)
      READ(5,1000,END=1002,ERR=1002) LISTE
 1002 CONTINUE
 1000 FORMAT(A20)
      OPEN(6,FILE=LISTE)
C
      WRITE(6,6255)
 6255 FORMAT(' '//
     *'*************************************************************'/
     *' PROGRAM MIEKE BY M. MATZKE, UPDATED 1.89                   *'//
     *' ************************************************************'/
     *' MONTE CARLO ESTIMATION OF FLUENCE RATE                     *'/
     *' AND DAMAGE PARAMETERS                                      *'/
     *' SPECIAL WEIGHTING METHOD                                   *'/
     *' ************************************************************')
C
C
C
C
      CALL RACTS(HEADA,IREAC)
C
C NOW IN COVA THERE IS THE ABSOLUTE COVARIANCE MATRIX
      CALL READS(ICOVC,IREAC,KK3)
C IF(ICOVC.NE.0) THERE IS THE ABSOLUTE COVARIANCE MATRIX OF
C THE CROSS SECTIONS IN SCRATCH FILE 35
      CALL FLUSS1(IFLUSS)
C
C CALCULATE ACT2
      DO 39 I=1,KA
      SUM=0.0
      DO 38 J=1,KG
   38 SUM=SUM+CROSS(I,J)*F1(J)
   39 ACT2(I)=SUM
C IF IFLUSS.EQ.0 NORMALIZE F1 WITH DIAGONAL WEIGHTS
      IF(IFLUSS.EQ.0) THEN
      SUMZ=0.0
      SUMN=0.0
      DO 37 I=1,KA
      SUMZ=SUMZ+ACT2(I)*ACT1(I)/COVA(I,I)
   37 SUMN=SUMN+ACT2(I)*ACT2(I)/COVA(I,I)
      DO 36 I=1,KG
   36 F1(I)=F1(I)*SUMZ/SUMN
      DO 40 I=1,KA
   40 ACT2(I)=ACT2(I)*SUMZ/SUMN
      END IF
C
      KA1=KA
      CALL ADDC(ICOVC,RR,KA1)
C NOW IN COVA THERE IS THE INVERSE OF THE WHOLE COVARIANCE MATRIX
C OF ACTIVITIES
C
      KG1=KG
C
      CALL MONTE(HEADA,IREAC,KK3,RR,KG1)
C
      WRITE(6,5444)
 5444 FORMAT(' '/' END OF CALCULATION :'/)
C
      STOP
      END
C
C    ************************ *    A C T S    * ************************
      SUBROUTINE RACTS(HEADA,IREAC)
      CHARACTER*4 HEADA(20),IREAC(30,2)
      DIMENSION FELD(30),IFELD(1000)
C
      CHARACTER*20 LISTE,LISTE1 ,LISTE2
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      DATA LISTE /'              '/
C
      LISTE1=LISTE
      LISTE2=LISTE
      WRITE(*,1224)
 1224 FORMAT(' GIVE NAME OF ACTIVITY FILE'/)
      READ(5,1225,ERR=1226,END=1226) LISTE
      WRITE(6,3221) LISTE
 3221 FORMAT(' '/' ',50('*')/' INPUT ACTIVITY FILE:',A20)
 1225 FORMAT(A20)
 1226 OPEN(20,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
C
C READ ACTIVITIES
      READ(20,1000,ERR=7777,END=7777) HEADA
 1000 FORMAT(20A4)
      WRITE(6,1010) HEADA
 1010 FORMAT(' '/' ','HEADLINE ACTIVITY FILE:'/' '/' ',20A4//)
      READ(20,*,END=7777,ERR=7777) KA
      DO 23 I=1,KA
   23 READ(20,1011,ERR=7777,END=7777) IREAC(I,1),IREAC(I,2),ACT1(I)
     *,SIG1(I)
C SIG1(I) IS GIVEN IN %
 1011 FORMAT(2A4,1P,E10.3,0P,F10.3)
 7777 CONTINUE
C MULTIPLICATION BY FACTA
      WRITE(*,2234)
 2234 FORMAT(' GIVE FACTOR FOR MULTIPLICATION WITH ACTIVITIES'/)
      READ(5,*) FACTA
      WRITE(6,3447) FACTA
 3447 FORMAT(' ALL ACTIVITIES ARE MULTIPLICATED BY:',1P,E12.4/)
      DO 21 I=1,KA
      ACT1(I)=ACT1(I)*FACTA
C CONVERT TO ABSULUTE SIG-VALUES
      SIG1(I)=SIG1(I)*ACT1(I)/100.
   21 CONTINUE
C NOW ACTIVITIES ARE READ IN
C
C
      WRITE(6,6432)
 6432 FORMAT(' INPUT REACTIONS WITH STANDARD DEVIATIONS'/)
      DO 6433 I=1,KA
      XHILF=SIG1(I)*100./ACT1(I)
 6433 WRITE(6,6434) I,IREAC(I,1),IREAC(I,2),ACT1(I),SIG1(I),XHILF
 6434 FORMAT(' ',I4,2X,2A4,1P,E12.4,2X,'+-',E12.4,2X,' +-',0P,F8.3,'%')
C
C ************** READ INFORMATION ON COVARIANCE MATRIX OF ACTIVITIES **
      WRITE(*,3381)
 3381 FORMAT(' GIVE IVAR FOR THE INFORMATION OF AVAILABLE '/
     *' COVARIANCE INFORMATION'/
     *' IVAR=0 : NO COVARIANCE INFORMATION ON THE ACTIVITIES'/
     *'     =1 : COVARIANCE INFORMATION ON FORMATTED FILE, '/
     *'          NAME OF THIS FILE IS ASKED LATER'/
     *'  GIVE IVAR !'/)
      READ(5,*) IVAR
      IF(IVAR.EQ.0) GOTO 7287
C************ COVARIANCE INFORMATION AVAILABLE:
C************ OPEN COVARIANCE FILE
      WRITE(*,7336)
 7336 FORMAT(' GIVE NAME OF ACTIVITY FORMATTED COVARIANCE FILE'/)
      READ(5,1225,END=7337,ERR=7337) LISTE1
 7337 OPEN(38,FILE=LISTE1,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,3385) LISTE1
 3385 FORMAT(' '/' COVARIANCE MATRIX OF ACTIVITIES FROM: ',A20/)
C
C INPUT ACTIVITY COVARIANCE
      READ(38,1000,END=8888,ERR=8888) HEADA
      WRITE(6,2010) HEADA
 2010 FORMAT(' '/' HEADLINE CORRELATION FILE'/' '/' ',20A4)
      READ(38,*,END=8888,ERR=8888) KAC
      IF(KAC.NE.KA) WRITE(6,1532) KA,KAC
 1532 FORMAT(' ','KAC.NE. KA     KA,KAC:',2I5)
      IHILF1=1
      IHILF2=KAC
C READ RELATIVE STANDARD DEVIATIONS TIMES 100 FROM FILE 20
      READ(38,3000,END=8888,ERR=8888) (FELD(I),I=IHILF1,IHILF2)
 3000 FORMAT(10(8E10.3/))
C
      DO 712 I=1,KA
  712 SIG1(I)=FELD(I)*ACT1(I)/100.
C
C LOWER TRIANGEL OF CORRELATION MATRIX*1000 IS READ IN IFELD(I)
      NR1=KA+1
      NRU=(KA*NR1)/2
      READ(38,1476,ERR=8888,END=8888) (IFELD(I),I=1,NRU)
 1476 FORMAT(16I5)
      IL=1
      IH=KA
      DO 40 I=1,KA
      DO 50 K=1,KA
C CONVERT TO ABSOLUTE COVARIANCE MATRIX
      IJU=I+(K*K-K)/2
      IF(I.GT.K) IJU=K+(I*I-I)/2
      COVA(I,K)=SIG1(I)*SIG1(K)*IFELD(IJU)/1000.0
   50 CONTINUE
   40 CONTINUE
      CLOSE(38)
      RETURN
C
C ******************* COVARIANCE MATRIX DIAGONAL:
 7287 CONTINUE
      DO 7288 I=1,KA
      DO 7289 J=1,KA
 7289 COVA(I,J)=0.0
 7288 COVA(I,I)=SIG1(I)*SIG1(I)
C
      RETURN
 8888 WRITE(6,7778)
 7778 FORMAT(' ERROR IN READING COVARIANCE-FILE OF ACTIVITIES')
      STOP
C
      END
C*****************************************************************
      SUBROUTINE READS(ICOVC,IREAC,KK3)
      CHARACTER*4 KK1(30,2),KK2(30,4),CN1,CN2,KK3(19,2)
     *,KK4(19,4),IREAC(30,2)
      CHARACTER*4 IFOIL1,IFOIL2
      CHARACTER*20 LISTE,LISTE1
      REAL*8 TB(100)
      DIMENSION FEHL(100,100)
      LOGICAL OK
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(16,100)
      DATA LISTE1 /'              '/
      LISTE=LISTE1
      WRITE(*,1227)
 1227 FORMAT(' NAME OF FILE 15, BINARY CROSS SECTION FILE'/
     1'  (E.G. CROSSBIN ?'/)
      READ(5,2000,END=117,ERR=117) LISTE
 2000 FORMAT(A20)
  117 CONTINUE
      OPEN(15,FILE=LISTE,STATUS='OLD',FORM='UNFORMATTED')
      WRITE(6,8107) LISTE
 8107 FORMAT(' '//' *************************'/
     *' BINARY CROSS SECTION INPUT FILE:  ',A20)
C*************************************************************
      READ(15) MPL1
      M=MPL1-1
      KG=M
      READ(15) (EL(I),I=1,MPL1)
      READ(15) NCOV
      NOVER=4+2*NCOV
      IF(NCOV.EQ.0) GOTO 4331
      DO 9 I=1,NCOV
      READ(15) NCOVE
    9 READ(15) (DUMMY,J=1,M)
 4331 CONTINUE
      READ(15) NFOIL
      OK=.TRUE.
      NF=0
      DO 100 I=1,KA
      IFOIL1=IREAC(I,1)
      IFOIL2=IREAC(I,2)
      CALL SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
C
      BACKSPACE 15
      BACKSPACE 15
      IF(.NOT.OK) GOTO 100
      READ(15) (KK1(I,K1),K1=1,2),(KK2(I,K1),K1=1,4)
      READ(15) CLAM,CN1,CN2,MAT,MT
      READ(15) (CROSS(I,K1),K1=1,M)
  100 CONTINUE
C    READ DAMAGE NAMES
      CALL DOSNAM(KK3)
      DO 233 I=1,KDAM
      IFOIL1=KK3(I,1)
      IFOIL2=KK3(I,2)
      CALL SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
C
      BACKSPACE 15
      BACKSPACE 15
      IF(.NOT.OK) GOTO 233
      READ(15) (KK3(I,K1),K1=1,2),(KK4(I,K1),K1=1,4)
      READ(15) CLAM,CN1,CN2,MAT,MT
      READ(15) (CROSSD(I,K1),K1=1,M)
  233 CONTINUE
      CLOSE(15)
      KG=M
C READ CROSS SECTION COVARIANCE FILE:
      WRITE(*,3381)
 3381 FORMAT(' GIVE ICOVC FOR THE INFORMATION OF AVAILABLE '/
     *' COVARIANCE INFORMATION OF THE CROSS SECTIONS'/
     *' ICOVC=0 : NO COVARIANCE INFORMATION ON THE X-SECTIONS'/
     *'      =1 : COVARIANCE INFORMATION ON FORMATTED FILE, '/
     *'          NAME OF THIS FILE IS ASKED LATER'/
     *'  GIVE ICOVC !'/)
      READ(5,*) ICOVC
      IF(ICOVC.EQ.0) GOTO 7287
      WRITE(*,7336)
 7336 FORMAT(' GIVE NAME OF FORMATTED COVARIANCE FILE OF X-SECTIONS'/)
      LISTE=LISTE1
      READ(5,2000,END=7337,ERR=7337) LISTE
 7337 OPEN(38,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,3385) LISTE
 3385 FORMAT(' '/' COVARIANCE MATRIX OF X-SECTIONS FROM: ',A20/)
C
C OPEN SCRATCH FILE
      OPEN(35,STATUS='SCRATCH',FORM='UNFORMATTED')
C
C READ CROSS SECTION COVARIANCE
      DO 10 I=1,KA
      READ(38,1333,END=88,ERR=88) IFOIL1,IFOIL2,MAT,MT,IDU,IL,IH
 1333 FORMAT(2A4,2X,5I5)
      DO 11 K1=1,KG
      DO 11 K2=1,KG
   11 FEHL(K1,K2)=0.0
      DO 15 K1=IL,IH
   15 READ(38,1001,END=88,ERR=88) (FEHL(K1,K2),K2=IL,IH)
 1001 FORMAT(1P,8E10.3)
      IF(FEHL(IL,IL).EQ.0.0) IL=IL+1
      NANZ=IH-IL+1
      WRITE(35) NANZ,IL,IH
C
      DO 12 K1=IL,IH
      DO 13 K2=IL,IH
C CONVERT TO ABSOLUTE COVARIANCE MATRIX DOUBLE PRECISION
   13 TB(K2)=DBLE(FEHL(K1,K2))*DBLE(CROSS(I,K1))*CROSS(I,K2)
C
      WRITE(35) (TB(K2),K2=IL,IH)
   12 CONTINUE
   10 CONTINUE
C
      CLOSE(38)
      REWIND 35
      RETURN
 7287 WRITE(6,7288)
 7288 FORMAT(' '/' NO COVARIANCE INFORMATION ON CROSS SECTIONS'/
     *' AVAILABLE (ICOVC=0)'/)
      RETURN
  88  WRITE(6,5288)
 5288 FORMAT(' ERROR READING CROSS SECTION COVARIANCE FILE'/)
      STOP
      END
C*****************************************************************
      SUBROUTINE FLUSS1(IFLUSS)
      CHARACTER*20 LISTE,LISTE1,LISTE2
      CHARACTER*4 HEAD(20)
C
      COMMON /ERG/ACT2(40),COV2(40),F1(100),F2(100)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
C
      DATA LISTE /'              '/
      LISTE1=LISTE
      LISTE2=LISTE
      WRITE(*,5555)
 5555 FORMAT(' IFLUSS=0 : NEW SPECTRUM, IFLUSS=1: OLD SPECTRUM'/
     *' ','IFLUSS ?'/)
      READ(5,*) IFLUSS
      IF(IFLUSS.EQ.1) WRITE(*,7351)
 7351 FORMAT(' GIVE NAME OF OLD SPECTRUM FILE'/)
      IF(IFLUSS.EQ.1) READ(5,7777,END=7352,ERR=7352) LISTE1
 7352 CONTINUE
      IF(IFLUSS.EQ.1) WRITE(6,7386) LISTE1
 7386 FORMAT(' OLD SPECTRUM INPUT FILE: ',A20)
      WRITE(*,6666)
 6666 FORMAT(' NAME OF NEW SPECTRUM FILE?'/)
      READ(5,7777,END=8888,ERR=8888) LISTE
 7777 FORMAT(A20)
 8888 CONTINUE
      WRITE(6,7258) LISTE
 7258 FORMAT(' '/' NAME OF NEW SPECTRUM FILE FOR OUTPUT: ',A20)
C
      WRITE(*,5556)
 5556 FORMAT(' NAME OF NEW SPECTRUM COVARIANCE FILE ?'/)
      READ(5,7777,END=5557,ERR=5557) LISTE2
 5557 OPEN(41,FILE=LISTE2,FORM='UNFORMATTED')
      WRITE(6,8258) LISTE2
 8258 FORMAT(' NAME OF COVARIANCE OUTPUT FILE: ',A20)
C
      IF(IFLUSS.EQ.1)
     *OPEN(14,FILE=LISTE1,STATUS='OLD',FORM='FORMATTED')
      IF(IFLUSS.NE.0) GOTO 10
      OPEN(14,FILE=LISTE,STATUS='NEW',FORM='FORMATTED')
      DO 20 I=1,KG
   20 F1(I)=ALOG(EL(I+1)/EL(I))
      GOTO 481
   10 CONTINUE
      READ(14,7238,END=7239,ERR=7239) HEAD
 7238 FORMAT(20A4)
 7239 WRITE(6,7240) HEAD
 7240 FORMAT(' '/' HEADLINE INPUT FLUENCE FILE 14: '/' ',20A4/)
      READ(14,*) MODE,MEV
      IF(MODE.NE.0) GOTO 177
      WRITE(6,178) MODE
  178 FORMAT(' NO GROUP AVERAGES AS INPUT, MODE=',I5)
      STOP
  177 CONTINUE
      READ(14,*) IL,IH,KG,EDUM
      MPL1=KG+1
      EL(MPL1)=EDUM
      IF(MEV.EQ.0) EL(MPL1)=EL(MPL1)*1.0E-6
      DO 2712 I=1,KG
      READ(14,*) EL(I),F1(I),F2(I)
      IF(MEV.EQ.0) EL(I)=EL(I)*1.0E-6
 2712 CONTINUE
C
      DO 30 I=1,KG
C
   30 F1(I)=F1(I)*(EL(I+1)-EL(I))
      CLOSE(14)
      OPEN(14,FILE=LISTE,STATUS='NEW',FORM='FORMATTED')
C
  481 CONTINUE
C
      RETURN
      END
C
C**************************************************************
C*********************************************************
      SUBROUTINE MONTE(HEADA,IREAC,KK3,RR,KG1)
C
      CHARACTER*4 HEADA(20),IREAC(30,2),KK3(19,2)
      CHARACTER*20 TEXT,COM
C
      DIMENSION FF(100),DFF(100),FF3(100)
     *,IZOG(100),DOSISQ(19)
     *,YPLOT(101),XPLOT(101)
     *,DACT(19),DACTS(19),DACTS2(19)
     *,DACTX1(19),DACTX2(19)
C
      DOUBLE PRECISION DRAND,F1D(100),CHI1D,FSS(100),XX3D,XHILFD,
     *FS(100),F2D(100),DF2(100),TT(100),CRRD,DSUM,TEMPED
     *,COVF(100,100),DELT55
      DOUBLE PRECISION RR(KG1,KG1)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(16,100)
C
      DRAND=0.2D0
      WRITE(*,3451)
 3451 FORMAT(' '/
     *' ML1:   NUMBER OF MC-RUNS IN ONE LOOP'/
     *' ML2:   NUMBER OF MC LOOPS'/
     *' MXMO:  NUMBER OF PARTIAL LOOPS BEFORE COMPARING CHI**2'/
     *' DELT:  SHIFT-VALUE FOR FLUENCE (E.G. 0.1)'/
     *' '/' GIVE ML1,ML2,MXMO,DELT'/)
C
      READ(5,*) ML1,ML2,MXMO,DELT
      DELT55=DBLE(DELT)
      WRITE(*,3453)
 3453 FORMAT(' GIVE  TEMPERATURPARAMETER'/)
C
      READ(5,*) TEMPE1
      TEMPE=TEMPE1
      TEMPED=DBLE(TEMPE1)
C
      DO 401 I=1,KG
      TT(I)=0.0D0
      DO 401 J=1,KG
  401 RR(I,J)=0.0D0
C
C PRINT THE MEASURED AND CALCULATED ACTIVITIES
      CALL OUTACT(IREAC)
C
C CALCULATE CHI
      CHI=0.0
      DO 1401 I=1,KA
      DO 1401 J=1,KA
 1401 CHI=CHI+(ACT1(I)-ACT2(I))*COVA(I,J)*(ACT1(J)-ACT2(J))
      WRITE(6,1402) CHI
 1402 FORMAT(' '//' FIRST CHI-VALUE:',F12.5)
C CALCULATE TT AND RR
      DO 1403 K1=1,KG
      SUM=0.0
      DO 1404 I=1,KA
      DO 1404 J=1,KA
 1404 SUM=SUM+ACT1(I)*COVA(I,J)*CROSS(J,K1)
 1403 TT(K1)=DBLE(SUM)
      DO 1405 K1=1,KG
      DO 1405 K2=K1,KG
      SUM=0.0
      DO 1406 I=1,KA
      DO 1406 J=1,KA
 1406 SUM=SUM+CROSS(I,K1)*COVA(I,J)*CROSS(J,K2)
      RR(K1,K2)=DBLE(SUM)
 1405 RR(K2,K1)=RR(K1,K2)
C
C CALCULATE WEIGHT FUNCTION FOR SHIFTING,
C WHICH IS PROPORTIONAL TO THE CURVATURE
C
      DO 46 I=1,KG
      F1D(I)=DBLE(F1(I))
  46  FS(I)=DSQRT(RR(I,I))
C
C CALCULATE CRR
      CRRD=0.0D0
      DO 431 I=1,KA
      DO 431 J=1,KA
  431 CRRD=CRRD+DBLE(ACT1(I)*ACT1(J)*COVA(I,J))
      CRRD=0.5*CRRD
      CRR=SNGL(CRRD)
      DO 550 I1=1,KG
      DSUM=0.0D0
      DO 551 I2=1,KG
  551 DSUM=DSUM+F1D(I2)*RR(I2,I1)
      FSS(I1)=DSUM
  550 CONTINUE
      CALL CHIW(CRRD,FSS,TT,F1D,KG,CHI1D)
      CHI1=SNGL(CHI1D)
      CHIAUS=CHI1*2.0
      WRITE(6,1357) CHIAUS
C
      WRITE(6,2298) ML1,ML2,MXMO,DELT,TEMPE1
 2298 FORMAT(' '/' USED PARAMETERS:'/
     *' ML1  =',I7/
     *' ML2  =',I7/
     *' MXMO =',I7/
     *' DELT =',F13.5/
     *' TEMPE1 =',F12.4/)
C
C CALCULATE FIRST DOSIS VALUES
      DO 234 I=1,KDAM
      DOSISQ(I)=0.0
      DO 234 J=1,KG
  234 DOSISQ(I)=DOSISQ(I)+CROSSD(I,J)*F1(J)
      SUM=0.0
      DO 235 J=1,KG
  235 SUM=SUM+F1(J)
C
      WRITE(6,2217)
 2217 FORMAT(' '/' FIRST DOSIS VALUES:')
      DO 237 I=1,KDAM
  237 WRITE(6,238) I,(KK3(I,K1),K1=1,2),DOSISQ(I)
  238 FORMAT(' ',I5,2X,2A4,2X,1P,E12.5)
C
 1357 FORMAT(' '/' CHI1=',F12.3)
C
      DO 140 I=1,KG
      F2D(I)=0.0D0
      FF3(I)=0.0
      FF(I)=0.0
      DF2(I)=0.0D0
      DFF(I)=0.0
      DO 140 J=1,KG
  140 COVF(I,J)=0.0D0
C SET DAMAGE VARIABLES TO ZERO
      DO 4299 I=1,KDAM
      DACTX1(I)=0.0
      DACTX2(I)=0.0
      DACT(I)=DOSISQ(I)
      DACTS(I)=0.0
      DACTS2(I)=0.0
 4299 CONTINUE
      DO 5299 I=1,KA
      ACT2(I)=0.0
 5299 CONTINUE
C
      ENNORM=0.0
      CHI2SU=0.0
      CHI4SU=0.0
      MAX=ML1*ML2
      MLAUF4=0
      MLAUF8=0
      MK=0
      MNOT= 0
      MLAUF= 0
      MLAUF1=0
      CHI1D=DBLE(CHI1)
CC
  610 CONTINUE
C
      MLAUF= MLAUF +1
      MLAUF1=MLAUF1+1
      MLAUF8=MLAUF8+1
C ACTUALIZE:
      IF(MLAUF8.EQ.200)  CALL
     *ACTUAL(MLAUF8,KG1,F1D,TT,RR,FSS,CHI1D,DACT,CRRD)
      CHI1=SNGL(CHI1D)
C
      CHI2SU=CHI2SU+CHI1*2.0
      CHI4SU=CHI4SU+CHI1*CHI1*4.0
      SUMNOR=0.0
C
      DO 510 I=1,KG
      XHILFD=F1D(I)
      XHILF=SNGL(XHILFD)
C CALCULATE DAMAGE VALUES
      SUMNOR=SUMNOR+XHILF
      F2D(I)=F2D(I)+XHILFD
      DF2(I)=DF2(I)+XHILFD*XHILFD
C
      DO 510 J=I,KG
      COVF(I,J)=COVF(I,J)+XHILFD*F1D(J)
  510 CONTINUE
C      CALCULATE  DAMAGE VALUES
      DO 511 I=1,KDAM
      XSUM=DACT(I)
      DACTX1(I)=DACTX1(I)+XSUM
      DACTS(I)=DACTS(I)+XSUM
      DACTS2(I)=DACTS2(I)+XSUM*XSUM
  511 CONTINUE
C
      ENNORM=ENNORM+SUMNOR
      IF(MLAUF1.EQ.ML1) GOTO 8835
 8836 CONTINUE
C
      IMONTE=0
 6201 IMONTE=IMONTE+1
      CALL MONTE1(DRAND,DELT55,FS,F1D,CHI1D,FSS,TT,RR,TEMPED,
     *DACT,IZOG,KG1,MNOT,MK)
C
      IF(IMONTE.LT.MXMO) GOTO 6201
      GOTO 610
C
 8835 CONTINUE
C
      MKX=MK
      MKY=MNOT
      MLAUF4=MLAUF4+1
C
      IHALT=0
      XJA=FLOAT(MKX)*100./(MLAUF*MXMO)
      XJA1=FLOAT(MKY)*100./(MLAUF*MXMO)
      XNEIN=FLOAT(MLAUF*MXMO-MKX-MKY)*100./(MLAUF*MXMO)
      CALL CHIW(CRRD,FSS,TT,F1D,KG,CHI1D)
      CHI1=SNGL(CHI1D)
      CHIAUS=CHI2SU/MLAUF
      CHIAU4=CHI4SU/MLAUF
      CHIAU5=SQRT(ABS(CHIAU4-CHIAUS*CHIAUS))
C
      WRITE(*,8637) MLAUF4,MLAUF,XJA,XJA1,XNEIN,CHIAUS,CHIAU4,CHIAU5
      WRITE(6,8637) MLAUF4,MLAUF,XJA,XJA1,XNEIN,CHIAUS,CHIAU4,CHIAU5
 8637 FORMAT(' '/' ****************************************'/
     *' ','L=',I7,' MLAUF=',I7,' YES=',F8.3,' %  YES1=',
     *F8.3,' %  NO=',F8.3,' %'/' CHI2=   ',F12.3,' CHI4=',F12.3/
     *' SIG(CHI2)=',F12.3/)
C
      WRITE(6,8435)
      WRITE(*,8435)
 8435 FORMAT(' '/' DOSIS-VALUES:'//
     *'     I',12X,'CALCULATED    MC-BIAS% ',
     *'  STD. DEVIATION % ',' MC-BIAS OF STD DEV.%'/)
C
      DO 3342 I=1,KDAM
      XHILF=DACTS(I)/MLAUF
      DACTX1(I)=DACTX1(I)/MLAUF1
      DACTX2(I)=DACTX2(I)+DACTX1(I)*DACTX1(I)
      DACTX1(I)=0.0
C XHILF1: 2. MOMENT
      XHILF1=DACTS2(I)/MLAUF-XHILF*XHILF
      IF(XHILF1.LT.0.0) WRITE(6,4779) I
 4779 FORMAT(' ATTENTION!  AT I=',I5,' NEGATIVE VARIANCE'/)
      XHILF1=SQRT(ABS(XHILF1))
      XHILF1=XHILF1*100./XHILF
C: XHILF2 : MC-BIAS OF STD DEVIATION
      XHILF2=SQRT(ABS(DACTX2(I)/MLAUF4-XHILF*XHILF))
      XHILF3=XHILF2
C: XHILF3 MC-BIAS OF MEAN VALUE
      IF(MLAUF4.GT.1) XHILF3=XHILF3/SQRT(FLOAT(MLAUF4-1))
      XHILF2=XHILF2*100./XHILF
      XHILF3=XHILF3*100./XHILF
      WRITE(*,3343) I,KK3(I,1),KK3(I,2),XHILF,XHILF3,XHILF1,XHILF2
 3342 WRITE(6,3343) I,KK3(I,1),KK3(I,2),XHILF,XHILF3,XHILF1,XHILF2
C
 3343 FORMAT(' ',I5,2X,2A4,1P,E12.4,0P,F12.2,4X,0P,2(F12.2,2X))
C
      DAM5=ENNORM/MLAUF
      WRITE(6,8658) DAM5
 8658 FORMAT(' '/' NORM=',1P,E12.5)
C
      DO 850 I1=1,KG
      DSUM=0.0D0
      DO 851 I2=1,KG
  851 DSUM=DSUM+F1D(I2)*RR(I2,I1)
      FSS(I1)=DSUM
  850 CONTINUE
C
      DO 3122 I=1,KG
      F2D(I)=F2D(I)/ML1
C FOLLOWING LINE INTRODUCED 23.6.88
 3122 CONTINUE
C
C ACTUALIZE THE WEIGHTS (INTRODUCED 23.6.88):
      MPL1=KG+1
      XLAM=0.0
      DO 513 I=1,KG
      XH=SNGL(F2D(I))
      F2D(I)=0.0D0
      FF(I)=FF(I)+XH
      XHILF=FF(I)/MLAUF4
      YPLOT(I)=XHILF/(EL(I+1)-EL(I))
      FF3(I)=FF3(I)+XH*XH
      DFF(I)=DFF(I)+SNGL(DF2(I)/ML1)
      XPLOT(I)=SQRT(ABS(DFF(I)/MLAUF4-XHILF*XHILF))/
     *(EL(I+1)-EL(I))
  513 DF2(I)=0.0D0
C
      LAY=-2
      IZEIG=1
      WRITE(TEXT(1:13),2771) MLAUF4
 2771 FORMAT('RUN NO.  ',I4)
C
      IF(MLAUF.EQ.MAX) IZEIG=1
      CALL PLBILD(EL,YPLOT,XPLOT,MPL1,LAY,-1,1,1.0,IZEIG,TEXT,COM,1)
C
      XLAM=(CHIAU4-CHIAUS*CHIAUS)/CHIAUS
      XLAM=TEMPE+2.*ALOG(CHIAUS/FLOAT(KA))/XLAM
      WRITE(6,3446) XLAM
 3446 FORMAT(' LAMBDA=',1P,E12.4,' (NEW TEMPERATURPARAMETER)'/
     *' **************************************************')
C
 4315 FORMAT(' ',I5,2E12.4,F10.3)
      MLAUF1=0
C
      IF(MLAUF4.LT.ML2) GOTO 8836
C
      DO 7836 I=1,KG
      XHILFD=DBLE(FF(I)/ML2)
      F1(I)=SNGL(F1D(I))
      DO 7837 J=I,KG
      XX3D=DBLE(FF(J)/ML2)
 7837 COVF(I,J)=COVF(I,J)/MLAUF-XHILFD*XX3D
 7836 CONTINUE
      DO 8936 I=1,KG
      DO 8937 J=I,KG
 8937 COVF(J,I)=COVF(I,J)
 8936 CONTINUE
      IL=1
      IH=KG
      WRITE(41) KG,IL,IH
      DO 8971 I=1,KG
 8971 WRITE(41) (COVF(I,J),J=1,KG)
      REWIND41
C
      CHI2SU=CHI2SU/MLAUF
      CHI4SU=CHI4SU/MLAUF
      WRITE(6,5930)
 5930 FORMAT(' '/' '/' RESULTS:'/)
  525 CONTINUE
      WRITE(6,5555)
 5555 FORMAT(' '/' ','          EL          NEW   '
     1,'      SIG      SIG-REL.    MC-BIAS     IZOG   '
     2,'  GROUP FLUX  MAX. SHIFT'/
     3,' ',33X,'ABSOLUT        %           % '/)
      MLAUF4=0
      REWIND 14
      MPL1=KG+1
      WRITE(14,6429) HEADA
 6429 FORMAT(20A4)
      ILLL=1
      IHHH=KG
      MODE=1
      MEV=1
      WRITE(14,*) MODE,MEV
      WRITE(14,*) ILLL,IHHH,KG,EL(MPL1)
      SUM=0.0
      DO 733 I=1,KG
      FF(I)=FF(I)/ML2
      DFF(I)=SQRT(ABS((DFF(I)-FF3(I))/ML2))
      FF3(I)=SQRT(ABS(FF3(I)/ML2-FF(I)*FF(I)))
      XHILF2=0.0
      XHILF=0.0
      IF(FF(I).LE.0.0) GOTO 3285
      XHILF2=FF3(I)*100.0/FF(I)
      XHILF=DFF(I)*100.0/FF(I)
 3285 XHILF3=SQRT(FF3(I)*FF3(I)+DFF(I)*DFF(I))
      XHILF3=XHILF3/(EL(I+1)-EL(I))
      DFF(I)=XHILF3
      XHILF8=FF(I)
      FF(I)=FF(I)/(EL(I+1)-EL(I))
C
      SUM=SUM+FF(I)*(EL(I+1)-EL(I))
 5347 FORMAT(' ',3(E12.5,',  '))
      WRITE(14,5347) EL(I),FF(I),XHILF3
      XHIL28=DELT55/FS(I)
  733 WRITE(6,734) I,EL(I),FF(I),XHILF3,XHILF,XHILF2,
     1IZOG(I),XHILF8,XHIL28
  734 FORMAT(' ',I4,1P,3E12.4,0P,2F12.4,I7,2X,1P,2E12.4)
      LAY=-2
      IZEIG=1
      TEXT(1:20)='RESULTING FLUENCE   '
      CALL PLBILD(EL,FF,DFF,MPL1,LAY,-1,1,1.0,IZEIG,TEXT,COM,1)
C
      WRITE(6,899) SUM,CHI2SU,CHI4SU
  899 FORMAT(//' ','NORM=',1P,E12.4/
     *' ','CHI*2=',E12.5,'  CHI*4=',E12.5)
C
      REWIND 14
      CALL CONTF(HEADA,IREAC,KK3)
      RETURN
      END
C***********************************************
      SUBROUTINE OUTACT(IREAC)
      CHARACTER*4 IREAC(30,2)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
C
      WRITE(6,6434)
 6434 FORMAT(' '//'     I',14X,'MEASURED   CALCULATED',
     *'       DIFFERENCE % ',' REL. UNCERTAINTY %'/)
      DO 41 I=1,KA
      XHILF1=(ACT1(I)-ACT2(I))*100./ACT1(I)
      XHILF2=SIG1(I)*100./ACT1(I)
   41 WRITE(6,1400) I,IREAC(I,1),IREAC(I,2),ACT1(I),ACT2(I),XHILF1
     *,XHILF2
 1400 FORMAT(' ',I5,2X,2A4,1P,2E12.4,4X,0P,2(F12.2,2X))
      RETURN
      END
C*******************************************************
      SUBROUTINE ACTUAL(MLAUF8,KG,F1D,TT,RR,FSS,CHI1D,DACT,CRRD)
      DOUBLE PRECISION F1D,FSS,RR,CHI1D,DSUM,TT,CRRD
      DIMENSION F1D(KG),TT(KG),FSS(KG),RR(KG,KG),DACT(19)
      COMMON /DAM/ KDAM,CROSSD(16,100)
C ACTUALIZE FSS AND CHI1D
      MLAUF8=0
C
      DO 1850 I1=1,KG
      DSUM=0.0D0
      DO 1851 I2=1,KG
 1851 DSUM=DSUM+F1D(I2)*RR(I2,I1)
      FSS(I1)=DSUM
 1850 CONTINUE
C
      CALL CHIW(CRRD,FSS,TT,F1D,KG,CHI1D)
      DO 413 J=1,KDAM
      DACT(J)=0.0
      DO 413 I=1,KG
  413 DACT(J)=DACT(J)+CROSSD(J,I)*F1D(I)
      RETURN
      END
C****************************************************************
      SUBROUTINE MONTE1(DRAND,DELT55,FS,F1D,CHI1D,FSS,TT,RR,TEMPED,
     *DACT,IZOG,KG,MNOT,MK)
      DOUBLE PRECISION DRAND,DELT55,FS,F1D,CHI1D,FSS,TT,RR,TEMPED,
     *DELT1D,DELT2D,DELT3D,BELT1D,BELT2D,BELT3D,CHI2D,XHILFD
      DIMENSION FS(KG),F1D(KG),FSS(KG),TT(KG),IZOG(KG),DACT(19)
     *,RR(KG,KG)
      COMMON /DAM/ KDAM,CROSSD(16,100)
      CALL RANDOM(DRAND)
      I1=IDINT(DRAND*KG)+1
      IF(I1.GT.KG) I1=KG
      CALL RANDOM(DRAND)
      DELT1D=-DELT55*DRAND/FS(I1)
C IF NO CHANGE (NOT ACCEPTED) RETURN
      IF((F1D(I1)+DELT1D).LT.0.0D0) RETURN
 7201 CALL RANDOM(DRAND)
      I2=IDINT(DRAND*KG)+1
      IF(I2.GT.KG) I2=KG
      DELT2D=-DELT1D
 7202 CALL RANDOM(DRAND)
      I3=IDINT(DRAND*KG)+1
C
      IF(I3.GT.KG) I3=KG
      CALL RANDOM(DRAND)
      DELT3D=DELT55*(1.0D0-2.0D0*DRAND)/FS(I3)
C
      BELT1D=F1D(I1)+DELT1D
      BELT2D=F1D(I2)+DELT2D
      BELT3D=F1D(I3)+DELT3D
C
C IF NO CHANGE (NOT ACCEPTED) RETURN
      IF(BELT3D.LT.0.0D0) RETURN
      IF (I1.EQ.I2) THEN
      CHI2D=CHI1D
     *+DELT3D*(FSS(I3)-TT(I3))+0.5D0*DELT3D*DELT3D*RR(I3,I3)
      ELSE
      CHI2D=CHI1D
     *+DELT1D*(FSS(I1)-TT(I1))+0.5D0*DELT1D*DELT1D*RR(I1,I1)
     *+DELT2D*(FSS(I2)-TT(I2))+0.5D0*DELT2D*DELT2D*RR(I2,I2)
     *+DELT3D*(FSS(I3)-TT(I3))+0.5D0*DELT3D*DELT3D*RR(I3,I3)
     *+DELT1D*DELT2D*RR(I1,I2)
     *+DELT1D*DELT3D*RR(I1,I3)
     *+DELT2D*DELT3D*RR(I2,I3)
      END IF
C
      IF (CHI2D.GT.CHI1D)  THEN
         XHILFD=(CHI2D-CHI1D)*TEMPED
         IF(XHILFD.GT.100.D0) THEN
         XHILFD=0.0
      ELSE
         XHILFD= DEXP(-XHILFD)
      END IF
      CALL RANDOM(DRAND)
C IF NO CHANGE (NOT ACCEPTED) RETURN
      IF (DRAND.GT.XHILFD) RETURN
         MNOT=MNOT+1
      ELSE
         MK=MK+1
      END IF
      IF(I1.EQ.I2) THEN
         F1D(I3)= BELT3D
         DO 413 IID=1,KDAM
  413    DACT(IID)=DACT(IID)+CROSSD(IID,I3)*DELT3D
C
         IZOG(I3)=IZOG(I3)+1
         DO 5275 L=1,KG
 5275    FSS(L)=FSS(L)+DELT3D*RR(I3,L)
      ELSE
         F1D(I1)= BELT1D
         F1D(I2)= BELT2D
         F1D(I3)= BELT3D
C
         DO 414 IID=1,KDAM
  414    DACT(IID)=DACT(IID)+CROSSD(IID,I3)*DELT3D+CROSSD(IID,I1)
     1   *DELT1D+CROSSD(IID,I2)*DELT2D
         IZOG(I1)=IZOG(I1)+1
         IZOG(I2)=IZOG(I2)+1
         IZOG(I3)=IZOG(I3)+1
         DO 5274 L=1,KG
 5274    FSS(L)=FSS(L)+DELT1D*RR(I1,L)+DELT2D*RR(I2,L)
     *   +DELT3D*RR(I3,L)
      END IF
      CHI1D=CHI2D
      RETURN
      END
C***********************************************
      SUBROUTINE CONTF(HEADA,IREAC,KK3)
      CHARACTER*4 HEADA(20),IREAC(30,2),KK3(19,2)
C
      DIMENSION DF1(100),DACT2(40),IDRU(100,100)
      DOUBLE PRECISION COVF(100,100),DXHILF
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(16,100)
C
      MPL1=KG+1
      READ(14,3378,END=3379,ERR=3379) (HEADA(I),I=1,20)
 3378 FORMAT(20A4)
 3379 READ(14,*) MODE,MEV
      READ(14,*) ILL,IHH,KG,EL(MPL1)
      DO 10 I=1,KG
   10 READ(14,*) EL(I),F1(I),DF1(I)
      DO 11 I=1,KG
      F1(I)=F1(I)*(EL(I+1)-EL(I))
   11 DF1(I)=DF1(I)*(EL(I+1)-EL(I))
C
      REWIND 41
      READ(41) KG,IL,IH
      DO 12 I=1,KG
   12 READ(41) (COVF(I,J),J=1,KG)
C
C PRINT COVF
      WRITE(6,2336)
 2336 FORMAT(' '/' OUTPUT COVARIANCE OF FLUENCE:'/)
      CALL PMAX1(KG,COVF,F1,100,IDRU)
C
      KA1=KA+KDAM
      DO 20 I=1,KA1
      ACT2(I)=0.0
      DACT2(I)=0.0
      DO 21 L1=1,KG
      IF (I.LE.KA) THEN
      XHILF=CROSS(I,L1)
      ELSE
      IHILF=I-KA
      XHILF=CROSSD(IHILF,L1)
      END IF
  21  ACT2(I)=ACT2(I)+XHILF*F1(L1)
  20  CONTINUE
C
      DO 30 L1=1,KA1
      DO 32 L2=1,KA1
      DXHILF=0.0D0
      DO 31 M1=1,KG
      IF (L1.LE.KA) THEN
      XHILF1=CROSS(L1,M1)
      ELSE
      IHILF=L1-KA
      XHILF1=CROSSD(IHILF,M1)
      END IF
      DO 31 M2=1,KG
      IF (L2.LE.KA) THEN
      XHILF2=CROSS(L2,M2)
      ELSE
      IHILF1=L2-KA
      XHILF2=CROSSD(IHILF1,M2)
      END IF
      DXHILF=DXHILF+DBLE(XHILF1)*COVF(M1,M2)*DBLE(XHILF2)
   31 CONTINUE
      COVA(L1,L2)=SNGL(DXHILF)
   32 CONTINUE
      DACT2(L1)=SQRT(ABS(COVA(L1,L1)))
   30 CONTINUE
C
C WRITE ACTIVITIES AND COVARIANCE MATRIX
      DO 40 L1=1,KA1
      DO 41 L2=1,KA1
      IDRU(L1,L2)=INT(COVA(L1,L2)*100./(DACT2(L1)*DACT2(L2))+0.5)
   41 CONTINUE
   40 CONTINUE
C
      WRITE(6,6434)
 6434 FORMAT(' '//'  FINAL RESULTS OF ACTIVITIES:'//
     *' '//'     I',14X,'MEASURED   REL. UNCERTAINTY ',
     *'  CALCULATED    REL. UNCERT.(%)'/)
C
      DO 411 I=1,KA1
      IF(I.LE.KA) THEN
      XHILF2=DACT2(I)*100./ACT2(I)
      XHILF1=SIG1(I)*100./ACT1(I)
C
      WRITE(6,1400) I,IREAC(I,1),IREAC(I,2),ACT1(I),XHILF1
     *,ACT2(I),XHILF2
      ELSE
      IHILF=I-KA
      XHILF1=DACT2(I)*100./ACT2(I)
      WRITE(6,2400) I,KK3(IHILF,1),KK3(IHILF,2),ACT2(I),XHILF1
      END IF
  411 CONTINUE
 1400 FORMAT(' ',I5,2X,2A4,1P,E12.4,2X,0P,F12.2,6X,1P,E12.4,2X,0P,
     *F12.2)
 2400 FORMAT(' ',I5,2X,2A4,32X,1P,E12.4,2X,0P,F12.2)
C
      WRITE(6,2000)
 2000 FORMAT(' '//' CORRELATION MATRIX'//
     *'  I',14X,'REL UNCERTAINTY (%)      CORRELATION MATRIX*100'/)
C
      DO 50 I=1,KA1
      XHILF=DACT2(I)*100./ACT2(I)
      IF(I.LE.KA) THEN
      WRITE(6,4000) I,IREAC(I,1),IREAC(I,2),XHILF,(IDRU(I,J),J=1,I)
      ELSE
      IHIL=I-KA
      XHILF=DACT2(I)*100./ACT2(I)
      WRITE(6,4000) I,KK3(IHIL,1),KK3(IHIL,2),XHILF,(IDRU(I,J),J=1,I)
      END IF
  50  CONTINUE
 4000 FORMAT(' ',I3,2X,2A4,1X,F5.2,20I4/' ',19X,20I4)
C
      RETURN
      END
C******************************************
      SUBROUTINE CHIW(CRRD,FSS,TT,F1D,KG,WERT)
      DOUBLE PRECISION FSS(KG),TT(KG),F1D(KG),CRRD,WERT
      WERT=0.0D0
      DO 10 I=1,KG
   10 WERT=WERT-(TT(I)-0.5*FSS(I))*F1D(I)
      WERT=WERT+CRRD
      RETURN
      END
C**********************************************************
      SUBROUTINE SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
      LOGICAL OK,AGAIN
      CHARACTER*4 IFOIL1,IFOIL2,INF1,INF2,F2(4)
      AGAIN=.TRUE.
      IF(NF.EQ.NFOIL)GO TO 5
    1 READ(15)INF1,INF2,F2
      NF=NF+1
      IF (INF1.EQ.IFOIL1.AND.INF2.EQ.IFOIL2) GOTO 2
      READ(15)
      READ(15)
      IF (NF.LT.NFOIL) GOTO 1
      IF (.NOT.AGAIN) GOTO 4
    5 AGAIN=.FALSE.
      NF=0
      REWIND 15
      DO 3 I=1,NOVER
    3 READ(15)
      GOTO 1
    2 READ(15)
      OK=.TRUE.
      RETURN
  4   OK=.FALSE.
      WRITE(6,1000) IFOIL1,IFOIL2
 1000 FORMAT(' ','REACTION ',2A4,'   NOT ON CROSS SECTION FILE')
      RETURN
      END
C***********************************************************
      SUBROUTINE DOSNAM(KK3)
C READ DOS-NAMES
      CHARACTER*4 IBL
      CHARACTER*4 KK3(19,2)
      COMMON /DAM/ KDAM,CROSSD(16,100)
      DATA IBL/'    '/
C
C READ NUMBER OF DOSE REACTIONS
      READ(20,*) KDAM
      DO 10 I=1,KDAM
      KK3(I,1)=IBL
      KK3(I,2)=IBL
      READ(20,1000,END=999,ERR=999) KK3(I,1),KK3(I,2)
 1000 FORMAT(2A4)
  999 CONTINUE
   10 CONTINUE
      RETURN
      END
CRANDOM RANDOM RANDOM RANDOM RANDOM RANDO
      SUBROUTINE RANDOM(DRND)
      DOUBLE PRECISION PI,DRND,EINS
      PARAMETER (PI=3.14159265D0,EINS=1.0D0)
      DRND=DRND+PI
      DRND=DRND*DRND*DRND*DRND*DRND
      DRND=DMOD(DRND,EINS)
      RETURN
      END
C*****************************************************************************
      SUBROUTINE PMAX1(KA,AP,TCC,KNUMB,IP)
      DOUBLE PRECISION AP(KNUMB,KNUMB)
      DIMENSION TCC(KNUMB),IP(KNUMB,KNUMB),TB(100)
      IL=1
      IH=KA
      DO 11 I=1,KA
   11 TB(I)=SQRT(ABS(SNGL(AP(I,I))))
      DO 13 I=1,KA
      DO 13 J=1,KA
      XHHH=SNGL(AP(I,J))
      IP(I,J)=0
      IF(TB(I).NE.0.0.AND.TB(J).NE.0.0)
     *IP(I,J)=INT(XHHH*100.0/(TB(I)*TB(J))+0.4)
   13 CONTINUE
      WRITE(6,1000)
 1000 FORMAT(' '/' ','CORRELATION MATRIX'//
     *' ','I   STANDARD  ','   CORRELATION COEFFICIENTS TIMES 100'/
     *' ','    DEVIATION'//)
      ILHILF=IL-1
      DO 15 I=1,KA
      ILHILF=ILHILF+1
      XHILF=0.0
      IF(TCC(ILHILF).NE.0.0) XHILF=100.0*TB(I)/TCC(ILHILF)
   15 WRITE(6,2000) ILHILF,XHILF,(IP(I,J),J=1,I)
 2000 FORMAT(' ',I2,F7.2,' %',20I4/4(12X,20I4/))
      RETURN
      END
C***********************************************
      SUBROUTINE ADDC(ICOVC,WW,KA1)
      REAL*8 WW(KA1,KA1),TB(100),DXHILF
C
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
C
      KA=KA1
      DO 10 I=1,KA
      DO 10 J=1,KA
  10  WW(I,J)=DBLE(COVA(I,J))
C ADD  THE CROSS SECTION PART TO WW
      IF(ICOVC.EQ.0) GOTO 401
C     READ COVARIANCE MATRIX OF CROSS SECTION AND CALCULATE
C     CROSS SECTION CONTRIBUTION
      REWIND 35
      DO 16 I=1,KA
      DO 16 J=1,KA
      DXHILF=0.0D0
C NO CROSS CORRELATIONS IN CROSS SECTION COVARIANCE
      IF(I.NE.J) GOTO 16
      READ(35) NANZ,IL,IH
      DO 14 K=IL,IH
      READ(35) (TB(L),L=IL,IH)
      DO 133 L=IL,IH
  133 DXHILF=DXHILF+TB(L)*DBLE(F1(L))*DBLE(F1(K))
   14 CONTINUE
   16 WW(I,J)=WW(I,J)+DXHILF
C
  401 CONTINUE
      CALL MATRIX(WW,KA)
      DO 26 I=1,KA
      DO 26 J=1,KA
   26 COVA(I,J)=SNGL(WW(I,J))
      RETURN
      END
C***********************************
      SUBROUTINE MATRIX(AP,KA)
      REAL*8 B(40),AP(KA,KA)
C
      CALL SCALEX(AP,B,KA)
      KD=KA
      CALL PIVOT(AP,KD)
      IF(KD.NE.0) GOTO 34
      WRITE(6,1000) KD
 1000 FORMAT(' MATRIXINVERSION FAILS, KD=',I5)
      STOP
   34 CONTINUE
      CALL RESCAL(AP,B,KA)
      RETURN
      END
C*****************************************************************
      SUBROUTINE SCALEX (A,B,KA)
      REAL*8 A(KA,KA),B(KA)
      DO 1 I=1,KA
      B(I)=A(I,1)
      DO 1 J=2,KA
      IF (B(I).GT.A(I,J)) GO TO 1
      B(I)=A(I,J)
 1    CONTINUE
      DO 2 I=1,KA
      DO 2 J=1,KA
 2    A(I,J)=A(I,J)/B(I)
      RETURN
      END
      SUBROUTINE RESCAL (A,B,KA)
      REAL*8 A(KA,KA),B(KA)
      DO 1 I=1,KA
      DO 1 J=1,KA
 1    A(I,J)=A(I,J)/B(J)
      RETURN
      END
      SUBROUTINE PIVOT (S,N)
      DIMENSION NC(40), NR(40)
      REAL*8 S(N,N), BIG, AIJ, TEMP
      DO 457 I = 1, N
      NC(I) = 0
  457 NR(I) = 0
      DO 600 KEEP = 1, N
      BIG = 0.0D0
      DO 500 NS = 1, N
      IF (NR(NS)) 500, 460, 500
  460 AIJ = 0.0D0
      NX = 1
      DO 480 K = 1, N
      IF (DABS(S(NS,K)) - AIJ) 480, 480, 470
  470 IF (NC(K)) 480,475, 480
  475 AIJ = DABS(S(NS,K))
      NX = K
  480 CONTINUE
      IF (AIJ - BIG) 500, 500, 490
  490 BIG = AIJ
      I = NS
      J = NX
  500 CONTINUE
      IF (BIG - 1.0D-8) 710, 710, 510
  510 L = 0
  515 L = L + 1
      IF (L -J) 520, 515, 520
  520 IF (L -N) 530, 530, 540
  530 S(I,L) = -S(I,L)/S(I,J)
      GO TO 515
  540 CONTINUE
      S(I,J) = 1.0D0/S(I,J)
      K = 0
  550 K = K + 1
      IF (K - I) 555, 550, 555
  555 IF (K - N) 560, 560, 590
  560 L = 0
  565 L = L + 1
      IF (L - J) 570, 565, 570
  570 IF (L - N) 575, 575, 580
  575 S(K,L) = S(K,L) + S(I,L)*S(K,J)
      GO TO 565
  580 CONTINUE
  585 S(K,J) = S(K,J)*S(I,J)
      GO TO 550
  590 CONTINUE
      NR(I) = J
      NC(J) = I
  600 CONTINUE
      DO 660 NY = 1,N
      DO 660 K = 1, N
      IF (NY - NR(K)) 630, 610, 630
  610 NR(K) = NR(NY)
      NR(NY) = NY
      DO 620 NV = 1, N
      TEMP = S(NY,NV)
      S(NY,NV) = S(K,NV)
  620 S(K,NV) = TEMP
  630 CONTINUE
      IF (NY - NC(K)) 660, 640, 660
  640 NC(K)  = NC(NY)
      NC(NY) = NY
      DO 650 NV = 1, N
      TEMP = S(NV,NY)
      S(NV,NY) = S(NV,K)
  650 S(NV,K) = TEMP
  660 CONTINUE
      GO TO 700
  710 N = 0
  700 CONTINUE
      RETURN
      END
C****************** FOLLOWING THE ROUTINE PLBILD ******
C****************** FOR SCREEN GRAFICS, WHICH MAY BE REPLACED
C****************** BY A DUMMY ROUTINE
      SUBROUTINE
     *PLBILD(X,Y,SIG,NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV)
C
      CHARACTER*20 TEXT,COM
      LOGICAL OD
      DIMENSION X(NP),Y(NP),SIG(NP)
C IZEIG=0 KEIN BILD
C IZEIG=1 BILD WIRD GEZEIGT, EINGABE ERWARTET
C IZEIG=2 BILD WIRD GEZEIGT UND BLEIBT STEHEN
C
C LAY=0 KEIN NEUER RAHMEN
C LAY=1 LIN-LIN
C    =2 LOG-LIN
C    =3 LIN-LOG
C    =4 LOG-LOG
C LAY NEGATIV: F(E)*E GEPLOTTET
C
C MODIN=1 HISTOGRAMMWERTE ALS EINGABE
C      =2 PUNKTWERTE ALS EINGABE
C
C MODPL=1 HISTOGRAMM
C      =2 LINIE
C      =3 PUNKTE
C MODIN NEGATIV: UNSICHERHEITEN GEPLOTTET
      INQUIRE(UNIT=29,OPENED=OD)
      IF(.NOT.OD) THEN
      OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='OLD',ERR=30)
   30 OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='NEW')
      END IF
      WRITE(29) NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV
C
      WRITE(29) X,Y,SIG
      RETURN
      END
