C
C     PROGRAM MRESBI
C program mresbi to convert bonner-sphere response data ***********************
c                                                       version 12-90
C******************************************************************************
C     PROGRAM MRESBI TO CONVERT POINTWISE GIVEN FLUENCE RESPONSE MATRIX       *
C     1. TO SAND STRUCTURE OF 640 GROUPS (MSAND=1),                           *
C     2. OR TO THE GROUP STRUCTURE CALCULATED FROM THE ENERGIES OF THE        *
C        POINTWISE GIVEN RESPONSE MATRIX FILE (MSAND=0),                      *
C     3. OR TO THE GROUP STRUCTURE GIVEN BY AN INPUT GROUP FLUENCE FILE,      *
C        THE NAME OF WHICH IS ASKED FROM TERMINAL (MSAND=2)                   *
C                                                                             *
C     A LOG-LOG INTERPOLATION (PROGRAMS ECSI AND GRATE FROM THE SUPERTOG      *
C     PROGRAM PACKAGE) IS USED                                                *
C                                                                             *
C                                                                             *
C     AN INPUT FLUENCE FILE IS NEEDED FOR THE CALCULATION OF THE COUNTING     *
C     EVENTS FOR THIS FILE (E.G. OUTPUT FILE FROM THE PROGRAM MSPECT)         *
C     THIS CALCULATION MAY BE CONSIDERED AS A CHECK OF THE PROGRAM            *
C                                                                             *
c     in the following "cross sections" and "response functions" mean the same*
c                                                                             *
C     NAMES OF INPUT AND OUTPUT FILES ARE READ FROM TERMINAL OR FROM THE      *
C     INPUT FILE: TAPE5 NAMED 'CON' IN THE OPEN STATEMENT                     *
C                                                                             *
C     INPUT FILES:                                                            *
C     FILE 15:                                                                *
C     response functions e.g. respdat from a.v.alevra                         *
C     ENERGIES OF file 15 IN EV !                                             *
c                                                                             *
C     FILE 38:                                                                *
C     FLUENCE FILE (E.G. WATT-SPECTRUM AS THE OUTPUT FILE OF MSPECT)          *
c     to calculate reaction rates for this spectrum                           *
C                                                                             *
C     LINE 1: HEADLINE (20A4)                                                 *
C     LINE 2: MODE,MEV (FORMATFREE,SEPARATED BY KOMMA)                        *
C     MODE=0: SPECTRAL POINT FLUENCE VALUES (PER DE)                          *
C     MODE=1: SPECTRAL GROUP FLUENCE VALUES (PER DE)                          *
C     MODE=2: GROUP FLUENCE VALUES                                            *
C NOTE: IN THIS PROGRAM MODE.NE.0 REQUIRED!!!!! *********                     *
C     MEV=0 : ENERGIES IN EV                                                  *
C     MEV=1 : ENERGIES IN MEV                                                 *
C                                                                             *
C     LINE 3: I1,I2,I,(E(I+1)) (FORMATFREE)                                   *
C     I1    : FIRST INDEX  (1)                                                *
C     I2    : LAST INDEX   (640)                                              *
C     I     : NUMBER OF ENERGY VALUES                                         *
C     E(I+1): LAST (RIGHT) ENERGY IN CASE OF GROUP VALUES                     *
C                                                                             *
C     LINE 4 TO LAST LINE: E(I),FLUENCE(I) (FORMATFREE)                       *
C                                                                             *
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
C     OUTPUT FILES:   RESPONSE MATRX FILES = CROSS SECTION FILES              *
C                                                                             *
C     FILE 16:                                                                *
C     RESPONSE MATRIX FILE IN SAND-II STRUCTURE WITH SPECIAL                  *
C     FORMAT WHICH IS ALSO USED IN THE PROGRAMS BY ZIJP AND NOLTHENIUS,       *
C     FILE 17: THE SAME AS FILE 16 BUT UNFORMATTED                            *
C                                                                             *
C                                                                             *
C      THE STRUCTURE OF A LIBRARY IS AS FOLLOWS:
C
C      LINE NO. 1:   MPL  FORMAT(I10)
C
C               MPL: NUMBER OF ENERGY BOUNDARIES, (ONE MORE THAN ENERGY
C
C                    GROUPS)
C
C      NEXT LINES:   MPL ENERGY BOUNDARIES WITH FORMAT(1P8E10.3)
C
C      NEXT LINE:    NC
C               NC:  NUMBER OF COVER MATERIALS IN THE LIBRARY.
C
C
C      NEXT LINES:   NC SETS CONSISTING OF A LINE WITH THE NAME OF THE
C                    COVER MATERIAL (FORMAT(A2)), FOLLOWED BY THE LINES
C                    FOR MPL-1 COVER CROSS SECTIONS (FORMAT(1P8E10.3))
C
C      NEXT LINE:    NL
C
C               NL:  NUMBER OF CROSS SECTION SETS IN THE LIBRARY
C
C      NEXT LINES:   NL BLOCKS CONSISTING OF:
C                    A LINE WITH S,F (FORMAT(2A4,2X,4A4))
C                    S: SHORT NAME OF THE REACTION
C                    F: 16 LETTER NAME OF THE REACTION
C      A LINE WITH   CLAM, CN1, CN2, MAT, MT (FORMAT(1PE10.3, 2A4, 2X, 2I10)
C                    CLAM: DECAY CONSTANT OF THE ACTIVATED ISOTOPE (NOT
C                    USED IN THESE PROGRAMS)
C                    CN1,CN2: NAME OF THE ISOTOPE
C                    MAT,MT:  ENDF-NUMBERS.
C
C                    NOTE: THIS LINE IS ONLY USED BY THE REACTOR CODE
C                    UNC33, FOR BONNER SPHERES THESE LINE CONTAINS DUMMY
C                    VARIABLES.
C      THE LINES WITH MPL-1 CROSS SECTIONS
C                    (FORMAT(1P8E10.3)) FOLLOW.
C
C      THE BINARY CROSS SECTION FILE CREATED FROM THE FORMATTED BY THE
C      PROGRAM UMSBIB HAS THE SAME STRUCTURE.
C
C
C      IN ADDITION TO THE CROSS SECTIONS OF THE REACTIONS
C      THE PROGRAM ALSO PROVIDES SOME PSEUDO CROSS SECTIONS, WHICH MAY
C      BE USED FOR THE CALCULATION OF PSEUDO REACTION RATES:
C
C
C      SHORT NAME    16-CHARACTER
C                     NAME
C
C      PHI-THER      PHI-THERMAL*****           ENERGIES E < 0.563E-6 MEV
C      PHI-INT*      PHI-INTERMEDIATE           0.563E-6 < E < 1.05 MEV
C      PHI-0.1*      PHI < 0.1 MEV **           E > 0.1 MEV
C      PHI-1.0*      PHI < 1.0 MEV **           E > 1.0 MEV
C      PHI-TOT*      PHI-TOTAL ******           TOTAL FLUX
C      < E > **      MEAN ENERGY <E>*
C      TO 0.5EV      THERM TO 0.5 EV            E < 0.5 EV
C      5E-7 E-3      0.5 EV TO 1  KEV           5.0E-7 MEV < E < 1.0E-3 MEV
C      E-3  E-1      1  KEV TO 100KEV           1.0E-3 MEV < E < 0.1 MEV
C      0.1  1.0      100KEV TO 1.0MEV           0.1 MEV < E < 1.0 MEV
C      1.0  5.0      1.0MEV TO 5.0MEV           1.0 MEV < E < 5.0 MEV
C      FROM 5.0      5.0MEV TO 20 MEV           5.0 MEV < E
C      1/V*          1/V RESPONSE FKT
C
C      YOU MAY LOOK AT THE CURVES BY TYPING: PLOT
C      PLOT USES THE FILE CREATED BY THE SUBROUTINE PLBILD
C****************************************************************************
c example of an input file tape5:
c
c  mresbi.pr1               comment:printer output file is mresbi.pr1
c  0,                               energy structure in response matrix format
c  respdat                          response matrix input file
c  resp48.fmt                       output formatted library
c  mspect.out                       input (!) fluence file which is converted
c  mresbi.48                        output fluence file
c  resp48.bin                       binary output library
c  1.0                              factor  for the cross sections
c*****************************************************************************
C                                                                             *
      CHARACTER*4 A(20),BLANK,HEAD(20),cn1,cn2
      CHARACTER*8 BK1(50),BK3(13),BKDOSE
      CHARACTER*16 BK2(50),BK4(13)
      CHARACTER*20 LISTE3,LISTE4
      character*20 text,com
c
      DIMENSION EX(641),EL(641),C(50,100),EL2(641),FLUSS2(641)
     *,SIG1(641),SIG(50,640),SIGX(100),FLUSS(641),FLUSS1(641)
     *,XPLOT(641),YPLOT(641),xplot2(641)
C
      DATA BLANK /'    '/,BKDOSE/'DOSE-EQU'/,BK3/
     *'PHI-THER','PHI-INT*','PHI-0.1*','PHI-1.0*','PHI-TOT*',
     *'< E > **','        ','TO 0.5EV','5E-7 E-3','E-3  E-1',
     *'0.1  1.0','1.0  5.0','FROM 5.0'/
     *BK4/'PHI-THERMAL*****','PHI-INTERMIDIATE',
     *'PHI < 0.1 MEV **','PHI < 1.0 MEV **',
     *'PHI-TOTAL ******','MEAN ENERGY <E>*','                ',
     *'THERM TO 0.5 EV ','0.5 EV TO 1  KEV','1  KEV TO 100KEV',
     *'100KEV TO 1.0MEV','1.0MEV TO 5.0MEV','5.0MEV TO 20 MEV'/
      BK3(7)='1/V*'
      BK4(7)='1/V RESPONSE FKT'
C
C
C     OPEN INPUT AND OUTPUT FILES
      CALL FILEIN(MSAND,LISTE3,LISTE4)
C
C
      DO 10 I=1,20
   10 A(I)=BLANK
C
C
      IF(MSAND.EQ.1) GOTO 7837
      IF(MSAND.EQ.2) GOTO 8837
C MSAND=0
C READ RESPONSE MATRIX ENERGIES FROM FILE 15
      READ(15,1005) A
C READ NUMBER OF ENERGY POINTS
      READ(15,*) KG1
C READ ENERGY POINTS
      DO 7840 I=1,KG1
      READ(15,*) EL(I)
C CONVERT TO MEV
      EL(I)=EL(I)*1.0E-6
 7840 CONTINUE
      MPL1=KG1+1
C FIRST ENERGY POINTS
      XH2=SQRT(EL(2)*EL(1))
      XH1=EL(1)*EL(1)/XH2
C LAST ENERGY POINT
      XHN=SQRT(EL(KG1-1)*EL(KG1))
      XHN1=EL(KG1)*EL(KG1)/XHN
      EX(1)=EL(1)
      DO 7838 I=2,KG1
      EX(I)=EL(I)
 7838 EL(I)=SQRT(EX(I)*EX(I-1))
      EL(1)=XH1
      EL(MPL1)=XHN1
      REWIND 15
      GOTO 7839
 7837 CONTINUE
C MSAND=1
C FILL EL(641) WITH SAND ENERGIES
      MPL1=641
      KG1=640
      CALL ETAB(EL,MPL1)
      GOTO 7839
C
 8837 CONTINUE
C MSAND=2:
C
C READ HEADLINE FROM FILE 29
      READ(29,3728,ERR=3729,END=3729) HEAD
 3728 FORMAT(20A4)
 3729 WRITE(6,3730) HEAD
 3730 FORMAT(' '/' HEADLINE FLUENCE FILE 29:'/' ',20A4/)
      READ(29,*) MODE,MEV
      IF(MODE.NE.0) GOTO 8838
      WRITE(6,8839) MODE
 8839 FORMAT(' NO GROUP FLUENCE VALUES IN FILE 29, MODE=',I4)
      STOP
 8838 READ(29,*) IL,IH,KG1,EDUM
      MPL1=KG1+1
      EL2(MPL1)=EDUM
      IF(MEV.EQ.0) EL2(MPL1)=EL2(MPL1)*1.0E-6
      DO 8840 I=1,KG1
      READ(29,*) EL2(I),FLUSS2(I)
      IF(MEV.EQ.0) EL2(I)=EL2(I)*1.0E-6
      IF(MEV.EQ.2) EL2(I)=EL2(I)*1.0E-3
 8840 CONTINUE
      DO 8841 I=1,KG1
      EL(I)=EL2(I)
C CONVERT TO AVERAGE GROUP FLUENCE VALUES:
      IF(MODE.EQ.1) FLUSS2(I)=FLUSS2(I)*(EL2(I+1)-EL2(I))
 8841 CONTINUE
      EL(MPL1)=EL2(MPL1)
C
 7839 CONTINUE
C READ SPECTRAL POINT FLUENCE VALUES FROM FILE 38
C READ HEADLINE FROM FILE 38
      READ(38,3728,ERR=4729,END=4729) HEAD
 4729 WRITE(6,4730) HEAD
 4730 FORMAT(' '/' HEADLINE FLUENCE FILE 38:'/' ',20A4/)
      READ(38,*) MODE,MEV
C
C     MODE=1 MEANS SPECTRAL group VALUES WHICH ARE HERE REQUIRED
      IF(MODE.EQ.1) GOTO 141
      WRITE(6,142) MODE
  142 FORMAT(' NO SPECTRAL group VALUES ON FILE 38, MODE=',I4)
      STOP
  141 READ(38,*) I1,I2,KG,edum
      MPL=KG+1
      ex(mpl)=edum
      DO 39 I=1,KG
C
      READ(38,*) EX(I),FLUSS(I)
C CONVERT TO MEV
      IF(MEV.EQ.1) GOTO 39
      IF(MEV.EQ.0) THEN
      EX(I)=EX(I)*1.0E-6
      ELSE
      EX(I)=EX(I)*1.0E-3
      END IF
      FLUSS(I)=FLUSS(I)*1.0E6
   39 YPLOT(I)=FLUSS(I)
c convert energies to mid-interval:
      xplot(mpl)=ex(mpl)
      do 389 i=1,kg
      xplot(I)=ex(I)
      ex(I)=sqrt(ex(I)*ex(i+1))
  389 continue
      text(1:20)=LISTE3
      call plbild(xplot,yplot,yplot,mpl,-2,1,1,1.0,1,text,com,1)
C     CALL PLBILD(XPLOT,YPLOT,KG,1,2,1)
      text(1:20)=liste4
C     CALL PLBILD(XPLOT,YPLOT,KG,1,2,0)
C NOW SPECTRAL VALUES ARE READ IN
C ENERGY UNIT IS MEV !
C
C
C     CONVERT TO FINE STRUCTURE
      CALL INTPOL(EX,FLUSS,KG,EL,FLUSS1,MPL1)
C
C NOW IN FLUSS1 ARE SPECTRAL GROUP FLUENCE VALUES
C
C OUTPUT OF SPECTRAL GROUP FLUENCE VALUES IN FILE 39
      WRITE(39,3728) HEAD
      MODE=1
      MEV=1
      WRITE(39,3921) MODE,MEV
 3921 FORMAT(' ',2(I4,1H,))
C
      IUN=0
      WRITE(39,3922) I1,KG1,KG1,EL(MPL1),IUN
 3922 FORMAT(' ',3(I4,1H,),1PE12.4,', ',I4)
      SUM=0.0
C NORMALIZE OUTPUT SPECTRUM TO 1000.
      DO 4923 I=1,KG1
 4923 SUM=SUM+FLUSS1(I)*(EL(I+1)-EL(I))
      SUM1=0.0
      DO 3923 I=1,KG1
      XPLOT(I)=EL(I)
      YPLOT(I)=FLUSS1(I)
      FLUSS1(I)=FLUSS1(I)*1000./SUM
      SUM1=SUM1+FLUSS1(I)*(EL(I+1)-EL(I))
 3923 WRITE(39,3924) EL(I),FLUSS1(I),yplot(I)
      XPLOT(MPL1)=EL(MPL1)
      text(1:20)=LISTE4
      call plbild(xplot,yplot,yplot,mpl1,0,1,1,1.0,1,text,com,1)
C     CALL PLBILD(XPLOT,YPLOT,MPL1,0,1,1)
 3924 FORMAT(' ',1PE12.4,1H,,' ',2(E12.4,1H,))
      WRITE(6,2276) SUM1
 2276 FORMAT(' '/' NORM OF OUTPUT FLUENCE :',1PE12.4)
C
C READ RESPONSE MATRIX FROM FILE 15
      READ(15,1005) A
 1005 FORMAT(20A4)
      WRITE(6,3005) A
 3005 FORMAT(' '/' ',20('****')/' ',20A4/)
C READ NUMBER OF ENERGY POINTS
      READ(15,*) NP
C READ ENERGY POINTS
      DO 100 I=1,NP
  100 READ(15,*) EX(I)
C READ NUMBER OF REACTIONS
      READ(15,*) NL
      NLINP=NL
C READ NAMES AND REACTION CROSS SECTIONS
      DO 200 I=1,NL
      FAKKT=1.0
      READ(15,3006) BK1(I)
      IF(BK1(I).EQ.BKDOSE) FAKKT=1.0E9
 3006 FORMAT(A8)
      READ(15,3007) BK2(I)
 3007 FORMAT(A16)
      DO 200 J=1,NP
      READ(15,*) C(I,J)
  200 C(I,J)=C(I,J)*FAKKT
C NOW EX,BK1,BK2,C IS FILLED
C
C PRINT THE DATA READ IN
      I2=0
 8384 I1=I2+1
      I2=I1+8
      IF(I2.GT.NL) I2=NL
      WRITE(6,4000) (BK1(I),I=I1,I2)
 4000 FORMAT(' ','  ','  ENERGY  ',9(' ',A8,' ')/ ' ','    EV'/)
      DO 401 I=1,NP
  401 WRITE(6,4001) I,EX(I),(C(K,I),K=I1,I2)
      IF(I2.LT.NL) GOTO 8384
 4001 FORMAT(' ',I2,10(1PE10.3))
C
C PRINT THE NAMES
      WRITE(6,3287)
 3287 FORMAT(' '//' REACTION NAMES FROM THE RESPONSE MATRIX FILE:'//)
      DO 402 I=1,NL
  402 WRITE(6,3001) BK2(I)
 3001 FORMAT(' '/
     *' ',A16)
C
C CONVERT EV READ IN ENERGIES TO MEV     (IMPORTANT ! **************)
      DO 403 I=1,NP
  403 EX(I)=EX(I)*1.0E-6
c
c fill xplot2
      mpl2=np+1
C FIRST ENERGY POINTS
      XH2=SQRT(Ex(2)*Ex(1))
      XH1=Ex(1)*Ex(1)/XH2
C LAST ENERGY POINT
      XHN=SQRT(Ex(np-1)*Ex(np))
      XHN1=Ex(np)*Ex(np)/XHN
      xplot2(1)=Ex(1)
      DO 2838 I=2,np
 2838 xplot2(I)=SQRT(ex(I)*ex(i-1))
      xplot2(1)=XH1
      xplot2(MPL2)=XHN1
c
C INTERPOLATE CROSS SECTIONS LOG-LOG AND INTEGRATE
      KG=MPL1-1
      DO 500 I=1,NL
      DO 501 J=1,NP
  501 SIGX(J)=C(I,J)
      if(msand.eq.0) then
      do 741 j=1,np
  741 sig1(j)=sigx(J)
      else
      CALL INTPOL(EX,SIGX,NP,EL,SIG1,MPL1)
      end if
      DO 502 J=1,KG
  502 SIG(I,J)=SIG1(J)
  500 CONTINUE
C
C
C FILL ADDITIONAL RESPONSE FUNCTIONS
      DO 1125 I=1,7
      I1=NL+I
      BK1(I1)=BK3(I)
      BK2(I1)=BK4(I)
      DO 132 KK=1,KG
      SIG(I1,KK)=1.0
      GOTO(126,127,128,129,130,131,1311) I
  126 CONTINUE
      XHH1=0.563E-6
      IF(EL(KK).LE.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(XHH1-EL(KK))
     */(EL(KK+1)-EL(KK))
      IF(EL(KK).GT.XHH1) SIG(I1,KK)=0.0
      GOTO 132
  127 CONTINUE
      XHH1=0.563E-6
      XHH2=1.05
      SIG(I1,KK)=0.0
      IF(EL(KK).LE.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LE.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LE.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 132
  128 CONTINUE
      SIG(I1,KK)=0.0
      IF(EL(KK).LE.0.1.AND.EL(KK+1).GT.0.1) SIG(I1,KK)=(EL(KK+1)-0.1)/
     *(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.0.1) SIG(I1,KK)=1.0
      GOTO 132
  129 CONTINUE
      SIG(I1,KK)=0.0
      IF(EL(KK).LE.1.0.AND.EL(KK+1).GT.1.0) SIG(I1,KK)=(EL(KK+1)-1.0)/
     *(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.1.0) SIG(I1,KK)=1.0
      GOTO 132
  130 CONTINUE
      GOTO 132
  131 SIG(I1,KK)=0.5*(EL(KK+1)+EL(KK))
      GOTO 132
 1311 SIG(I1,KK)=2.*(SQRT(EL(KK+1))-SQRT(EL(KK)))/(EL(KK+1)-EL(KK))
  132 CONTINUE
 1125 CONTINUE
C
C FILL ADDITIONAL RESPONSE FUNCTIONS
      ISPR=0
      DO 3125 I=8,13
      ISPR=ISPR+1
      I1=NL+I
      BK1(I1)=BK3(I)
      BK2(I1)=BK4(I)
      DO 332 KK=1,KG
      SIG(I1,KK)=1.0
      GOTO(326,327,328,329,330,331) ISPR
  326 CONTINUE
      XHH1=0.5E-6
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(XHH1-EL(KK))
     */(EL(KK+1)-EL(KK))
      IF(EL(KK).GT.XHH1) SIG(I1,KK)=0.0
      GOTO 332
  327 CONTINUE
      XHH1=0.5E-6
      XHH2=1.0E-3
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  328 CONTINUE
      XHH1=1.0E-3
      XHH2=1.0E-1
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  329 CONTINUE
      XHH1=1.0E-1
      XHH2=1.0
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  330 CONTINUE
      XHH1=1.0
      XHH2=5.0
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
      GOTO 332
  331 CONTINUE
      XHH1=5.0
      XHH2=20.0
      SIG(I1,KK)=0.0
      IF(EL(KK).LT.XHH1.AND.EL(KK+1).GT.XHH1) SIG(I1,KK)=(EL(KK+1)-
     *XHH1)/(EL(KK+1)-EL(KK))
      IF(EL(KK).GE.XHH1.AND.EL(KK).LT.XHH2)   SIG(I1,KK)=1.0
      IF(EL(KK).LT.XHH2.AND.EL(KK+1).GT.XHH2) SIG(I1,KK)=(XHH2-EL(KK))
     */(EL(KK+1)-EL(KK))
  332 CONTINUE
 3125 CONTINUE
C
C OUTPUT IN FILE 16
      M=KG
C*************************************************************
C
C
C     MPL1 = NUMBER OF ENERGY POINTS
C     M    = NUMBER OF ENERGY GROUPS
C
   80 FORMAT (I10)
      IF(MSAND.EQ.1)
     *WRITE (6,120) MPL1,M
  120 FORMAT (' '/' SAND-STRUCTURE :'/7H MPL1 =,I10/4H M =,I13/)
      IF(MSAND.EQ.0)
     *WRITE (6,119) MPL1,M
  119 FORMAT (' '/' ENERGY STRUCTURE :'/7H MPL1 =,I10/4H M =,I13/)
      WRITE (16,80) MPL1
      WRITE(16,81) (EL(J),J=1,MPL1)
      WRITE (17) MPL1
      WRITE(17) (EL(J),J=1,MPL1)
C FILL XPLOT
   81 FORMAT (1P8E10.3)
      NC=0
      WRITE(16,80) NC
      WRITE(17) NC
C
C     NC = NUMBER OF COVER MATERIALS
C
      NL=NL+13
      WRITE(16,80) NL
      write(17) nl
C
C     NL = NUMBER OF CROSS SECTION SETS IN THE LIBRARY
C
      WRITE (6,124) NL
  124 FORMAT (' ------------------------------------'/' NL =',I5/
     *' ------------------------------------')
C
      DO 2 N=1,NL
C
      WRITE(16,83) BK1(N),BK2(N)
   83 FORMAT (A8,2X,A16)
      WRITE(17) BK1(N),BK2(N)
      WRITE (6,125) N,BK1(N),BK2(N)
  125 FORMAT (I5,5X,A8,2X,A16)
      CLAM=0.0
      MAT=0
      MT=0
      cn1='    '
      cn2='    '
      WRITE(16,84) CLAM,MAT,MT
      WRITE(17) CLAM,CN1,CN2,MAT,MT
C
C     CLAM = DECAY CONSTANT (LAMBDA) IN S**-1
C     CN1  = NAME OF THE ISOTOPE FOR WHICH THE DECAY CONSTANT IS GIVEN,
C            FIRST PART
C     CN2  = CONTINUATION OF THE NAME
C     MAT  = MATERIAL NUMBER IN THE ORIGINAL LIBRARY
C            OF THE ENDF/B-V FORMAT
C     MT   = REACTION NUMBER IN THE ORIGINAL LIBRARY
C            OF THE ENDF/B-V FORMAT
C
   84 FORMAT (1PE10.3,8X,2X,2I10)
C
C     THE SAND-II CODE NEEDS THE CLAM ONLY (CN1,CN2,MAT AND MT
C     ARE NOT READ BY IT), THE NEXT WRITE STATEMENT CAN BE MODIFIED
C
C
C PRINT THE REACTION EVENTS
      SUM1=0.0
C
      SUM=0.0
      DO 7856 J=1,M
      IF(MSAND.EQ.2) SUM1=SUM1+FLUSS2(I)*SIG(N,J)
 7856 SUM=SUM+FLUSS1(J)*SIG(N,J)*(EL(J+1)-EL(J))
      IF(MSAND.NE.2)
     *WRITE(6,7857) SUM
 7857 FORMAT(' REACTION EVENTS:  ',1PE12.4/' ',5('------------')/)
      IF(MSAND.EQ.2)
     *WRITE(6,8857) SUM,SUM1
 8857 FORMAT(
     *' REACTION EVENTS FOR FILE 38 AND FILE 39 :  ',1PE12.4/
     *'                             FOR FILE 29 :  ',E12.4/
     *' ',5('------------')/)
C
      WRITE(16,81) (SIG(N,J),J=1,M)
      WRITE(17) (SIG(N,J),J=1,M)
C FILL YPLOT AND NORMALIZE FOR PLOTTING
C IF ADDITIONAL REACTIONS DO NOT PLOT
      MBILD=0
      DO 793 J=1,M
      YPLOT(J)=SIG(N,J)
 793  xplot(J)=el(J)
      XPLOT(MPL1)=EL(MPL1)
      com(1:8)=BK1(N)
      text(1:13)='OUTPUT VALUES'
      IF(N.GT.NLINP) MBILD=1
      call plbild(xplot,yplot,yplot,mpl1,2,1,1,1.0,0,text,com,1)
C
      IF(MBILD.EQ.1) GOTO 2
      MBILD=1
      mpl2=np+1
      DO 790 J=1,NP
  790 YPLOT(J)=C(N,J)
c
      text(1:12)='INPUT VALUES'
      call plbild(xplot2,yplot,yplot,mpl2,0,1,3,1.0,1,text,com,1)
    2 CONTINUE
      ENDFILE 16
      STOP
      END
C**************************************************************
C*********************************************************************
      SUBROUTINE ETAB(EL,MPL1)
      DIMENSION ENUL(45),EL(MPL1)
      DATA ENUL/1.,1.05,1.1,1.15,1.2,1.275,1.35,1.425,1.5,1.6,1.7,
     11.8,1.9,2.,2.1,2.2,2.3,2.4,2.55,2.7,2.8,3.,3.2,3.4,3.6,3.8,4.,
     24.25,4.5,4.75,5.,5.25,5.5,5.75,6.,6.3,6.6,6.9,7.2,7.6,8.,8.4,
     38.8,9.2,9.6/
      J=0
      DO 12  I=1,10
      IN=I-5
      P=10.**IN
      DO 12  IK=1,45
      J=J+1
   12 EL(J) = ENUL(IK)*P
      EL(451) = 1.E+6
      DO 24  I=452,641
   24 EL(I) = EL(I-1)+1.E+5
      NEL = 641
      DO 33 I=1,NEL
   33 EL(I)=EL(I)*1.0E-6
      RETURN
      END
C**********************************************************************
      SUBROUTINE INTPOL(EX,SIGX,NP,EL,SIG1,MPL1)
      DIMENSION EX(NP),SIGX(NP),EL(MPL1),SIG1(MPL1)
      KG=MPL1-1
      DO 10 I=1,KG
      XLP=EL(I)
      XHP=EL(I+1)
C XLP,XHP ARE THE INTEGRATION LIMITS
      CALL GRATE(XLP,XHP,ANS,EX,SIGX,NP)
      SIG1(I)=ANS/(XHP-XLP)
   10 CONTINUE
      RETURN
      END
C***************************************************************
      SUBROUTINE ECSI(X3P,Y3P,X4P,Y4P,X1P,X2P,I,ANSP)
C=====COMPUT INTEGRAL OF Y(X)===========================================
C     Y(X) DEFINED BY THE END POINTS (X3,Y3), (X4,Y4), AND THE
C     INTERPOLATION CODE I.  X1 AND X2 ARE THE INTEGRATION LIMITS.
C-----ERROR STOP
C       110 INTERPOLATION CODE OUT OF RANGE
C     X1 AND X2 MAY LIE OUTSIDE X3 AND X4
C*****THE NEXT STATEMENT IS MACHINE DEPENDENT.
C     THE STATEMENT IS REQUIRED FOR IBM-360 BUT SHOULD BE REMOVED
C     FOR CDC MACHINES.
      REAL*8 A,B,Z,X1,X2,X3,X4,Y3,Y4,ANS,X
      ALOG(X)=DLOG(X)
      EXP(X)=DEXP(X)
      X3=DBLE(X3P)
      Y3=DBLE(Y3P)
      X4=DBLE(X4P)
      Y4=DBLE(Y4P)
      X1=DBLE(X1P)
      X2=DBLE(X2P)
   10 ANS=0.0
      IF(X4-X3)200,200,20
   20 IP=I
      IF(IP)30,30,40
C  30 CALL ERROR(110)
   30 CONTINUE
   40 IF(IP-5)50,50,30
   50 GOTO(60,70,80,110,140),IP
C-----Y CONSTANT
   60 ANS=(X2-X1)*Y3
      GOTO200
C-----Y LINEAR IN X
   70 B=(Y4-Y3)/(X4-X3)
      A=Y3-B*X3
      ANS=(X2-X1)*(A+0.5*B*(X2+X1))
      GOTO200
C-----Y LINEAR IN LN(X)
   80 IF((X3.LE.0.0).OR.(X4.LE.0.0)) GO TO 70
      B=(Y4-Y3)/ALOG(X4/X3)
      Z=(X2-X1)/X1
      IF(DABS(Z)-0.15)90,90,100
   90 ANS=(X2-X1)*(Y3+B*ALOG(X1/X3))+(0.5*B*X1*Z*Z)*
     1(1.0+Z*(-0.33333333+Z*(0.16666667-0.1*Z)))
      GOTO200
  100 ANS=(X2-X1)*(Y3+B*ALOG(X1/X3))+B*X1*
     1(1.0+(X2/X1)*(ALOG(X2/X1)-1.0))
      GOTO200
C-----LN(Y) LINEAR IN X
  110 IF((Y3.LE.0.0).OR.(Y4.LE.0.0)) GO TO 70
      B=ALOG(Y4/Y3)/(X4-X3)
      A=ALOG(Y3)-B*X3
      Z=(X2-X1)*B
      IF(DABS(Z)-0.1)120,120,130
  120 ANS=EXP(A+B*X1)*(X2-X1)*(1.0+Z*(0.5+0.16666667*Z))
      GOTO200
  130 ANS=EXP(A+B*X1)*(EXP(Z)-1.0)/B
      GOTO200
C-----LN(Y) LINEAR IN LN(X)
  140 IF((X3.LE.0.0).OR.(X4.LE.0.0)) GO TO 110
      IF((Y3.LE.0.0).OR.(Y4.LE.0.0)) GO TO 80
      B=ALOG(Y4/Y3)/ALOG(X4/X3)
      Z=(B+1.0)*ALOG(X2/X1)
      IF(DABS(Z)-0.1)150,150,160
  150 ANS=Y3*X1*((X1/X3)**B)*ALOG(X2/X1)*(1.+Z*(0.5+0.16666667*Z))
      GOTO200
  160 ANS=Y3*X1*((X1/X3)**B)*(((X2/X1)**(B+1.0))-1.0)/(B+1.0)
      GOTO200
C-----FINISHED
  200 ANSP=SNGL(ANS)
      RETURN
      END
      SUBROUTINE GRATE(XLP,XHP,ANS,EX,SIGX,NP)
      DIMENSION EX(NP),SIGX(NP)
C     XLP AND XHP ARE THE INTEGRATION LIMITS
C     ANS IS THE ANSWER
C LOCATE XLP,XHP
      IF(XHP.GT.EX(2)) GOTO 10
C XHP<=EX(2)
      NL=1
      NH=2
      GOTO 50
   10 CONTINUE
C XHP>EX(2)
      IF(XLP.LT.EX(NP-1)) GOTO 11
      NL=NP-1
      NH=NP
      GOTO 50
   11 CONTINUE
C XHP>EX(2) AND XLP<EX(NP-1)
      DO 18 I=2,NP
      NL=I-1
      IF(EX(I).GT.XLP) GOTO 19
   18 CONTINUE
   19 CONTINUE
C NOW NL IS FIXED
      DO 20 I=NL,NP
      NH=I
      IF(EX(I).GT.XHP) GOTO 21
   20 CONTINUE
   21 CONTINUE
C NOW ALSO NH IS FIXED
      IF(NL.EQ.NH.AND.NH.EQ.NP) NL=NH-1
      IF(NL.EQ.NH.AND.NL.EQ.1)  NH=NL+1
      IF(NL.EQ.NH) NH=NL+1
   50 CONTINUE
      IF(NH.GT.(NL+1)) GOTO 60
C ONLY ONE PANEL
      CALL ECSI(EX(NL),SIGX(NL),EX(NH),SIGX(NH),XLP,XHP,5,ANS)
      GOTO 400
C MORE THAN ONE PANEL
   60 SUM=0.0
      I2=NH-1
      XL1=XLP
      XH1=XHP
      DO 70 I=NL,I2
      XH1=EX(I+1)
      IF(XH1.GT.XHP) XH1=XHP
      CALL ECSI(EX(I),SIGX(I),EX(I+1),SIGX(I+1),XL1,XH1,5,ANS)
      XL1=XH1
   70 SUM=SUM+ANS
      ANS=SUM
  400 CONTINUE
      RETURN
      END
C******************************************************************************
      SUBROUTINE FILEIN(MSAND,LISTE3,LISTE4)
      CHARACTER*20 LISTE1,LISTE2,LISTE,LISTE3,LISTE4,LISTE5,list17
C
      DATA LISTE /'              '/
C
      LISTE1=LISTE
C
C
      WRITE(*,503)
  503 FORMAT(
     1' GIVE NAME OF PRINTER FILE OR PRINTER IDENTIFICATION (LPT1):'/)
      READ(5,7777,ERR=504,END=504) LISTE1
  504 OPEN(6,FILE=LISTE1)
      LISTE1=LISTE
C
      WRITE(6,3000)
 3000 FORMAT(' PROGRAM MRESBI BY MATZKE (VERSION 11.87)'//)
C
      LISTE1=LISTE
      LISTE2=LISTE
      LISTE3=LISTE
      LISTE4=LISTE
      LISTE5=LISTE
      list17=liste
C
C ASK ENERGY STRUCTURE
      WRITE(*,7836)
 7836 FORMAT(
     *' MSAND=0: ENERGY STRUCTURE FROM THE RESPONSE MATRIX FILE,'/
     *' MSAND=1: SAND-II ENERGY STRUCTURE OF 640 GROUPS,'/
     *' MSAND=2: ENERGY STRUCTURE FROM A GROUP FLUENCE FILE'/
     *' GIVE MSAND !'/)
      READ(5,*) MSAND
      IF(MSAND.EQ.0) WRITE(6,5302)
      IF(MSAND.EQ.1) WRITE(6,5303)
      IF(MSAND.EQ.2) WRITE(6,5304)
 5302 FORMAT(' MSAND=0: ENERGY STRUCTURE FROM RESPONSE MATRIX FILE')
 5303 FORMAT(' MSAND=1: SAND-II ENERGY STRUCTURE OF 640 GROUPS,')
 5304 FORMAT(' MSAND=2: ENERGY STRUCTURE FROM A GROUP FLUENCE FILE')
C
      WRITE(*,5555)
C
 5555 FORMAT(' NAME OF INPUT RESPONSE MATRIX FILE ?  '/
     *' E.G. RESPDAT'/)
      READ(5,7777,END=9911,ERR=9911) LISTE
 9911 WRITE(6,9912) LISTE
 9912 FORMAT(' NAME OF INPUT RESPONSE MATRIX FILE: '/
     *' FILE 15: ',A20/)
C
      WRITE(*,6666)
 6666 FORMAT(' NAME OF NEW FORMATTED OUTPUT RESPONSE MATRIX FILE?'/)
      READ(5,7777,END=8888,ERR=8888) LISTE1
 7777 FORMAT(A20)
 8888 CONTINUE
      WRITE(6,9913) LISTE1
 9913 FORMAT(' NAME OF OUTPUT FORMATTED RESPONSE MATRIX FILE 16: ',
     *A20//)
C
C
      OPEN(15,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
C
      OPEN(16,FILE=LISTE1,STATUS='NEW',FORM='FORMATTED')
C
      WRITE(*,4422)
 4422 FORMAT(' NAME OF INPUT FLUENCE FILE ? '/
     *' E.G. MSPECT.OUT FROM A MSPECT-RUN, THIS FILE IS NOT '/
     *' TAKEN FOR THE CALCULATION OF THE GROUP STRUCTURE !!!!!'/)
      READ(5,7777,END=4423,ERR=4423) LISTE3
 4423 CONTINUE
      WRITE(*,4434)
 4434 FORMAT(' NAME OF binary output response function file ?'/)
      READ(5,7777,END=4435,ERR=4435) LIST17
 4435 open(17,file=list17,status='new',form='unformatted')
      write(6,4436) list17
 4436 format(' name of output binary response matrix file 17   :',
     1a20//)
c
      OPEN(38,FILE=LISTE3,STATUS='OLD',FORM='FORMATTED')
C
      WRITE(*,4424) LISTE3
 4424 FORMAT(' NAME OF OUTPUT FLUENCE FILE ? (GROUP FLUENCE VALUES)'/
     *' OF THE FILE ',A20,' IN THE NEW STRUCTURE'/
     *' E.G. MRESBI.640'/)
      READ(5,7777,END=4425,ERR=4425) LISTE4
 4425 CONTINUE
      OPEN(39,FILE=LISTE4,STATUS='NEW',FORM='FORMATTED')
      WRITE(6,4426) LISTE3,LISTE4
 4426 FORMAT(' '/' INPUT POINT FLUENCE FILE 38: ',A20/
     *' OUTPUT CONVERTED SPECTRAL GROUP FLUENCE FILE 39: ',A20)
C
      IF(MSAND.NE.2) RETURN
      WRITE(*,5424)
 5424 FORMAT(' ENERGIES FROM A GROUP FLUENCE FILE'/
     *' NAME OF THE FLUENCE FILE CONTAINING ENERGIES'/
     *' IN THE NEW STRUCTURE'/
     *' (GROUP FLUENCE VALUES !)'/)
      READ(5,7777,END=5425,ERR=5425) LISTE5
 5425 CONTINUE
      OPEN(29,FILE=LISTE5,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,5426) LISTE5
 5426 FORMAT(' '/' ENERGIES FROM THE GROUP FLUENCE FILE 29: ',A20)
      RETURN
      END
c
C****************** FOLLOWING THE ROUTINE PLBILD ******
C****************** FOR SCREEN GRAFICS, WHICH MAY BE REPLACED
C****************** BY A DUMMY ROUTINE
      SUBROUTINE
     *PLBILD(X,Y,SIG,NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV)
C
      CHARACTER*20 TEXT,COM
      LOGICAL OD
      DIMENSION X(NP),Y(NP),SIG(NP)
C IZEIG=0 KEIN BILD
C IZEIG=1 BILD WIRD GEZEIGT, EINGABE ERWARTET
C IZEIG=2 BILD WIRD GEZEIGT UND BLEIBT STEHEN
C
C LAY=0 KEIN NEUER RAHMEN
C LAY=1 LIN-LIN
C    =2 LOG-LIN
C    =3 LIN-LOG
C    =4 LOG-LOG
C LAY NEGATIV: F(E)*E GEPLOTTET
C
C MODIN=1 HISTOGRAMMWERTE ALS EINGABE
C      =2 PUNKTWERTE ALS EINGABE
C
C MODPL=1 HISTOGRAMM
C      =2 LINIE
C      =3 PUNKTE
C MODIN NEGATIV: UNSICHERHEITEN GEPLOTTET
      INQUIRE(UNIT=29,OPENED=OD)
      IF(.NOT.OD) THEN
      OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='OLD',ERR=30)
   30 OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='NEW')
      END IF
      WRITE(29) NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV
C
      WRITE(29) X,Y,SIG
      RETURN
      END
