C
C***********************************************************************
C PROGRAM MSITER (MODIFIED STAYSL CODE                  BY M.MATZKE )
C VERSION 11-90
C
C  THIS IS A MODIFICATION OF THE ORIGINAL STAY'SL ALGORITHM OF
C  F. G. PEREY (REPORT ORNL/TM-6062, ENDF 254, OAK RIDGE, 1986).
C  IN ADDITION TO THE STAY'SL CODE THE NORMALIZATION FACTOR
C  OF THE SPECTRUM CAN BE CALCULATED BY MSITER.
C
C  THERE ARE SOME PARTS OF THE PROGRAM TAKEN FROM OTHER CODES:
C
C  THE MATRIX INVERSION IS FROM THE ORIGINAL STAYSL CODE OF F. PEREY
C  THE SEARCHING ROUTINE FOR CROSS SECTIONS (RESPONSE FUNCTIONS)
C  IS A MODIFIED VERSION FROM THE PROGRAM FITOCO BY HENK NOLTHENIUS
C
C  IN THE DESCRIPTION THERE ARE OFTEN USED THE PHYSICAL QUANTITIES
C  FLUX DENSITY, FLUENCE AND ACTIVITIES, REACTION EVENTS.
C  FLUX DENSITY CORRESPONDS TO ACTIVITIES,
C  FLUENCE CORRESPONDS TO REACTION EVENTS:
C
C  A=INTEGRAL(SIG(E)*F(E))      A: ACTIVITIES, F(E): SPECTRAL FLUX DENSITY
C                           OR: A: REACTION EVENTS, F(E) SPECTRAL FLUENCE
C
C
C  THE MOST FAMOUS ADJUSTMENT CODE IS THE STAY'SL PROGRAM BY F.G. PERY
C  THE ALGORITHM OF WHICH IS ALSO PART OF THE GERMAN INDUSTRIAL
C  STANDARD DIN1319, PART 4 . THIS PROGRAM IS BASED ON THAT ALGORITHM.
C
C***********************************************************************
C  SHORT DESCRIPTION OF THE METHOD:
C
C  GIVEN:
C  A VECTOR OF MEASURED ACTIVITIES A0 WITH ELEMENTS A0(I),(I=1,...KA),
C  THE COVARIANCE MATRIX KA0 WITH ELEMENTS KA0(I,J), (I,J=1,...KA),
C
C  A SO-CALLED PARAMETER VECTOR P0 WITH ELEMENTS P0(K),(K=1,...M),
C  THE COVARIANCE MATRIX KP0 WITH ELEMENTS KP0(K1,K2), (K1,K2=1,...M).
C
C  THE VECTOR P0 IS THOUGHT TO BE COMPOSED OF THE A PRIORI KNOWN
C  FLUX DENSITY VECTOR F0 (OBTAINED E.G. BY A TRANSPORT CODE CALCULATION)
C  AND OF ALL THE ELEMENTS OF THE CROSS SECTIONS S0(I,K) (I=1,..,KA,K=1,..,M)
C  KNOWN FROM LITERATURE (I: REACTION INDEX, K: ENERGY INDEX).
C  THE COVARIANCE MATRIX KP0 IS COMPOSED OF THE (UNCORRELATED) PARTS
C  KF0 OF THE FLUX DENSITY AND OF KS0 OF THE CROSS SECTIONS.
C
C  IN THIS NOTATION THE GENERAL LEAST-SQUARES ADJUSTMENT CAN BE
C  PERFORMED BY MINIMIZING:
C
C  CHI**2 = (A0-A)*KA0(-1)*(A0-A) + (P0-P)*KP0(-1)*(P0-P) + (A-H(P,C))*LAMBDA
C
C  ( KA0(-1), KP0(-1) : MATRIX INVERS, TRANSPOSITION OF LEFT HAND VECTORS)
C  LAMBDA: LAGRANGE PARAMETER VECTOR (SEE J.J. WAGSCHAL, Y. YEIVIN:
C  7TH ASTM-EURATOM SYMPOSIUM, STRASBOURG, 1990)
C
C  A = H(P,C): MODEL EQUATIONS, E.G. A = C * S * F
C              C: NORMALIZATION CONSTANT, S: CROSS SECTIONS, F: FLUX DENSITY
C
C  MINIMIZATION WITH RESPECT TO A, P, C UNDER THE CONSTRAINT A = H(P,C).
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C  IN THE STAY'SL CODE C IS THOUGHT TO BE KNOWN, THEREFORE, NO MINIMIZATION
C  WITH RESPECT TO C IS PERFORMED IN STAY'SL. HOWEVER, IN PRACTICE THE STAY'SL
C  CODE HAS SOME OPTIONS FOR FIRST DERIVING C.
C
C  THE PROGRAM MSITER CAN EITHER BE USED AS A STAY'SL LIKE CODE WITH
C  C=1 OR AS A STAY'SL CODE WITH C CALCULATED BY
C
C            KA                            KA
C      C =   S  AC(I)*KA0(I,J)(-1)*A0(J) / S  AC(I)* KA0(I,J)(-1)*AC(J)
C           I=1                           I=1
C           J=1                           J=1
C
C  (AC: REACTION RATES CALCULATED FROM THE INPUT VALUES F0 AND S0).
C   AC=S0*F0
C
C  (FOR THESE TWO CASES NO MINIMIZATION WITH RESPECT TO C IS NEEDED.)
C
C  OR MSITER CAN BE USED AS A NON-LINEAR LEAST SQUARES CODE, WHERE C AND F
C  ARE CALCULATED DURING THE ITERATION PROCEDURE AS A NEW PARAMETERS
C  TAKING F0 AND THE C-VALUE OF THE ABOVE EQUATION AS FIRST ESTIMATES F1, C1.
C  (HERE ALSO MINIMIZATION WITH RESPECT TO C IS PERFORMED)
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C  IN THE MSITER CODE THE CROSS SECTIONS ARE NOT ADJUSTED. FOR THE
C  EVALUATION OF THE ITERATION EQUATIONS THE READER SHOULD USE THE
C  ORIGINAL LITERATURE . HERE, ONLY A FEW EQUATIONS NEEDED FOR
C  COMPILATION ARE REPRODUCED:
C
C  IF C1 AND F1 ARE THE RESULTS OF THE I-TH ITERATION, THE VALUES C
C  AND F OF THE I+1-TH ITERATION ARE GIVEN BY:
C     C = C1 + (HC*W*HC)**(-1) * HC*W * (A0-H1-HF(F0-F1)
C
C     F = F0 + KF0*HF*(W-W*T*W)*(A0-H1-HF(FO-F1))
C
C  WITH
C
C  HC = S0*F1
C  W IS THE INVERSE OF:     KA0 + C1*C1* (F0*KS0*F0 + S0*KF0*S0)
C  H1 = C1*S0*F1
C  HF = C1*S0
C
C  T IS A DYADIC MATRIX: COMPOSED OF HC AND HC:  T  = HC HC / (HC*W*HC)
C
C  (IT SHOULD BE MENTIONED THAT IN THE STAY'SL CODE FOR FIXED C IN
C  THE F-PART THE TERM CONTAINING T IS MISSING, WHICH IS CORRECT FOR KNOWN C).
C
C  THE RESULTING FLUENCE F IS COMPOSED OF C AND F:
C
C      PHI = C * F
C
C  WITH  R = HC*W*HC THE VARIANCE OF C CAN BE CALCULATED TO BE:
C
C       KC = 1/R
C
C AND THE COVARIANCE MATRIX OF THE FLUX DENSITY PHI CAN BE EVALUATED TO:
C
C KPHI = C*KF*C + F*KC*F - C*KF0*HF*W*HC*F/R - C*F*HC*W*HF*KF0/R
C
C WITH KF = KF0 - KF0*S0*(W-W*T*W)*S0*KF0, WHICH IS AGAIN THE STAY'SL RESULT
C IF THE T-TERM IS OMITTED.
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C COMMENT ON LINEAR ADJUSTMENT:
C IN LINEAR ADJUSTMENT ONLY THE FIRST STEP OF THE ITERATION PROCEDURE
C IS PERFORMED. IN THAT CASE ADJUSTMENT OF THE FLUX DENSITY IS NOT NEEDED
C WHEN AIMING AT INTEGRAL QUANTITIES LIKE TOTAL FLUX DENSITY OR DAMAGE.
C CONSIDERING E.G. THE MODEL EQATIONS A= DAM * ((S * F)/(D * F)), WHERE
C D(E) IS A DAMAGE CROSS SECTION, MINIMIZATION OF CHI**2 WITH RESPECT TO
C THE DAMAGE PARAMETER DAM, TO S AND F LEADS IN A LINEAR LEAST SQUARES
C APPROXIMATION TO
C        KA                             KA
C DAM =  S  KDAM**(-1)(I,J) * DD(J) /   S  KDAM**(-1)(I,J)
C       I=1                            I=1
C       J=1                            J=1
C
C WITH DD = A0/((S0 * F0)/(D * F0)), KDAM=DD*(COVREL(A0)+COVREL(DD))*DD
C COVREL(A0) AND COVREL(DD) ARE THE RELATIVE COVARIANCE MATRICES.
C
C ((S0 * F0)/(D * F0)) IS CALLED THE EFFECTIVE "CROSS SECTION".
C (SEE M. MATZKE: 7TH ASTM-EURATOM SYMPOSIUM STRASBOURG 1990.)
C
C*************************************************************************
C  THERE IS A SWITCH VARIABLE NSTAY TO TELL THE PROGRAM WHICH MODE THE USER
C  PREFERS:
C   NSTAY=0 : NON-LINEAR ITERATION, NORMALIZATION CONSTANT IS CALCULATED
C             IN EACH ITERATION,
C        =1 : STAYSL RUN WITH NORMALIZATION CONSTANT C=1,
C             (THIS MODE CAN ONLY BE USED IF THE ACTIVITIES AND THE
C             A PRIORI FLUX DENSITY ARE AT THE SAME REACTOR POWER LEVEL)
C        =2 : STAYSL RUN, C IS CALCULATED ONCE DUE TO STAY'SL
C
C
C
C INPUT FILES:
C       5  : TERMINAL OR FILE NAME (NAMED CON)
C            FOR USING INPUT FILE INSTEAD OF TERMINAL YOU HAVE TO
C            ASSIGN THE FILE TO CON
C FILE 20  : ACTIVITIES (REACTION RATES),
C FILE 39  : COVARIANCE MATRIX OF THE ACTIVITIES (OPTIONAL)
C FILE 15  : BINARY RESPONSE FUNCTIONS (CROSS SECTIONS)
C            IN SAND-II FORMAT E.G.OUTPUT FROM MFITIB AND UMSBIB
C FILE 38  : COVARIANCE MATRIX OF THE CROSS SECTIONS,
C            OUTPUT FROM A RUN OF THE PROGRAMS UNC33M, XSC33FM
C            (OPTIONAL)
C FILE 14  : FLUENCE FILE IN THE SPECIAL FORMAT
C            (OPTIONAL)
C FILE 28  : INPUT FLUENCE COVARIANCE MATRIX
C            (OPTIONAL)
C
C OUTPUT FILES:
C FILE  6  : TERMINAL OR PRINTER (NAME IS ASKED FROM INPUT)
C FILE 33  : FLUENCE FILE IN THE SPECIAL FORMAT (FLUENCE PER DE)
C FILE 34  : COVARIANCE MATRIX OF THE FLUENCE (BINARY)
C FILE 35  : SCRATCH
C FILE 36  : SCRATCH
C FILE 29  : PLOTTING FILE TO BE USED BY THE PROGRAM PLOT
C
C
C INPUT FROM TERMINAL OR FROM THE INPUT FILE:
C NAMES OF THE FILES
C
C***************************************************************************
C CONTENTS OF THE INPUT FILE (FORMAT-FREE)
C
C  LINE     CONTENT                         COMMENT
C===========================================================================
C    1       NAME OF PRINTER FILE           E.G. LPT1
C---------------------------------------------------------------------------
C    2       NAME OF THE ACTIVITY FILE      STRUCTURE SEE BELOW
C---------------------------------------------------------------------------
C    3       FACTOR TO BE MULTIPLIED WITH   IN STANDARD CASE: 1.0
C            THE ACTIVITIES
C---------------------------------------------------------------------------
C    4       IVAR                           SWITCH FOR AVAILABLE COVARIANCE
C                                           INFORMATION ON THE ACTIVITIES
C                IVAR=0     :               NO COVARIANCE AVAILABLE
C                IVAR=1     :               COVARIANCE IN A COVARIANCE FILE
C---------------------------------------------------------------------------
C  NEXT      NAME OF ACTIVITY COV. FILE     ONLY NEEDED FOR IVAR=1
C---------------------------------------------------------------------------
C  NEXT      NAME OF BINARY CROSS SECTION   E.G. OUTPUT FROM
C            FILE                           MFITIB
C---------------------------------------------------------------------------
C  NEXT      ICOVC                          SWITCH FOR AVAILABLE COVARIANCE
C                                           ON THE CROSS SECTIONS
C                ICOVC=0    :               NO COVARIANCE AVAILABLE
C                ICOVC=1    :               COVARIANCE IN A COVARIANCE FILE
C---------------------------------------------------------------------------
C  NEXT      NAME OF THE CROSS SECTION      ONLY NEEDED FOR ICOVC=1
C            COVARIANCE FILE                E.G. OUTPUT FROM UNC33M
C---------------------------------------------------------------------------
C  NEXT      IRAC                           SWITCH FOR AVAILABLE FLUENCE
C                                           INFORMATION
C                 IRAC=0    :               NOTHING KNOWN ABOUT THE FLUENCE
C                                           1/E SPECTRUM ASSUMED
C                 IRAC=1    :               MODERATED RECTOR SPECTRUM
C                 IRAC=2    :               PRE INFORMATION IN A FLUENCE FILE
C---------------------------------------------------------------------------
C  NEXT      NAME OF INPUT FLUENCE FILE     ONLY NEEDED FOR IRAC=2
C---------------------------------------------------------------------------
C  NEXT      IVARF                          SWITCH FOR AVAILABLE FLUENCE
C                                           COVARIANCE INFORMATION.
C                 IVARF=0   :               NO COVARIANCE INFORMATION ON THE
C                                           FLUENCE AVAILABLE,
C                                           READ STANDARD DEVIATION FROM
C                                           INPUT.
C                      =1   :               COVARIANCE INFORMATION ON FILE.
C                      =2   :               NO COVARIANCE INFORMATION, BUT
C                                           STANDARD DEVIATIONS TAKEN
C                                           FROM THE FLUENCE FILE 14.
C                                           FOR THE MODERATED FISSION
C                                           SPECTRUM UNCERTAINTIES ARE
C                                           CALCULATED USING A SIMPLE
C                                           PROBABILITY ARGUMENT.
C                      =3   :               NO COVARIANCE INFORMATION, BUT
C                                           RELATIVE STANDARD DEVIATIONS
C                                           TAKEN FROM THE INPUT FILE
C                                           TAPE5 (SEE BELOW).
C---------------------------------------------------------------------------
C  FOR IVARF=0:
C  NEXT      RELATIVE STANDARD DEVIATION    INPUT REL. STANDARD DEVIATION
C            IN %                           FOR ALL GROUPS THE SAME
C  FOR IVARF=1:
C  NEXT      NAME OF FLUENCE COVARIANCE     SPECIAL FORMAT, SEE PROGRAM
C            FILE                           UMSDAT
C---------------------------------------------------------------------------
C  FOR IVARF=3:
C                     DIAGONAL COVARIANCE MATRIX OF FLUX SHALL BE CONSTRUCTED
C                     GIVE IN ASCENDING ORDER:
C                     LEFT ENERGY IN MEV, % CONTRIBUTION OF STANDARD DEVIATION
C                     THE INTERVAL IS TAKEN FROM THIS ENERGY TO NEXT LEFT
C                     ENERGY OR TO THE RIGHT END OF THE WHOLE ENERGY RANGE ,IF
C                     ENERGY=0.0         LAST INPUT: 0.0,0.0
C
C  NEXT      LEFT ENERGY, %-CONTRIBUTION
C  AND FOLLOWING
C  NEXT      TERMINATE BY 0.0, 0.0
C---------------------------------------------------------------------------
C  NEXT      NAME OF OUTPUT FLUENCE FILE
C  NEXT      NAME OF OUTPUT UNFORMATTED
C            FLUENCE COVARIANCE FILE
C---------------------------------------------------------------------------
C  NEXT      NSTAY
C                    NSTAY=0 : NON-LINEAR ITERATION, NORMALIZATION CONSTANT IS
C                              CALCULATED IN EACH ITERATION,
C                         =1 : STAYSL RUN WITH NORMALIZATION CONSTANT C=1,
C                         =2 : STAYSL RUN, C IS CALCULATED ONCE DUE TO
C                              STAY'SL
C---------------------------------------------------------------------------
C  FOR NSTAY=0:
C  NEXT      IT                   IT=NUMBER IF ITERATIONS FOR THE
C                                 NON-LINEAR CASE.
C                                 TERMINATION OF THE PROGRAM, IF THE CHI**2
C                                 IN SUBSEQUENT ITERATIONS DOES NOT
C                                 CHANGE MORE THAN 1.0E-4
C---------------------------------------------------------------------------
C*****************************************************************************
C AN EFFECTIVE CROSS-SECTION, SIGEFF:
C
C         INTEGRAL(SIGI(E)*F(E)*DE)/INTEGRAL(SIGD(E)*F(E)*DE)
C
C WITH SIG(E) = CROSS SECTION OF REACTION NO. I,
C      SIGD(E)= CROSS SECTION OF A PSEUDO REACTION. E.G. A DAMAGE CROSS SECTION
C
C CAN ALSO BE CALCULATED. FOR THAT PURPOSE IN THE ACTIVITY FILE
C THE CODE NAME OF THE RELEVANT CROSS SECTION HAS TO BE GIVEN AS LAST LINE.
C SEE EXAMPLE BELOW.
C FROM SIGEFF THE CORRESPONDING INTEGRAL PARAMETER IS CALCULATED.
C GENERALLY THIS CALCULATION CAN BE PERFORMED WITHOUT UNFOLDING.
C SEE: M. MATZKE: PROCEEDINGS OF THE 7TH ASTM-EURATOM SYMPOSIUM.
C USING AS THE PSEUDO CROSS SECTION SIGD(E)=1.0, (PSEUDO CROSS SECTION
C FOR THE TOTAL FLUENCE (SEE PROGRAM MCROBI OR MRESBI)), THE EFFECTIVE
C CROSS SECTION EQUALS THE SPECTRUM AVERAGED CROSS SECTION.
C
C AFTER ADJUSTMENT THE PROGRAM ALSO PROVIDES INTEGRAL VALUES FOR REACTIONS OR
C PSEUDO REACTIONS. THE INFORMATION ON THAT IS TAKEN FROM THE ACTIVITY FILE.
C----------------------------------------------------------------------------
C IN ADDITION TO THE NAMES (REACTION CODES) OF THE MEASURED REACTIONS,
C IN THE ACTIVITY FILE THE NAMES OF THE PSEUDO REACTIONS (WHICH SHOULD
C BE CONTAINED IN THE BINARY CROSS SECTION FILE) ARE EXPECTED.
C*****************************************************************************
C
C     FORMAT OF THE ACTIVITY FILE NEEDED IN THIS PROGRAM:                  *
C     LINE 1: HEADLINE                                     20A4            *
C     LINE 2: KA,ISO                                  FORMAT-FREE          *
C             KA   : NUMBER OF REACTIONS                                   *
C                                                                          *
C     LINE 3 TO LINE KA+2:                                                 *
C     NAM1(I),NAM2(I),ACT1(I),SIG1(I)                                      *
C     FORMAT(2A4,E10.3,F10.3)                                              *
C                                                                          *
C     NAM1,NAM2:  CHARACTER*4 VALUES FOR THE                               *
C                 NAMES OF THE REACTIONS, THESE NAMES                      *
C                 SHOULD BE FOUND IN THE LIBRARY                           *
C                                                                          *
C     ACT1(I),SIG1(I)*100./ACT1(I):                                        *
C                 (REACTION RATE AND RELATIVE UNCERTAINTY)                 *
C                                                                          *
C                                                                          *
C     FURTHER LINES: NAMES OF INTEGRAL QUANTITIES                          *
C     TO BE CALCULATED                                                     *
C     LAST LINE:  NAME OF A REACTION FOR WHICH THE EFFECTIVE CROSS SECTION *
C                 AND THE INTEGRAL VALUE IS CALCULATED DIRECTLY            *
C---------------------------------------------------------------------------
C
C EXAMPLE OF AN ACTIVITY (OR REACTION RATE) FILE :
C    REAL88 **** PS1 **** ORNL POOLSIDE FAC., POSITION: SIMUL. SURV.
C        9                   COMMENT: 9 REACTIONS
C    U235F    1.382E-03     8.000    COMMENT: REACTION NAMES( REACTION CODE)
C    CO59G    3.818E-04     4.000
C    SC45G    5.864E-05     4.000
C    FE58G    5.219E-06     4.000
C    NP237F   7.096E-05     8.000
C    NI58P    2.264E-06     4.000
C    FE54P    1.541E-06     4.000
C    TI46P    2.190E-07     4.000
C    CU63A    1.076E-08     4.000
C    10                              COMMENT: 10 PSEUDO REACTIONS
C    ST-D-AST
C    FE-GP-H
C    FE-GP-HE
C    PHI-THER
C    PHI-INT*
C    PHI-0.1*
C    PHI-1.0*
C    PHI-TOT*
C    NI58P
C    CO59G
C    ST-D-AST                         COMMENT: FOR EFFECTIVE CROSS SECTION
C                                              AND DIRECT CALCULATION
C                                              OF THE DAMAGE PARAMETER
C**************************************************************************
C    EXAMPLE OF AN INPUT FILE:
C MSITERPR.PS1     COMMENT:  PRINTER FILE
C ACT.PS1                    ACTIVITY INPUT FILE
C 1.0                        FACTOR FOR MULTIPLICATION WITH ACTIVITIES
C 1                          COVARIANCE INFORMATION ON ACTS. AVAILABLE
C COVACT.PS1                 INPUT ACTIVITY COVARIANCE INFORMATION
C CROSS1BI.PS1               INPUT BINARY CROSS SECTION FILE
C 1                          COVARIANCE INFORMATION ON CROSS SECTION AVAILABLE
C COV.PS1                    CROSS SECTION COVARIANCE FILE
C 1                          PRE INFORMATION ON FLUENCE IN A FILE
C F1.PS1                     INPUT FLUENCE FILE
C 1                          COVARIANCE MATRIX ON FLUENCE AVAILABLE
C CF.PS1                     INPUT FLUENCE COVARIANCE FILE
C FSITER.PS1                 OUTPUT FLUX FILE
C CFSITER.PS1                OUTPUT FLUX COVARIANCE FILE
C 0                          ITERATION RUN
C 50                         NUMBER OF ITERATIONS
C*****************************************************************************
C
C
C THE PROGRAM USES A SUBROUTINE PLBILD TOGETHER WITH THE
C SCREEN SOFTWARE.
C
C
C USERS WITHOUT SCREEN SOFTWARE SHOULD INCLUDE A DUMMY ROUTINE
C PLBILD
C
C************************************************************************
C
C
      CHARACTER*4 HEADA(20),IREAC(30,2),KK3(19,2)
      CHARACTER*20 LISTE,LISTE1
      DOUBLE PRECISION ACT1,SIG1,COVA,ACT2,COV2,F1,F2
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(10,100)
      DATA LISTE/'              '/
C
C****************   OPEN INPUT FILE ************
C
      LISTE1=LISTE
      OPEN(5,FILE='CON')
C
C********************OPEN PRINTER FILE *******************
      WRITE(*,700)
  700 FORMAT(' GIVE NAME OF PRINTER FILE OR LPT1'/)
      READ(5,1000,END=1002,ERR=1002) LISTE1
 1002 CONTINUE
 1000 FORMAT(A20)
      OPEN(6,FILE=LISTE1)
C
      WRITE(6,1003)
 1003 FORMAT(' '//
     *'*************************************************************'/
     *' PROGRAM MSITER BY M. MATZKE, UPDATED 11-90                 *'//
     *' ************************************************************'/
     *' MODIFIED STAYSL-PROGRAM                                    *'/
     *' WITH SPECIAL NORMALIZATION                                 *'/
     *' NON LINEAR CALCULATION POSSIBLE                            *'/
     *' ************************************************************')
C
C**************** READ ACTIVITIES AND COVARIANCE *****************
      CALL RACTS(HEADA,IREAC)
C NOW COVA CONTAINS THE RELATIVE COVARIANCE MATRIX OF ACTIVITIES
C
C**************** READ CROSS SECTION AND COVARIANCE ***************
      CALL READS(ICOVC,IREAC,KK3)
C**************** READ OR ESTIMATE INPUT FLUX AND COVARIANCE ******
      CALL FLUSS1(IFLUSS,XNORMI)
C
C READ OUTPUT FILE INFORMATION:
      LISTE1=LISTE
      WRITE(*,1004)
 1004 FORMAT(' NAME OF SPECTRUM OUTPUT ABSOLUT FLUX-FILE'/)
      READ(5,1000,END=1005,ERR=1005) LISTE1
 1005 CONTINUE
C
      OPEN(33,FILE=LISTE1,STATUS='NEW',FORM='FORMATTED')
      WRITE(*,1006)
 1006 FORMAT(' NAME OF ABSOLUTE SPECTRUM OUTPUT COV-F-FILE?'/)
      READ(5,1000,END=1007,ERR=1007) LISTE
 1007 CONTINUE
C
      OPEN(34,FILE=LISTE,STATUS='NEW',FORM='UNFORMATTED')

      CALL STAYSL (HEADA,ICOVC,IREAC,KK3,XNORMI)
      WRITE(6,1008) LISTE1
 1008 FORMAT(' '/' NAME OF ABSOLUTE SPECTRUM OUTPUT FLUX-FILE ',A20)
C
      WRITE(6,1009) LISTE
 1009 FORMAT(' '/' NAME OF ABSOLUTE SPECTRUM OUTPUT COV-F-FILE: ',A20)

      WRITE(6,1010)
 1010 FORMAT(' '/' END OF CALCULATION '/72('-'))
C
      STOP
      END
C
C    ************************ *    A C T S    * ************************
      SUBROUTINE RACTS(HEADA,IREAC)
C ------READS ACTIVITY FILE AND COVARIANCE OF ACTIVITIES
      DIMENSION FELD(30),IFELD(1000)
      CHARACTER*20 LISTE,LISTE1 ,LISTE2
      CHARACTER*4 HEADA(20),HEAD1(20),IREAC(30,2)
      DOUBLE PRECISION ACT1,SIG1,COVA
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      DATA LISTE /'              '/
C
      LISTE1=LISTE
      LISTE2=LISTE
C ****************** OPEN ACTIVITY FILE 20 ****************+
      WRITE(*,1000)
 1000 FORMAT(' GIVE NAME OF ACTIVITY FILE'/)
      READ(5,500,ERR=1001,END=1001) LISTE
      WRITE(6,1002) LISTE
 1002 FORMAT(' '/70('-')/' INFORMATION ON INPUT ACTIVITIES:'/
     170('-')//
     1' INPUT ACTIVITY FILE: ',A20)
  500 FORMAT(A20)
 1001 OPEN(20,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
C
C READ ACTIVITIES
      READ(20,1003,ERR=7777,END=7777) HEADA
 1003 FORMAT(20A4)
      WRITE(6,1004) HEADA
 1004 FORMAT(' '/' HEADLINE ACTIVITY FILE:'/' '/' ',20A4//)
      READ(20,*,END=7777,ERR=7777) KA
      DO 23 I=1,KA
      READ(20,1011,ERR=7777,END=7777) IREAC(I,1),IREAC(I,2),XH1,XH2
      ACT1(I)=DBLE(XH1)
  23  SIG1(I)=DBLE(XH2)
C SIG1(I) IS GIVEN IN %
 1011 FORMAT(2A4,E10.3,F10.3)
 7777 CONTINUE
C MULTIPLICATION BY FACTA
      WRITE(*,1006)
 1006 FORMAT(' GIVE FACTOR FOR MULTIPLICATION WITH ACTIVITIES'/)
      READ(5,*) FACTA
      WRITE(6,1007) FACTA
 1007 FORMAT(' ALL ACTIVITIES ARE MULTIPLIED BY :',1P,E12.4/)
C NOW ACTIVITIES ARE READ IN
C WRITE ACTIVITIES:
C
      WRITE(6,1008)
 1008 FORMAT(72('-')/' INPUT REACTIONS WITH STANDARD DEVIATIONS:'/)
      DO 30 I=1,KA
      ACT1(I)=ACT1(I)*FACTA
      XH1=SNGL(ACT1(I))
      XH2=SNGL(SIG1(I)*ACT1(I))
      XHILF=SNGL(SIG1(I))
C CONVERT TO RELATIVE STANDARD DEVIATION
      SIG1(I)=SIG1(I)/100.
   30 WRITE(6,1009) I,IREAC(I,1),IREAC(I,2),XH1,XH2,XHILF
 1009 FORMAT(' ',I4,2X,2A4,1P,E12.4,2X,'+-',1P,E12.4,2X,' +-',0P,
     *F8.3,'%')
C
C ************** READ INFORMATION ON COVARIANCE MATRIX OF ACTIVITIES **
C
      WRITE(*,1020)
 1020 FORMAT(' GIVE IVAR FOR THE INFORMATION OF AVAILABLE '/
     *' COVARIANCE INFORMATION'/
     *' IVAR=0 : NO COVARIANCE INFORMATION ON THE ACTIVITIES'/
     *'     =1 : COVARIANCE INFORMATION ON FORMATTED FILE, '/
     *'          NAME OF THIS FILE IS ASKED LATER'/
     *' GIVE IVAR !'/)
      READ(5,*) IVAR
      IF(IVAR.EQ.0) GOTO 2000
C************ COVARIANCE INFORMATION AVAILABLE:
C************ OPEN COVARIANCE FILE
      WRITE(*,1021)
 1021 FORMAT(' GIVE NAME OF ACTIVITY FORMATTED COVARIANCE FILE'/)
      READ(5,500,END=1022,ERR=1022) LISTE1
 1022 OPEN(39,FILE=LISTE1,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,1023) LISTE1
 1023 FORMAT(/72('-')/' COVARIANCE MATRIX OF ACTIVITIES FROM: ',A20/)
C
C INPUT ACTIVITY COVARIANCE
      READ(39,1003,END=8888,ERR=8888) HEAD1
      WRITE(6,1024) HEAD1
 1024 FORMAT(' '/' HEADLINE CORRELATION FILE:'/' '/' ',20A4)
      READ(39,*,END=8888,ERR=8888) KAC
      IF(KAC.NE.KA) WRITE(6,1025) KA,KAC
 1025 FORMAT(' ','KAC.NE. KA     KA,KAC:',2I5)
      IHILF1=1
      IHILF2=KAC
C READ RELATIVE STANDARD DEVIATIONS TIMES 100 FROM FILE 20
      READ(39,3000,END=8888,ERR=8888) (FELD(I),I=IHILF1,IHILF2)
 3000 FORMAT(10(8E10.3/))
C
      DO 39 I=1,KA
      FELD(I)=FELD(I)/100.
   39 SIG1(I)=DBLE(FELD(I))
C
C LOWER TRIANGEL OF CORRELATION MATRIX*1000 IS READ IN IFELD(I)
      NR1=KA+1
      NRU=(KA*NR1)/2
      READ(39,1026,ERR=8888,END=8888) (IFELD(I),I=1,NRU)
 1026 FORMAT(16I5)
      IL=1
      IH=KA
      DO 40 I=1,KA
      DO 50 K=1,KA
C CONVERT TO RELATIVE COVARIANCE MATRIX
      IJU=I+(K*K-K)/2
      IF(I.GT.K) IJU=K+(I*I-I)/2
      COVA(I,K)=IFELD(IJU)*SIG1(I)*SIG1(K)/1000.D0
   50 CONTINUE
   40 CONTINUE
      CLOSE(39)
      GOTO 1027
C
C ******************* COVARIANCE MATRIX DIAGONAL:
 2000 CONTINUE
      DO 51 I=1,KA
      DO 52 J=1,KA
   52 COVA(I,J)=0.0
   51 COVA(I,I)=SIG1(I)*SIG1(I)
C
C WRITE COVARIANCE MATRIX
 1027 WRITE(6,1028)
 1028 FORMAT(/72('-')/
     1' RELATIVE COVARIANCE MATRIX OF INPUT ACTIVITIES:'/)
      CALL PMAX1(KA,COVA,ACT1,40,0)
      RETURN
 8888 WRITE(6,1029)
 1029 FORMAT(' ERROR IN READING COVARIANCE-FILE OF ACTIVITIES')
      STOP
      END
C*****************************************************************
C  READ CROSS SECTIONS AND ITS COVARIANCE:
      SUBROUTINE READS(ICOVC,IREAC,KK3)
      CHARACTER*4 KK1(30,2),KK2(30,4),CN1,CN2,KK3(19,2)
     *,KK4(19,4),IREAC(30,2)
      DIMENSION FEHL(100)
      CHARACTER*4 IFOIL1,IFOIL2
      CHARACTER*20 LISTE,LISTE1
      LOGICAL OK
      DOUBLE PRECISION ACT1,SIG1,COVA,ACT2,COV2,F1,F2,TB(100)
C
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(10,100)
      DATA LISTE1 /'              '/
C*******************OPEN CROSS SECTION FILE******************
      LISTE=LISTE1
      WRITE(*,1227)
 1227 FORMAT(' NAME OF FILE 15, BINARY CROSS SECTION FILE'/
     1'  (E.G. CROSSBIN ?'/)
      READ(5,2000,END=117,ERR=117) LISTE
 2000 FORMAT(A20)
  117 CONTINUE
      OPEN(15,FILE=LISTE,STATUS='OLD',FORM='UNFORMATTED')
      WRITE(6,8107) LISTE
 8107 FORMAT(72('-')//
     *' BINARY CROSS SECTION INPUT FILE:  ',A20)
C*************************************************************
C THE FOLLOWING PART IS FROM THE PROGRAM FITOCO
C*************************************************************
      READ(15) MPL1
      M=MPL1-1
      KG=M
      READ(15) (EL(I),I=1,MPL1)
      READ(15) NCOV
      NOVER=4+2*NCOV
      IF(NCOV.EQ.0) GOTO 4331
      DO 9 I=1,NCOV
      READ(15) NCOVE
    9 READ(15) (DUMMY,J=1,M)
 4331 CONTINUE
      READ(15) NFOIL
      OK=.TRUE.
      NF=0
      DO 100 I=1,KA
      IFOIL1=IREAC(I,1)
      IFOIL2=IREAC(I,2)
      CALL SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
C
      BACKSPACE 15
      BACKSPACE 15
      IF(.NOT.OK) GOTO 100
      READ(15) (KK1(I,K1),K1=1,2),(KK2(I,K1),K1=1,4)
      READ(15) CLAM,CN1,CN2,MAT,MT
      READ(15) (CROSS(I,K1),K1=1,M)
  100 CONTINUE
C    READ DAMAGE NAMES
      CALL DOSNAM(KK3)
      DO 233 I=1,KDAM
      IFOIL1=KK3(I,1)
      IFOIL2=KK3(I,2)
      CALL SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
C
      BACKSPACE 15
      BACKSPACE 15
      IF(.NOT.OK) GOTO 233
      READ(15) (KK3(I,K1),K1=1,2),(KK4(I,K1),K1=1,4)
      READ(15) CLAM,CN1,CN2,MAT,MT
      READ(15) (CROSSD(I,K1),K1=1,M)
  233 CONTINUE
      CLOSE(15)
      KG=M
C READ CROSS SECTION COVARIANCE FILE:
      WRITE(*,3381)
 3381 FORMAT(' GIVE ICOVC FOR THE INFORMATION OF AVAILABLE '/
     *' COVARIANCE INFORMATION OF THE CROSS SECTIONS'/
     *' ICOVC=0 : NO COVARIANCE INFORMATION ON THE X-SECTIONS'/
     *'      =1 : COVARIANCE INFORMATION ON FORMATTED FILE, '/
     *'          NAME OF THIS FILE IS ASKED LATER'/
     *' GIVE ICOVC !'/)
      READ(5,*) ICOVC
      IF(ICOVC.EQ.0) GOTO 7287
      WRITE(*,7336)
 7336 FORMAT(' GIVE NAME OF FORMATTED COVARIANCE FILE OF X-SECTIONS'/)
      LISTE=LISTE1
      READ(5,2000,END=7337,ERR=7337) LISTE
 7337 OPEN(38,FILE=LISTE,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,3385) LISTE
 3385 FORMAT(' '/' COVARIANCE MATRIX OF X-SECTIONS FROM: ',A20//)
C
C OPEN SCRATCH FILE
      OPEN(35,STATUS='SCRATCH',FORM='UNFORMATTED')
C
C READ CROSS SECTION COVARIANCE
      DO 10 I=1,KA
      READ(38,1333,END=88,ERR=88) IFOIL1,IFOIL2,MAT,MT,IDU,IL,IH
 1333 FORMAT(2A4,2X,5I5)
C
      DO 15 K1=IL,IH
      IL1=IL
      READ(38,1001,END=88,ERR=88) (FEHL(K2),K2=IL,IH)
 1001 FORMAT(8E10.3)
      IF(K1.EQ.IL) THEN
          IF(FEHL(IL).EQ.0.0) IL1=IL1+1
          NANZ=IH-IL1+1
          WRITE(35) NANZ,IL1,IH
      END  IF
      IF(K1.EQ.IL.AND.IL1.NE.IL) GOTO 15
C CONVERT TO ABSOLUTE COVARIANCE MATRIX DOUBLE PRECISION
      DO 13 K2=IL1,IH
   13 TB(K2)=DBLE(FEHL(K2))*DBLE(CROSS(I,K1))*CROSS(I,K2)
      WRITE(35) (TB(K2),K2=IL1,IH)
   15 CONTINUE
   10 CONTINUE
C
      CLOSE(38)
      REWIND 35
      RETURN
 7287 WRITE(6,7288)
 7288 FORMAT(' '/' NO COVARIANCE INFORMATION ON CROSS SECTIONS'/
     *' AVAILABLE (ICOVC=0)'/)
      RETURN
  88  WRITE(6,5288)
 5288 FORMAT(' ERROR READING CROSS SECTION COVARIANCE FILE'/)
      STOP
      END
C*****************************************************************
      SUBROUTINE FLUSS1(IFLUSS,XNORMI)
      CHARACTER*4 HEAD(20)
      CHARACTER*20 LISTE,LISTE1
      DIMENSION FELD(100),IFELD(10000),EF(101)
      DOUBLE PRECISION ACT1,SIG1,COVA,ACT2,COV2,F1,F2,TB(100),COVEFF
     *,G1,G2,GEWI,BACT1,RHILF,BACTF,CSKFS,DSUM1,DSUM2,DSUM,DXH1,DXH2
C
      COMMON /CIVI/ G1(100),G2(100),GEWI(30,100),BACT1(30)
     *,RHILF(100,100),BACTF(30),CSKFS(40,40),COVEFF(30,30)
      COMMON /ERG/ACT2(40),COV2(40),F1(100),F2(100)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      DATA LISTE /'              '/
C
C***** READ SPECTRUM INFORMATION FROM INPUT FILE:
C
      WRITE(6,998)
  998 FORMAT(/72('-'))
      MPL1=KG+1
      WRITE(*,1000)
 1000 FORMAT(' '/
     *' NOTHING KNOWN ABOUT SPECTRUM      : IRAC=0'/
     *' MODERATED REACTOR SPECTRUM        : IRAC=1'/
     *' PRE INFORMATION SPECTRUM IN A FILE: IRAC=2'/
     *' GIVE IRAC'/)
      READ(5,*) IRAC
      IF(IRAC.EQ.0) THEN
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C ************** IRAC=0**** 1/E SPECTRUM ASSUMED *********
      WRITE(6,1001)
 1001 FORMAT(' '/' ********* ARBITRARY SPECTRUM, 1/E USED'/)
C
      DSUM=0.0D0
      DO 10 I=1,KG
      F1(I)=DBLE(ALOG(EL(I+1)/EL(I)))
      DSUM=DSUM+F1(I)
C RELATIVE STANDARD DEVIATION 100% ASSUMED:
      F2(I)=1.0
   10 CONTINUE
      END IF
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      IF(IRAC.EQ.1) THEN
C IRAC=1: (MODERATED REACTOR SPECTRUM)
      WRITE(6,1002)
 1002 FORMAT(' '/' ********** MODERATED REACTOR SPECTRUM'/)
C
C FILL REACTOR SPECTRUM
C
      DSUM=0.0D0
      DO 20 I=1,KG
      XHILF=SQRT(EL(I+1)*EL(I))
      TB(I)=SQRT(XHILF)*DEXP(-DBLE(XHILF)/1.29)*(EL(I+1)-EL(I))
   20 DSUM=DSUM+TB(I)
C NORMALIZE FISSION SPECTRUM
      DO 21 I=1,KG
   21 TB(I)=TB(I)/DSUM
C
      DSUM1=0.0D0
      DO 22 I=1,KG
      DSUM=TB(I)
      DO 23 J=I,KG
   23 DSUM=DSUM+TB(J)*DBLE(ALOG(EL(I+1)/EL(I)))
      F1(I)=DSUM
C 100% UNCERTAINTY:
      F2(I)=F1(I)
      DSUM1=DSUM1+F1(I)
   22 CONTINUE
      DSUM=DSUM1
C TB(I): FISSION SPECTRUM GROUP VALUES
C F1(I): MODERATED FISSION SPECTRUM, GROUP VALUES
      END IF
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      IF(IRAC.EQ.2) THEN
C** IRAC =2 (SPECTRUM FROM INPUT FILE)
C OPEN INPUT FILE ****++++++++++++++++ READ FLUENCE INPUT+++
      LISTE1=LISTE
      IFLUSS=1
      WRITE(*,1003)
 1003 FORMAT(' NAME OF SPECTRUM INPUT FILE?'/)
      READ(5,1004,END=1005,ERR=1005) LISTE1
 1004 FORMAT(A20)
 1005 CONTINUE
      WRITE(6,1006) LISTE1
 1006 FORMAT(' '/' NAME OF SPECTRUM INPUT FILE: ',A20)
C
      OPEN(14,FILE=LISTE1,STATUS='OLD',FORM='FORMATTED')
      READ(14,1007,END=1008,ERR=1008) HEAD
 1007 FORMAT(20A4)
 1008 WRITE(6,1009) HEAD
 1009 FORMAT(' '/' HEADLINE INPUT FLUENCE FILE 14: '/' ',20A4/)
      READ(14,*) MODE,MEV
      IF(MODE.EQ.0) THEN
      WRITE(6,1010) MODE
 1010 FORMAT(' NO GROUP AVERAGES AS INPUT, MODE=',I5)
      STOP
      END IF
      READ(14,*) IL,IH,KG1,EDUM
      IF(KG1.NE.KG) THEN
      WRITE(6,1011) KG1,KG
 1011 FORMAT(' NUMBER KG1 OF GROUPS IN FLUX FILE NOT EQUALS KG'
     1,' KG1=',I5,' KG=',I5/)
      STOP
      END IF
      EL(MPL1)=EDUM
      IF(MEV.EQ.0) EL(MPL1)=EL(MPL1)*1.0E-6
      DO 30 I=1,KG
      READ(14,*) EL(I),X1,X2
      F1(I)=DBLE(X1)
      F2(I)=DBLE(X2)
      IF(MEV.EQ.0) EL(I)=EL(I)*1.0E-6
   30 CONTINUE
C
      DSUM=0.0
      DO 31 I=1,KG
      IF(MODE.EQ.1) THEN
      F1(I)=F1(I)*(EL(I+1)-EL(I))
      F2(I)=F2(I)*(EL(I+1)-EL(I))
      END IF
      DSUM=DSUM+F1(I)
   31 CONTINUE
      CLOSE(14)
C+++++NOW FLUENCE FILE IS READ IN F1(I)=GROUP FLUXES
C                                 F2(I) STANDARD DEVIATION
C
      END IF
C NORM OF INPUT FLUENCE:
      XNORMI=SNGL(DSUM)
C NOW F1=FLUX IS FILLED
C
C COVARIANCE OF F1:
C
C OPEN SCRATCH FILE
      OPEN(36,STATUS='SCRATCH',FORM='UNFORMATTED')
      IL=1
      IH=KG
      WRITE(36) KG,IL,IH
C
C
C******************** READ COVARIANCE INFORMATION *****
      WRITE(*,1020)
 1020 FORMAT(' GIVE IVARF FOR THE INFORMATION OF AVAILABLE '/
     *' COVARIANCE INFORMATION'/
     *' IVARF=0 : NO COVARIANCE INFORMATION ON THE FLUENCE'/
     *'      =1 : COVARIANCE INFORMATION ON FORMATTED FILE, '/
     *'           NAME OF THIS FILE IS ASKED LATER'/
     *'      =2 : NO COVARIANCE INFORMATION, BUT ERRORS TAKEN'/
     *'           FROM THE FLUENCE FILE.'/
     *'           FOR THE MODERATED FISSION SPECTRUM:'/
     *'           TAKE THE CALCULATED VALUES'/
     *'      =3 : NO COVARIANCE INFORMATION, BUT ERRORS TAKEN'/
     *'           FROM TERMINAL INPUT (SEE BELOW)'/
     *' GIVE IVARF !'/)
      READ(5,*) IVARF
C
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C NO COVARIANCE INFORMATION AVAILABLE:
      IF(IVARF.EQ.0) THEN
      WRITE(*,1021)
 1021 FORMAT(' NO COVARIANCE AVAILABLE, COVARIANCE MATRIX TAKEN AS',
     1' DIAGONAL'/' WITH X.XX % CONTRIBUTION.   GIVE X.XX '/)
      READ(5,*) XX
      XX=XX*1.0E-2
      DO 50 I=1,KG
      DO 51 J=1,KG
   51 TB(J)=0.0D0
      TB(I)=DBLE(XX*XX)
   50 WRITE(36) (TB(K),K=1,KG)
      GOTO 1748
      END IF
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      IF(IVARF.EQ.1) THEN
C IVARF=1 : READ COVARIANCE VALUES:
C COVARIANCE OF INPUT FLUENCE
      WRITE(*,1030)
 1030 FORMAT(' GIVE NAME OF FORMATTED COVARIANCE FILE OF FLUENCE'/)
      LISTE1=LISTE
      READ(5,1004,END=1031,ERR=1031) LISTE1
 1031 OPEN(28,FILE=LISTE1,STATUS='OLD',FORM='FORMATTED')
      WRITE(6,1032) LISTE1
 1032 FORMAT(' '/' COVARIANCE MATRIX OF FLUENCE FROM: ',A20/)
C
C
      READ(28,1033,END=8888,ERR=8888) HEAD
 1033 FORMAT(20A4)
      WRITE(6,1034) HEAD
 1034 FORMAT(' HEADLINE FLUENCE COVARIANCE FILE:'/' ',20A4)
      READ(28,*,END=8888,ERR=8888) KGF
      WRITE(6,1035) KGF
 1035 FORMAT(' '/' NUMBER OF GROUPS FROM COVARIANCE-FILE: ',I4/)
      MPF=KGF+1
      READ(28,2000,END=8888,ERR=8888) (EF(I),I=1,MPF)
 2000 FORMAT(8E10.3)
C READ RELATIVE STANDARD DEVIATION TIMES 100
      READ(28,2000,END=8888,ERR=8888) (FELD(I),I=1,KGF)
C
      DO 60 I=1,KGF
   60 FELD(I)=FELD(I)/100.
C BINARY OUTPUT OF RELATIVE COVARIANCE MATRIX
      NR1=MPF
      NRU=(NR1*KGF)/2
      READ(28,2099) (IFELD(I),I=1,NRU)
 2099 FORMAT(16I5)
C IFELD:  LOWER TRINGLE OF CORRELATION MATRIX TIMES 1000
      DO 61 I=1,KGF
      DO 62 K=1,KGF
      IJU=I+(K*K-K)/2
      IF(I.GT.K) IJU=K+(I*I-I)/2
   62 TB(K)=DBLE(FELD(I)*IFELD(IJU)*FELD(K))/1000.0
   61 WRITE(36) (TB(K),K=1,KGF)
      CLOSE(28)
C  NOW IN THE SCRATCH FILE THERE IS THE RELATIVE COVARIANCE MATRIX
      GOTO 1748
      END IF
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      IF(IVARF.EQ.2.AND.IRAC.NE.1) THEN
      DO 70 I=1,KG
      DO 71 J=1,KG
   71 TB(J)=0.0D0
      TB(I)=F2(I)*F2(I)
   70 WRITE(36) (TB(K),K=1,KG)
      GOTO 1748
      END IF
      IF(IVARF.EQ.2.AND.IRAC.EQ.1) THEN
C
C++++++++++++IRAC=1, CALCULATE COVARIANCE MATRIX FOR MODERATED FISSION
      DO 40 I=1,KG
      DXH1=DBLE(EL(I+1)-EL(I))
      DO 41 J=1,KG
      DXH2=DBLE(EL(J+1)-EL(J))
      DSUM=0.0D0
      DO 42 I1=I,KG
      DO 42 J1=J,KG
      IF(I1.NE.J1) GOTO 42
      DXH3=DXH1
      DXH4=DXH2
      IF(I.EQ.I1) DXH3=DXH3+1.0D0
      IF(J.EQ.I2) DXH4=DXH4+1.0D0
C
      DSUM=DSUM+TB(I1)*TB(J1)*DXH3*DXH4
  42  CONTINUE
  41  F2(J)=DSUM/(F1(I)*F1(J))
  40  WRITE(36) (F2(K),K=1,KG)
      GOTO 1748
      END IF
C
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C NO FLUX COVARIANCE AVAILABLE:
      IF(IVARF.EQ.3) THEN
      WRITE(*,2141)
 2141 FORMAT(' IFLUX=1 AND ICOVF=0 AND IVARF=3'/
     *' DIAGONAL COVARIANCE MATRIX OF FLUX SHALL BE CONSTRUCTED'/
     *' GIVE IN ASCENDING ORDER:'/
     *' LEFT ENERGY IN MEV, % CONTRIBUTION OF STANDARD DEVIATION'/
     *' THE INTERVAL IS TAKEN FROM THIS ENERGY TO NEXT LEFT ENERGY'/
     *' OR TO THE RIGHT END OF THE WHOLE ENERGY RANGE ,IF ENERGY=0.0'/
     *' LAST INPUT: 0.0,0.0 '/)
C
      I1=0
   80 I1=I1+1
      READ(5,*) EF(I1),FELD(I1)
      IF(EF(I1).NE.0.0.AND.FELD(I1).NE.0.0) GOTO 80
      IF(EF(I1).EQ.0.0) EF(I1)=EL(MPL1)
C TRANSFORMATION OF UNCERTAINTIES
      I2=I1-1
      IF(EF(1).GT.EL(1)) EF(1)=EL(1)
C
      SUM1=0.0
      DO 81 I=1,KG
      SUM=0.0
      DO 82 J=1,I2
      IF(EF(J).GE.EL(I+1)) GOTO 83
      IF(EF(J+1).LE.EL(I)) GOTO 82
      EMIN=AMAX1(EF(J),EL(I))
      EMAX=AMIN1(EF(J+1),EL(I+1))
      FRAC=(EMAX-EMIN)
      SUM=SUM+FRAC*FELD(J)
   82 CONTINUE
   83 CONTINUE
      SUM=(SUM/100.0)/(EL(I+1)-EL(I))
   81 F2(I)=SUM
C
      DO 84 I=1,KG
      DO 85 K=1,KG
   85 TB(K)=0.0D0
      TB(I)=F2(I)*F2(I)
   84 WRITE(36) (TB(K),K=1,KG)
      END IF
C*********************** IVARF=3 FINISHED****
C
 1748 REWIND 36
C PRINT INPUT DATA
      DSUM=0.0D0
      DSUM1=0.0D0
      DSUM2=0.0D0
      READ(36) KGF,IL,IH
      WRITE(6,6262)
 6262 FORMAT(72('-')/
     1' INPUT NORMALIZED SPECTRAL FLUENCE AND STANDARD DEVIATION:'//
     1'    ENERGY     SPECTRAL               UNCERTAINTY',7X,' F(E)*E'/
     1'               FLUENCE         RELATIVE     ABSOLUTE'/)
      DO 90 I=1,KGF
   90 DSUM=DSUM+F1(I)
      XNORMI=SNGL(DSUM)
      DO 91 I=1,KGF
   91 F1(I)=F1(I)/DSUM
      XBET=0.0
      DO 92 I=1,KGF
      READ(36) (TB(K),K=1,KGF)
      DO 93 K=1,KGF
   93 DSUM2=DSUM2+TB(K)*F1(I)*F1(K)
      DSUM1=DSUM1+TB(I)*F1(I)*F1(I)
      XHILF=SNGL(DSQRT(DABS(TB(I)))*100.0D0)
      XHILF1=SNGL(F1(I)/(EL(I+1)-EL(I)))
      XHILF4=SNGL(F1(I)/ALOG(EL(I+1)/EL(I)))
      XHILF2=XHILF*XHILF1/100.
   92 WRITE(6,6261) EL(I),XHILF1,XHILF,XHILF2,XHILF4
 6261 FORMAT(' ',1P,E12.4,E12.4,' +- ',0P,F7.3,'%','  +-',1P,2E12.3)
      REWIND 36
      WRITE(6,7621) DSUM
 7621 FORMAT(/' NORM OF INPUT FLUENCE: ',1P,D12.4,
     1' NORMALIZED TO 1.0'/)
      XBET=SQRT(SNGL(DSUM2))
      XHILF=XBET*100.0
      WRITE(6,6621) DSUM1,DSUM2,XHILF
      XNORMI=SNGL(DSUM)
 6621 FORMAT(' '/
     *' TRACE OF FLUENCE COVARIANCE MATRIX : ',1P,D12.5/
     *' SUM OVER ROWS AND COLUMNS          : ',D12.5//
     *' REL. UNCERTAINTY OF INPUT FLUENCE  : ',0P,F10.3,' %'/)
      RETURN
 8888 WRITE(*,8889)
 8889 FORMAT(' ERROR READING COVARIANCE FLUENCE FILE'/)
      STOP
      END
C
C
C**************************************************************
      SUBROUTINE STAYSL(HEADA,ICOVC,IREAC,KK3,XNORMI)
C
      CHARACTER*8 IREAC1(30)
      CHARACTER*20 TEXT,COM
      CHARACTER*4 HEADA(20),IREAC(30,2),KK3(19,2)

C
      DIMENSION  YPLOT1(101),YPLOT2(101)
C
      DOUBLE PRECISION ACT1,SIG1,COVA,ACT2,COV2,F1,F2
     *,G1,G2,GEWI,BACT1,DSUM,RHILF,BACTF,COUT1,DSUM1
     *,CSKFS,COVAS(40,40),COUT2,DCHI1,DCHI2,WW(40,40)
     *,XX(30),YY(30),RR,SS,DXHILF,DCOUT2
     *,TB(100),BACT2(30),COVEFF
      COMMON /CIVI/ G1(100),G2(100),GEWI(30,100),BACT1(30)
     *,RHILF(100,100),BACTF(30),CSKFS(40,40),COVEFF(30,30)
C
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(10,100)
C
C F1(I)  : INPUT FLUENCE NORMALIZED TO 1.0
C XNORMI : NORM OF INPUT FLUENCE
C
C SCRATCH FILE 36 : RELATIVE COVARIANCE MATRIX OF F1 (INPUT FLUENCE)
C ACT1(I) : INPUT ACTIVITIES
C COVA(I,J) : RELATIVE COVARIANCE MATRIX OF INPUT ACTIVITIES
C CROSS, CROSSD : CROSS SECTIONS
C SCRATCH FILE 35 : ABSOLUTE COVARIANCE MATRIX OF CROSS SECTIONS
C
C CALCULATE GEWI=COV(FLUX)*CROSS
      CALL GEWCAL
C NOW IN RHILF THERE IS THE ABSOLUTE COVARIANCE MATRIX OF F1
C
C NOW GEWI,BACTF AND CSKFS IS FILLED
C GEWI(I,J)=SUM(RR(I,K)*CROSS(J,K))
C BACTF ARE THE ACTIVITIES WITH THE NORMALIZED INPUT FLUENCE
C CSKFS IS THE FLUENCE PART OF THE COVARIANCE MATRIX OF ACTIVITIES
C CSKFS: ABSOLUTE COVARIANCE MATRIX
C PRINT INPUT CALCULATED ACTIVITIES USING XNORMI
      WRITE(6,3210)
 3210 FORMAT(' '/' REACTION EVENTS FROM INPUT FLUENCE'/
     *' WITH UNCERTAINTIES RESULTING FROM INPUT FLUENCE COVARIANCE'/
     *' '/
     *' IF THE INPUT FLUENCE IS NOT NORMALIZED TO THE LEVEL OF THE'/
     *' ACTIVITIES, MEASURED AND CALCULATED VALUES MAY DIFFER'//
     *'  I   REACTION    MEASURED   CALCULATED   STAND. DEV.(%)'/
     *'                                                       '/)
      DO 3211 I=1,KA
      XHILF1=XNORMI*BACTF(I)
      XHILF2=XNORMI*DSQRT(DABS(CSKFS(I,I)))*100.0/XHILF1
      WRITE(6,2866) I,IREAC(I,1),IREAC(I,2),ACT1(I),XHILF1,XHILF2
 3211 CONTINUE
C
C
C FILL G1
      DO 7113 I=1,KG
 7113 G1(I)=F1(I)
C CALCULATE EFFECTIVE CROSS SECTIONS
C CALCULATE THE EFFECTIVE CROSS SECTION USING F1
C AND THE DAMAGE PARAMETER CONSIDERED.
C THE RESULT IS CORRECT IN THE SENSE OF LINEAR LEAST SQUARES.
         CALL EFFCAL(KK3,ICOVC,IREAC)
C NOW COVEFF IS FREE FOR FURTHER USE
C
C CALCULATE COUT1
C FIRST: INVERS OF COVAS, NOTE: COVA IS RELATIVE COV. MATRIX
      DO 5166 I=1,KA
C SET IREAC1
      IREAC1(I)(1:4)=IREAC(I,1)
      IREAC1(I)(5:8)=IREAC(I,2)
      BACT1(I)=BACTF(I)
      DO 5166 J=1,KA
      COVA(I,J)=COVA(I,J)*ACT1(I)*ACT1(J)
      COVAS(I,J)=COVA(I,J)
 5166 CONTINUE
C NOW COVA IS ABSOLUTE COVARIANCE MATRIX
C IN BACT1 THERE IS THE FIRST ESTIMATE
C INVERT COVAS
      CALL MATRIX(COVAS,KA,40)
C DECIDE MODUS OF RUN
      WRITE(*,3100)
 3100 FORMAT(' '/
     *' NSTAY=0 : ITERATION, NORMALIZATION CONSTANT IS CALCULATED'/
     *'            IN EACH ITERATION'/
     *'      =1 : STAYSL RUN WITH C=1, YOU MUST BE SURE THAT'/
     *'           THE ACTIVITIES AND THE INPUT FLUENCE ARE AT THE'/
     *'           SAME POWER LEVEL'/
     *'      =2 : STAYSL RUN, C IS CALCULATED ONCE'/
     *' GIVE NSTAY'/)
      READ(5,*) NSTAY
      IF(NSTAY.EQ.1) THEN
      COUT=1.
      COUT1=DBLE(COUT)
      ELSE
      DSUM=0.0D0
      DSUM1=DSUM
      DO 5335 I=1,KA
      DO 5335 J=1,KA
      DSUM=DSUM+BACTF(I)*COVAS(I,J)*ACT1(J)
      DSUM1=DSUM1+BACTF(I)*COVAS(I,J)*BACTF(J)
 5335 CONTINUE
      COUT1=DSUM/DSUM1
      COUT=SNGL(COUT1)
      END IF
      IT1=0
      IF(NSTAY.EQ.0) THEN
        WRITE(*,4338)
 4338   FORMAT(' GIVE NUMBER OF ITERATIONS'/)
        READ(5,*) IT
      ELSE
        IT=1
      END IF
C
C--------------------------------------------------------------------
  998 CONTINUE
      IT1=IT1+1
C
C CALCULATE THE WEIGHTING MATRIX
C CALCULATE ITS INVERS IN WW
      IF(IT1.EQ.IT.AND.NSTAY.EQ.0) WRITE(6,7798)
 7798 FORMAT(/72('-')/' RESULTS FOR THE LAST ITERATION:')
      CALL WCAL(WW,ICOVC,COUT1,IT1,IT)
      IF(IT1.EQ.1) THEN
         WRITE(6,2265)
 2265    FORMAT(//72('-')/)
C WRITE
         IF(NSTAY.EQ.0) WRITE(6,*) 'NON-LINEAR ITERATION RUN:'
         IF(NSTAY.EQ.1) WRITE(6,*) 'STAY-SL RUN WITH C = 1.0'
         IF(NSTAY.EQ.2) WRITE(6,*) 'STAY-SL RUN, C CALCULATED ONCE'
         WRITE(6,7286) NSTAY,COUT
 7286    FORMAT(/' NSTAY=',I4/' COUT1 USED HERE: ',1P,E12.4/
     1' COUT1: NORMALIZATION FACTOR FOR THE FIRST ITERATION'/)
       END IF
C
      IF(IT1.NE.IT) WRITE(6,9158) IT1
 9158 FORMAT(/72('*')/
     *' ITERATION NO.: ',I4/)
C
C MATRIX INVERSE OF WW
      CALL MATRIX(WW,KA,40)
C
      RR=0.0D0
      SS=RR
      DO 467 I=1,KA
      DSUM=0.0D0
      DSUM1=0.0D0
      DO 468 J=1,KA
      DXHILF=WW(I,J)
      DSUM=DSUM+DXHILF*(ACT1(J)-COUT1*(BACTF(J)-BACT1(J)))
  468 DSUM1=DSUM1+DXHILF*BACT1(J)
      XX(I)=DSUM
      YY(I)=DSUM1
      RR=RR+DSUM1*BACT1(I)
  467 SS=SS+DSUM*BACT1(I)
C CALCULATE COUT2
      IF(NSTAY.EQ.0) THEN
      COUT2=SS/RR
      DCOUT2=1.0/RR
      XHILF1=SNGL(DSQRT(DCOUT2))
      XHILF2=XHILF1*100./SNGL(COUT2)
C PRINT COUT AND UNCERTAINTY
      WRITE(6,2298) COUT2,XHILF1,XHILF2
 2298 FORMAT(/' NORMALIZATION FACTOR:'/
     *' C   =',1P,D12.4/
     *'    +-',E12.4,
     *'    +-',0P,F12.2,'%')
C
      ELSE
      COUT2=COUT1
      DCOUT2=0.0
      END IF
C CALCULATE G2
      DO 483 I=1,KG
      DSUM=0.0D0
      DO 484 J=1,KA
  484 DSUM=DSUM+GEWI(J,I)*(XX(J)-COUT2*YY(J))
  483 G2(I)=F1(I)+COUT1*DSUM
C CALCULATE NEW BACT2
      DO 488 I=1,KA
      DSUM=0.0D0
      DO 485 J=1,KG
  485 DSUM=DSUM+CROSS(I,J)*G2(J)
  488 BACT2(I)=DSUM
C CALCULATE CHI2
      DCHI2=0.0D0
      DO 486 I=1,KA
      DO 486 J=1,KA
  486 DCHI2=DCHI2+(ACT1(I)-COUT2*BACT2(I))*WW(I,J)*(ACT1(J)-
     *COUT2*BACT2(J))
C
      IF(IT1.EQ.1.OR.IT1.EQ.IT) THEN
C       PRINT MEASURED AND PRECALCULATED VALUES
        WRITE(6,2865) COUT2
 2865 FORMAT(' '/' NORMALIZATION FACTOR C IS ITERATED IF NSTAY=0'/
     1' PRESENT VALUE C=',1P,D12.4//
     *'  I   REACTION    MEASURED   CALCULATED   DIFFERENCE(%)'/
     *'                             USING C  '/)
        DO 47 I=1,KA
        XHILF1=SNGL(BACT2(I)*COUT2)
        XHILF2=(SNGL(ACT1(I))-XHILF1)*100./SNGL(ACT1(I))
        WRITE(6,2866) I,IREAC(I,1),IREAC(I,2),ACT1(I),XHILF1,XHILF2
 2866   FORMAT(' ',I4,2X,2A4,1P,2E12.4,0P,F12.4)
   47   CONTINUE
      END IF
      CHI=SNGL(DCHI2/KG)
      WRITE(6,7334) CHI
 7334 FORMAT(/' CHI-VALUE FOR ACTIVITY DIFFERENCES: '/
     1' CHI=',1P,E12.4,' PER DEGREE OF FREEDOM'/)
C
C FILL YPLOT1,YPLOT2
      MPL1=KG+1
      DO 510 I=1,KG
      YPLOT1(I)=SNGL(G1(I)/(EL(I+1)-EL(I)))
      YPLOT2(I)=SNGL(G2(I)/(EL(I+1)-EL(I)))
  510 CONTINUE
C FILL G1
      DO 7761 I=1,KG
 7761 G1(I)=G2(I)
      DO 8761 I=1,KA
 8761 BACT1(I)=BACT2(I)
      COUT1=COUT2
      COM(1:14)='FLUX PER DLNE '
      IF(IT1.EQ.1) THEN
         TEXT(1:20)='INPUT FLUX          '
      ELSE
          WRITE(TEXT(1:14),7738) ITM1
      END IF
      CALL PLBILD(EL,YPLOT1,YPLOT1,MPL1,-2,1,1,1.0,0,TEXT,COM,1)
      ITM1=IT1
      IF(IT1.LT.IT) THEN
        WRITE(TEXT(1:14),7738) IT1
      ELSE
        TEXT(1:14)='LAST RUN      '
      END IF
 7738 FORMAT('RUN NO.:  ',I4)
      CALL PLBILD(EL,YPLOT2,YPLOT1,MPL1,0,1,1,1.0,1,TEXT,COM,1)
C
      IF(IT1.NE.1) THEN
        DSUM1=DABS(DCHI2/DCHI1-1.0D0)
        IF(DSUM1.LT.1.0D-4.AND.IT1.LT.(IT-1)) IT1=IT-1
      END IF
      DCHI1=DCHI2
      IF(IT1.NE.IT) GOTO 998
C
C CALCULATE COVARIANCE MATRIX OF G2
C
C FIRST CALCULATE W**-1 - W**-1 * T * W**-1 IN COVEFF
C NOTE: IN COVA THERE IS THE ABSOLUTE COVARIANCE MATRIX
      DO 570 I=1,KA
      DO 570 J=1,KA
  570 COVEFF(I,J)=WW(I,J)-YY(I)*YY(J)/RR
C
      DO 583 I=1,KG
      DO 583 J=1,KG
      DSUM=0.0D0
      DO 584 L1=1,KA
      DO 584 L2=1,KA
      IF(NSTAY.EQ.0) THEN
      DSUM=DSUM+GEWI(L1,I)*COVEFF(L1,L2)*GEWI(L2,J)
      ELSE
      DSUM=DSUM+GEWI(L1,I)*WW(L1,L2)*GEWI(L2,J)
      END IF
  584 CONTINUE
      RHILF(I,J)=-COUT2*COUT2*DSUM+RHILF(I,J)
C FOR NSTAY.NE.0 CALCULATE THE ABSOLUTE COV. MATRIX OF THE OUTPUT FLUENCE:
      IF(NSTAY.NE.0) RHILF(I,J)=RHILF(I,J)*COUT2*COUT2
  583 CONTINUE
C
C CALCULATE COVARIANCE OF PHI
      IF(NSTAY.EQ.0) THEN
      DO 683 I=1,KG
      DSUM=0.0D0
      DO 684 J=1,KA
  684 DSUM=DSUM+GEWI(J,I)*YY(J)
  683 F2(I)=DSUM
      END IF
C NOW IN F2 IS GEWI*YY
C
      DO 985 I=1,KG
      IF(NSTAY.EQ.0) THEN
      DO 685 J=1,KG
      DXHILF=COUT2*COUT2*RHILF(I,J)+G2(I)*G2(J)/RR
     *-COUT2*COUT2*(G2(I)*F2(J)+G2(J)*F2(I))/RR
  685 RHILF(I,J)=DXHILF
      END IF
      IVOR=1
      IF(RHILF(I,I).LT.0.0) IVOR=-1
  985 F1(I)=IVOR*DSQRT(DABS(RHILF(I,I)))
C NOW IN F1 THERE IS THE STANDARD DEVIATION OF PHI
C
C CALCILATE PHI
      DO 700 I=1,KG
      DXHILF=F1(I)
      F1(I)=G2(I)*COUT2
  700 F2(I)=DXHILF
C F1 IS THE OUTPUT FLUENCE, F2 IS THE STANDARD DEVIATION
C CALCULATE NEW ACTIVITY VALUES IN COV2
      DO 736 I=1,KA
      COV2(I)=0.0
      DO 736 J=1,KG
  736 COV2(I)=COV2(I)+CROSS(I,J)*F1(J)
C
C CALCULATE NEW CHI**2
      CHI=0.0
      DO 547 I=1,KA
      DO 547 J=1,KA
      CHI=CHI+(ACT1(I)-COV2(I))*WW(I,J)*(ACT1(J)-COV2(J))
  547 CONTINUE
      CHI=CHI/KG
      WRITE(6,8334) CHI,KG
 8334 FORMAT(' '/' CHI-VALUE OUTPUT',
     *' (AFTER ADJUSTMENT OF THE  ACTIVITIES): '/
     1' WITH  C       :    NORMALIZATION FACTOR,'/
     1' ACT(I)        :    MEASURED ACTIVITIES,'/
     1' B(I)   = SUM (CROSS(I,L) * G(L))'/
     1' G(J)          :    ADJUSTED FLUENCE.'//
     1' CHI**2 = SUM (ACT(I)-C*B(I)) * WW(-1)(I,J) * (ACT(J)-C*B(J))'//
     1' WW(-1)        :    INVERSE OF WEIGHTING MATRIX.'//
     1' CHI**2=',1P,E12.4,' PER DEGREE OF FREEDOM (',I4,')'//)
      IL=1
      IH=KG
      WRITE(34) KG,IL,IH
      DO 850 I=1,KG
      DO 851 J=1,KG
  851 TB(J)=RHILF(I,J)
  850 WRITE(34) (TB(J),J=1,KG)
C
      WRITE(6,5930)
 5930 FORMAT(' '/' RESULTS:')
      WRITE(6,5555)
 5555 FORMAT(' '/' ',5X,'      EL    ','FLUX PER DE ',' GROUP FLUX  ',
     1'  PER DLNE        +-'//)
      REWIND 33
      WRITE(33,6429) HEADA
 6429 FORMAT(20A4)
      ILLL=1
      IHHH=KG
      MODE=1
      MEV=1
      WRITE(33,*) MODE,MEV
      WRITE(33,*) ILLL,IHHH,KG,EL(MPL1)
      SUM2=0.0
      SUMP=0.0
      DO 733 I=1,KG
      SUM2=SUM2+SNGL(F1(I))
 5347 FORMAT(' ',3(E12.6,',  '))
      XHILF1=SNGL(F1(I)/(EL(I+1)-EL(I)))
      YPLOT1(I)=XHILF1
      XHILF2=SNGL(F2(I)/(EL(I+1)-EL(I)))
      YPLOT2(I)=XHILF2
      WRITE(33,5347) EL(I),XHILF1,XHILF2
      XHILF2=SNGL(F1(I))
      XHILF4=SNGL(F2(I)*100.0/F1(I))
      XHILF3=SNGL(F1(I)/ALOG(EL(I+1)/EL(I)))
  733 WRITE(6,734) I,EL(I),XHILF1,XHILF2,XHILF3,XHILF4
  734 FORMAT(' ',I4,E12.4,1P,E12.4,E12.4,E12.4,0P,F10.2,'%',2X)
      TEXT(1:20)='OUTPUT FLUX         '
      COM(1:20)='FINAL RESULT        '
      CALL PLBILD(EL,YPLOT1,YPLOT2,MPL1,-2,-1,1,1.0,1,TEXT,COM,1)
C
      WRITE(6,899) SUM2
  899 FORMAT(//' ',/' NORM (PHI-OUT) OF THE FLUENCE =',1P,E12.4//)
C
C NOW IN COV2 THERE ARE THE NEW ACTIVITIES, IN COVA THERE IS THE
C ABSOLUTE COVARIANCE OF INPUT ACTIVITIES, IN SIGEFF THERE IS
C W**-1 - W**-1 * T * W**-1
      CALL CONTF(KK3,IREAC)
      RETURN
      END
C***********************************************
      SUBROUTINE GEWCAL
      DOUBLE PRECISION ACT1,SIG1,COVA,ACT2,COV2,F1,F2
     *,G1,G2,GEWI,BACT1,DSUM,RHILF,BACTF,TB(100)
     *,CSKFS,COVEFF
      COMMON /CIVI/ G1(100),G2(100),GEWI(30,100),BACT1(30)
     *,RHILF(100,100),BACTF(30),CSKFS(40,40),COVEFF(30,30)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      DO 10 I=1,KA
      DSUM=0.0D0
      DO 11 J=1,KG
   11 DSUM=DSUM+DBLE(CROSS(I,J))*F1(J)
   10 BACTF(I)=DSUM
C FILL GEWI=COV(F1)*CROSS AND CSKFS=CROSS*COV(F1)*CROSS
C IN RHILF : ABSOLUTE COVARIANCE MATRIX OF INPUT FLUENCE
      REWIND 36
      READ(36) KG,IL,IH
      DO 7033 I=1,KG
      READ(36) (TB(J),J=1,KG)
      DO 2038 J=1,KG
 2038 RHILF(I,J)=TB(J)*F1(I)*F1(J)
      DO 2035 L1=1,KA
      DSUM=0.0D0
      DO 2034 J=1,KG
 2034 DSUM=DSUM+RHILF(I,J)*DBLE(CROSS(L1,J))
 2035 GEWI(L1,I)=DSUM
 7033 CONTINUE
C
      DO 2041 I=1,KA
      DO 2041 J=1,KA
      DSUM=0.0D0
      DO 2042 K=1,KG
 2042 DSUM=DSUM+GEWI(I,K)*DBLE(CROSS(J,K))
 2041 CSKFS(I,J)=DSUM
      WRITE(6,1000)
 1000 FORMAT(72('-')/' COVARIANCE MATRIX OF ACTIVITIES'/
     *' INPUT FLUENCE PART:'/)
      CALL PMAX1(KA,CSKFS,BACTF,40,1)
      RETURN
      END
C**************************************************************
      SUBROUTINE WCAL(WW,ICOVC,COUT1,IT1,IT)
C NOTE: IN COVA THERE IS THE ABSOLUTE COVARIANCE MATRIX
      DOUBLE PRECISION WW(40,40)
     *,ACT1,SIG1,COVA
     *,G1,G2,GEWI,BACT1,RHILF,BACTF
     *,CSKFS,COUT1,TB(100),COVEFF
      COMMON /CIVI/ G1(100),G2(100),GEWI(30,100),BACT1(30)
     *,RHILF(100,100),BACTF(30),CSKFS(40,40),COVEFF(30,30)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
C
C ADD  THE CROSS SECTION PART TO WW
      IF(ICOVC.EQ.0) GOTO 401
C     READ COVARIANCE MATRIX OF CROSS SECTION AND CALCULATE
C     CROSS SECTION CONTRIBUTION
      REWIND 35
      DO 16 I=1,KA
      DO 16 J=1,KA
      DXHILF=0.0D0
C NO CROSS CORRELATIONS IN CROSS SECTION COVARIANCE
      IF(I.NE.J) GOTO 16
      READ(35) NANZ,IL,IH
      DO 14 K=IL,IH
      READ(35) (TB(L),L=IL,IH)
      DO 13 L=IL,IH
   13 DXHILF=DXHILF+TB(L)*G1(L)*G1(K)
   14 CONTINUE
   16 WW(I,J)=DXHILF
C
      IF(IT1.EQ.1.OR.IT1.EQ.IT) THEN
        WRITE(6,3001)
 3001   FORMAT(72('-')/
     1' COVARIANCE MATRIX OF ACTIVITIES, CROSS SECTION PART:'/
     1' (CALCULATED WITH THE ACTUAL FLUENCE VALUES)'/)
        CALL PMAX1(KA,WW,BACT1,40,1)
      END IF
  401 CONTINUE
C ADD FLUX-PART AND ACTIVITY PART
      DO 10 I=1,KA
      DO 10 J=1,KA
      IF(ICOVC.EQ.0) THEN
        WW(I,J)=COVA(I,J)+COUT1*COUT1*CSKFS(I,J)
      ELSE
        WW(I,J)=COVA(I,J)+COUT1*COUT1*(CSKFS(I,J)+WW(I,J))
      END IF
  10  CONTINUE
C
      IF(IT1.NE.1.AND.IT1.NE.IT) RETURN
C   PRINT MATRICES
      WRITE(6,3000)
 3000 FORMAT(72('-')/
     *' WEIGHTING MATRIX WW OF ACTIVITIES :'/
     *' (CALCULATED WITH THE ACTUAL FLUENCE AND THE ACTUAL NORMALI',
     *'ZATION CONSTANT)'/
     1' WITH  C       :  NORMALIZATION FACTOR,'/
     1' COVA(I,J)     :  COVARIANCE MATRIX OF MEASURED ACTIVITIES,'/
     1' COVF(L,M)     :  COVARIANCE MATRIX OF ACTUAL FLUENCE,'/
     1' COVS(I,J,L,M) :  COVARIANCE MATRIX OF CROSS SECTIONS,'/
     1' F(L)          :  ACTUAL FLUENCE,'/
     1' CROSS(I,L)    :  CROSS SECTION FOR REACTION I,'///
     1' WW(I,J)=COVA(I,J)+C*C*SUM(CROSS(I,L)*COVF(L,M)*CROSS(J,M)'/
     1'                          +F(L)*COVS(I,J,L,M)*F(M))'//
     1'                           (SUM OVER L, M)'//
     1' VALUES OF THE WEIGHTING MATRIX:'/)
      CALL PMAX1(KA,WW,ACT1,40,1)
      RETURN
      END
C***********************************************
      SUBROUTINE CONTF(KK3,IREAC)
C
      CHARACTER*4 IREAC(30,2),KK3(19,2)
      DOUBLE PRECISION ACT1,SIG1,COVA,ACT2,COV2,F1,F2,DACT2(40)
     *,G1,G2,GEWI,BACT1,RHILF,BACTF,CSKFS,COVEFF,DSUM,TB
      DIMENSION IDRU(100,100),TB(100)
      COMMON /CIVI/ G1(100),G2(100),GEWI(30,100),BACT1(30)
     *,RHILF(100,100),BACTF(30),CSKFS(40,40),COVEFF(30,30)
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(10,100)
C
C NOW IN COV2 THERE ARE THE NEW ACTIVITIES, IN COVA THERE IS THE
C ABSOLUTE COVARIANCE OF INPUT ACTIVITIES, IN SIGEFF THERE IS
C W**-1 - W**-1 * T * W**-1
C
C PRINT COVARIANCE OF NEW FLUENCE
      WRITE(6,2336)
 2336 FORMAT(' '/' OUTPUT COVARIANCE OF FLUENCE:'/)
C
      DO 331 I=1,KG
  331 TB(I)=DSQRT(DABS(RHILF(I,I)))
      DO 393 I=1,KG
      DO 393 J=1,KG
      IDRU(I,J)=0
      IF(TB(I).NE.0.0D0.AND.TB(J).NE.0.0D0) IDRU(I,J)
     *=IDINT(100.0D0*RHILF(I,J)/(TB(I)*TB(J))+0.04D0)
  393 CONTINUE
      WRITE(6,1000)
 1000 FORMAT(' '/' CORRELATION MATRIX:'//
     *'  I  STANDARD  ','   CORRELATION COEFFICIENTS TIMES 100'/
     *' ','    DEVIATION'//)
      DO 395 I=1,KG
      XHILF=SNGL(TB(I))*100.0
      XHILF=XHILF/F1(I)
  395 WRITE(6,2099) I,XHILF,(IDRU(I,J),J=1,I)
 2099 FORMAT(' ',I2,F7.2,' %   ',16I4/4(15X,16I4/))
C
C
C PRINT ADJUSTED ACTIVITIES WITH COVARIANCE MATRIX
C
C CALCULATE THE UNCERTAINTY IN CSKFS
      DO 10 I=1,KA
      DO 10 J=1,KA
      DSUM=0.0D0
      DO 11 L1=1,KA
      DO 11 L2=1,KA
   11 DSUM=DSUM+COVA(I,L1)*COVEFF(L1,L2)*COVA(L2,J)
   10 CSKFS(I,J)=COVA(I,J)-DSUM
      WRITE(6,12)
   12 FORMAT(//72('-')/'  FINAL RESULTS OF ADJUSTED ACTIVITIES:'//
     *' '//'     I',14X,'MEASURED   SIGMA(%)',
     *'  CALCULATED  SIGMA(%)  DIFF-ACT (%)'/)
C
      DO 13 I=1,KA
      IVOR=1
      XHILF=SNGL(CSKFS(I,I))
      IF(XHILF.LT.0.0) IVOR=-1
      XHILF=SQRT(ABS(XHILF))*IVOR
      XHILF2=XHILF*100.0/SNGL(COV2(I))
C IN SIG1 THERE ARE THE RELATIVE STANDARD DEVIATIONS
      XHILF1=SNGL(SIG1(I)*100.)
      XHILF9=SNGL((ACT1(I)-COV2(I))*100.0/ACT1(I))
      WRITE(6,1400) I,IREAC(I,1),IREAC(I,2),ACT1(I),XHILF1
     *,COV2(I),XHILF2,XHILF9
   13 CONTINUE
      WRITE(6,14)
   14 FORMAT(/' COVARIANCE MATRIX OF THE ADJUSTED ACTIVITIES:'/)
      CALL PMAX1(KA,CSKFS,COV2,40,1)
C
C
      KA1=KA+KDAM
      DO 20 I=1,KA1
      ACT2(I)=0.0D0
      DACT2(I)=0.0D0
      DO 21 L1=1,KG
      IF (I.LE.KA) THEN
      XHILF=CROSS(I,L1)
      ELSE
      IHILF=I-KA
      XHILF=CROSSD(IHILF,L1)
      END IF
  21  ACT2(I)=ACT2(I)+XHILF*F1(L1)
  20  CONTINUE
C
      DO 30 L1=1,KA1
      DO 32 L2= L1,KA1
      COVA(L1,L2)=0.0D0
      DO 31 M1=1,KG
      IF (L1.LE.KA) THEN
      XHILF1=CROSS(L1,M1)
      ELSE
      IHILF=L1-KA
      XHILF1=CROSSD(IHILF,M1)
      END IF
      DO 31 M2=1,KG
      IF (L2.LE.KA) THEN
      XHILF2=CROSS(L2,M2)
      ELSE
      IHILF1=L2-KA
      XHILF2=CROSSD(IHILF1,M2)
      END IF
      COVA(L1,L2)=XHILF1*RHILF(M1,M2)*XHILF2+COVA(L1,L2)
   31 CONTINUE
   32 CONTINUE
      DACT2(L1)=DSQRT(DABS(COVA(L1,L1)))
   30 CONTINUE
C
C WRITE ACTIVITIES AND COVARIANCE MATRIX
      DO 40 L1=1,KA1
      DO 41 L2=L1,KA1
      COVA(L2,L1)=COVA(L1,L2)
      IDRU(L1,L2)=DINT(COVA(L1,L2)*100./(DACT2(L1)*DACT2(L2))+0.5D0)
   41 IDRU(L2,L1)=IDRU(L1,L2)
   40 CONTINUE
C
C
      WRITE(6,6434)
 6434 FORMAT(' '/72('=')/' FINAL RESULTS OF ACTIVITIES:'//
     *' '/' (FOR THE FOLLOWING RESULTS ONLY THE COVARIANCE MATRIX'/
     *' OF THE OUTPUT FLUENCE IS TAKEN INTO ACCOUNT)'/
     *' THAT MEANS: IN THE OUTPUT UNCERTAINTY OF THE ACTIVITIES'/
     *' THE CROSS SECTION UNCERTAINTIES AND THE COVARIANCE MATRIX'/
     *' BETWEEN CROSS SECTION AND OUTPUT FLUENCE ARE NEGLECTED'/
     *' '//'     I',14X,'MEASURED   SIGMA(%)',
     *'  CALCULATED  SIGMA(%)  DIFF-ACT (%)'/)
C
      DO 411 I=1,KA1
      IF(I.LE.KA) THEN
      XHILF2=SNGL(DACT2(I)*100./ACT2(I))
C IN SIG1 THERE ARE THE RELATIVE STANDARD DEVIATIONS
      XHILF1=SNGL(SIG1(I)*100.)
C
      XHILF9=SNGL((ACT1(I)-ACT2(I))*100.0/ACT1(I))
      WRITE(6,1400) I,IREAC(I,1),IREAC(I,2),ACT1(I),XHILF1
     *,ACT2(I),XHILF2,XHILF9
      ELSE
      IHILF=I-KA
      XHILF1=SNGL(DACT2(I)*100./ACT2(I))
      WRITE(6,2400) I,KK3(IHILF,1),KK3(IHILF,2),ACT2(I),XHILF1
      END IF
  411 CONTINUE
 1400 FORMAT(' ',I5,2X,2A4,1P,D12.4,2X,0P,F7.3,1P,D12.4,2X,0P,
     *2F9.3)
 2400 FORMAT(' ',I5,2X,2A4,21X,1P,D12.4,2X,0P,F9.3)
C
      WRITE(6,2000)
 2000 FORMAT(' '//' CORRELATION MATRIX'//
     *'  I',11X,'UNCERTAINTY (%)      CORRELATION MATRIX*100'/)
C
      DO 50 I=1,KA1
      XHILF=SNGL(DACT2(I)*100./ACT2(I))
      IF(I.LE.KA) THEN
      WRITE(6,4000) I,IREAC(I,1),IREAC(I,2),XHILF,(IDRU(I,J),J=1,I)
      ELSE
      IHIL=I-KA
      XHILF=SNGL(DACT2(I)*100./ACT2(I))
      WRITE(6,4000) I,KK3(IHIL,1),KK3(IHIL,2),XHILF,(IDRU(I,J),J=1,I)
      END IF
  50  CONTINUE
 4000 FORMAT(' ',I3,2X,2A4,F8.2,2X,13I4/' ',23X,13I4/' ',23X,13I4)
C
      RETURN
      END
C******************************************
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      SUBROUTINE SEARCH(IFOIL1,IFOIL2,NFOIL,NF,NOVER,OK)
      LOGICAL OK,AGAIN
      CHARACTER*4 IFOIL1,IFOIL2,INF1,INF2,F2(4)
      AGAIN=.TRUE.
      IF(NF.EQ.NFOIL)GO TO 5
    1 READ(15)INF1,INF2,F2
      NF=NF+1
      IF (INF1.EQ.IFOIL1.AND.INF2.EQ.IFOIL2) GOTO 2
      READ(15)
      READ(15)
      IF (NF.LT.NFOIL) GOTO 1
      IF (.NOT.AGAIN) GOTO 4
    5 AGAIN=.FALSE.
      NF=0
      REWIND 15
      DO 3 I=1,NOVER
    3 READ(15)
      GOTO 1
    2 READ(15)
      OK=.TRUE.
      RETURN
  4   OK=.FALSE.
      WRITE(6,1000) IFOIL1,IFOIL2
 1000 FORMAT(' REACTION ',2A4,'   NOT ON CROSS SECTION FILE')
      RETURN
      END
C***********************************************
C***********************************************************
      SUBROUTINE DOSNAM(KK3)
C READ DOS-NAMES
      CHARACTER*4 IBL,KK3(19,2)
      COMMON /DAM/ KDAM,CROSSD(10,100)
      DATA IBL/'    '/
C
C READ NUMBER OF DOSE REACTIONS
      READ(20,*) KDAM
      DO 10 I=1,KDAM
      KK3(I,1)=IBL
      KK3(I,2)=IBL
      READ(20,1000,END=999,ERR=999) KK3(I,1),KK3(I,2)
 1000 FORMAT(2A4)
  999 CONTINUE
   10 CONTINUE
C READ INFORMATION FOR SIG.EFF
      IWEIT1=KDAM+1
      READ(20,1000,END=20,ERR=20) KK3(IWEIT1,1),KK3(IWEIT1,2)
   20 CONTINUE
      RETURN
      END
C************************************************************
      SUBROUTINE PMAX1(KA,AP,ACT,KNUMB,MOD)
C MOD=0   AP IS RELATIVE COVARIANCE MATRIX
C MOD=1   AP IS ABSOLUTE COVARIANCE MATRIX, ACT ARE THE MEASURED VALUES
      DOUBLE PRECISION AP,TB,ACT
      DIMENSION AP(KNUMB,KNUMB),TB(100),ACT(KNUMB)
      DIMENSION IP(100,100)
      DO 11 I=1,KA
   11 TB(I)=DSQRT(DABS(AP(I,I)))
      DO 13 I=1,KA
      DO 13 J=1,KA
      IP(I,J)=0
      IF(TB(I).NE.0.0D0.AND.TB(J).NE.0.0D0) IP(I,J)
     *=IDINT(100.0D0*AP(I,J)/(TB(I)*TB(J))+0.04D0)
   13 CONTINUE
      WRITE(6,1000)
 1000 FORMAT(' '/' CORRELATION MATRIX:'//
     *'  I  STANDARD  ','   CORRELATION COEFFICIENTS TIMES 100'/
     *' ','    DEVIATION'//)
      DO 15 I=1,KA
      XHILF=SNGL(TB(I))*100.0
      IF(MOD.EQ.1) XHILF=XHILF/ACT(I)
   15 WRITE(6,2000) I,XHILF,(IP(I,J),J=1,I)
 2000 FORMAT(' ',I2,F7.2,' %   ',16I4/4(15X,16I4/))
      RETURN
      END
C***************************************************************************
      SUBROUTINE SCALEX (A,B,KA,IDIM)
      DOUBLE PRECISION A(IDIM,IDIM),B(40)
      DO 1 I=1,KA
      B(I)=A(I,1)
      DO 1 J=2,KA
      IF (B(I).GT.A(I,J)) GO TO 1
      B(I)=A(I,J)
 1    CONTINUE
      DO 2 I=1,KA
      DO 2 J=1,KA
 2    A(I,J)=A(I,J)/B(I)
      RETURN
      END
      SUBROUTINE RESCAL (A,B,KA,IDIM)
      DOUBLE PRECISION A(IDIM,IDIM),B(40)
      DO 1 I=1,KA
      DO 1 J=1,KA
 1    A(I,J)=A(I,J)/B(J)
      RETURN
      END
      SUBROUTINE PIVOT (S,N,IDIM)
      DIMENSION NC(40), NR(40)
      DOUBLE PRECISION S(IDIM,IDIM), BIG, AIJ, TEMP
      DO 457 I = 1, N
      NC(I) = 0
  457 NR(I) = 0
      DO 600 KEEP = 1, N
      BIG = 0.0D0
      DO 500 NS = 1, N
      IF (NR(NS)) 500, 460, 500
  460 AIJ = 0.0D0
      NX = 1
      DO 480 K = 1, N
      IF (DABS(S(NS,K)) - AIJ) 480, 480, 470
  470 IF (NC(K)) 480,475, 480
  475 AIJ = DABS(S(NS,K))
      NX = K
  480 CONTINUE
      IF (AIJ - BIG) 500, 500, 490
  490 BIG = AIJ
      I = NS
      J = NX
  500 CONTINUE
      IF (BIG - 1.0D-8) 710, 710, 510
  510 L = 0
  515 L = L + 1
      IF (L -J) 520, 515, 520
  520 IF (L -N) 530, 530, 540
  530 S(I,L) = -S(I,L)/S(I,J)
      GO TO 515
  540 CONTINUE
      S(I,J) = 1.0D0/S(I,J)
      K = 0
  550 K = K + 1
      IF (K - I) 555, 550, 555
  555 IF (K - N) 560, 560, 590
  560 L = 0
  565 L = L + 1
      IF (L - J) 570, 565, 570
  570 IF (L - N) 575, 575, 580
  575 S(K,L) = S(K,L) + S(I,L)*S(K,J)
      GO TO 565
  580 CONTINUE
  585 S(K,J) = S(K,J)*S(I,J)
      GO TO 550
  590 CONTINUE
      NR(I) = J
      NC(J) = I
  600 CONTINUE
      DO 660 NY = 1,N
      DO 660 K = 1, N
      IF (NY - NR(K)) 630, 610, 630
  610 NR(K) = NR(NY)
      NR(NY) = NY
      DO 620 NV = 1, N
      TEMP = S(NY,NV)
      S(NY,NV) = S(K,NV)
  620 S(K,NV) = TEMP
  630 CONTINUE
      IF (NY - NC(K)) 660, 640, 660
  640 NC(K)  = NC(NY)
      NC(NY) = NY
      DO 650 NV = 1, N
      TEMP = S(NV,NY)
      S(NV,NY) = S(NV,K)
  650 S(NV,K) = TEMP
  660 CONTINUE
      GO TO 700
  710 N = 0
  700 CONTINUE
      RETURN
      END
C**************************************************************
      SUBROUTINE MATRIX(AP,KA,IDIM)
      DOUBLE PRECISION B(40),AP(IDIM,IDIM)
C
      CALL SCALEX(AP,B,KA,IDIM)
      KD=KA
      CALL PIVOT(AP,KD,IDIM)
      IF(KD.NE.0) GOTO 34
      WRITE(6,1000) KD
 1000 FORMAT(' MATRIXINVERSION FAILS, KD=',I5)
      STOP
   34 CONTINUE
      CALL RESCAL(AP,B,KA,IDIM)
C
      RETURN
      END
C*******************************************************************
      SUBROUTINE EFFCAL(KK3,ICOVC,IREAC)
      CHARACTER*4 KK3(19,2)
      CHARACTER*4 IREAC(30,2)
C
      DOUBLE PRECISION ACT1,SIG1,COVA,ACT2,COV2,F1,F2
     *,TB(100),SUMZ(30),SUMN,SIGEFF(30)
     1,COVEFF,COVFFC(30,30),DXHILF,DXH1
     *,G1,G2,GEWI,BACT1,RHILF,BACTF
     *,CSKFS
      COMMON /CIVI/ G1(100),G2(100),GEWI(30,100),BACT1(30)
     *,RHILF(100,100),BACTF(30),CSKFS(40,40),COVEFF(30,30)
C
      COMMON/ACTS/ ACT1(40),SIG1(40),COVA(40,40),KA,ILC,IHC
      COMMON /SIGS/ KG,EL(101),CROSS(30,100)
      COMMON /ERG/ ACT2(40),COV2(40),F1(100),F2(100)
      COMMON /DAM/ KDAM,CROSSD(10,100)
C
      IWEIT1=KDAM+1
C LOCATE DAMAGE NAME
      IDAM=0
      DO 12 J=1,KDAM
      IF(KK3(J,1).EQ.KK3(IWEIT1,1).AND.KK3(J,2).EQ.KK3(IWEIT1,2))
     1 IDAM=J
   12 CONTINUE
      IF(IDAM.EQ.0) THEN
      WRITE(6,1000)
 1000 FORMAT(' NO EFFECTIVE CROSS SECTIONS TO BE CALCULATED'/)
      RETURN
      END IF
      WRITE(6,5544) KK3(IDAM,1),KK3(IDAM,2),KK3(IDAM,1),KK3(IDAM,2)
 5544 FORMAT(' '/72('*')//
     1' EFFECTIVE CROSS SECTIONS RELATED TO ',2A4//
     1' THE EFFECTIVE CROSS SECTION FOR A RECTION I IS THE RATIO:'//
     1' SIGEFFI=INTEGRAL(SIGI(E)*F(E)*DE) / INTEGRAL(SIGD(E)*F(E)*DE)'//
     1' WITH SIGI(E) = CROSS SECTION OF THE REACTION I CONSIDERED'/
     1'      SIGD(E) = PSEUDO CROSS SECTION, IN THE PRESENT CASE IS'/
     1'                SIGD(E) RELATED TO ',2A4//
     1' SIGEFF IS INDEPENDENT FROM THE NORMALIZATION FACTOR'//
     1' THE RESULTS GIVEN HERE ARE CORRECT IN THE SENSE OF A'/
     1' LINEAR LEAST SQUARES ADJUSTMENT WITHOUT ADJUSTING THE '/
     1' FLUENCE. COMPARE THE RESULTS WITH THOSE OF THE FINAL OUTPUT'/
     172('-')/)
C
      SUMN=0.0D0
      DO 10 I=1,KG
  10  SUMN=SUMN+DBLE(CROSSD(IDAM,I))*F1(I)
C
      DO 11 I=1,KA
      SUMZ(I)=0.0
C
      DO 20 J=1,KG
      SUMZ(I)=SUMZ(I)+DBLE(CROSS(I,J))*F1(J)
   20 CONTINUE
   11 SIGEFF(I)=SUMZ(I)/SUMN
C
C CALCULATE COVARIANCE MATRIX
C
      DO 30 I=1,KA
      DO 30 J=1,KA
      DXH1=0.0D0
C
      DO 31 L1=1,KG
      DXHILF=DBLE(CROSS(I,L1))-SIGEFF(I)*DBLE(CROSSD(IDAM,L1))
      DO 32 L2=1,KG
      DXH1=DXH1+DXHILF*RHILF(L1,L2)*(DBLE(CROSS(J,L2))
     1-SIGEFF(J)*DBLE(CROSSD(IDAM,L2)))
   32 CONTINUE
   31 CONTINUE
      COVEFF(I,J)=DXH1/(SUMZ(I)*SUMZ(J))
   30 CONTINUE
C NOW COVEFF IS THE RELATIVE COVARIANCE MATRIX
C
      IF(ICOVC.EQ.0) GOTO 40
C     CROSS SECTION CONTRIBUTION
      REWIND 35
      DO 16 I=1,KA
      DO 16 J=1,KA
      DXHILF=0.0D0
C NO CROSS CORRELATIONS IN CROSS SECTION COVARIANCE
      IF(I.NE.J) GOTO 16
      READ(35) NANZ,IL,IH
      DO 14 K=IL,IH
      READ(35) (TB(L),L=IL,IH)
      DO 133 L=IL,IH
  133 DXHILF=DXHILF+TB(L)*F1(L)*F1(K)
   14 CONTINUE
   16 COVFFC(I,J)=DXHILF/(SUMZ(I)*SUMZ(J))
C   PRINT MATRICES
      WRITE(6,3000)
 3000 FORMAT(' '/72('-')/
     *' REL. COVARIANCE MATRIX OF SIGEFF, (CROSS SECTION PART):'/)
      CALL PMAX1(KA,COVFFC,SIGEFF,30,0)
   40 CONTINUE
      WRITE(6,3001)
 3001 FORMAT(' '/72('-')/
     *' REL. COVARIANCE MATRIX OF SIGEFF, (FLUENCE PART):'/)
      CALL PMAX1(KA,COVEFF,SIGEFF,30,0)
C ADD BOTH
      DO 50 I=1,KA
      DO 50 J=1,KA
   50 COVEFF(I,J)=COVEFF(I,J)+COVFFC(I,J)
      WRITE(6,3002)
 3002 FORMAT(' '/72('-')/
     *' REL. COVARIANCE MATRIX OF SIGEFF, (ALL PARTS):'/)
      CALL PMAX1(KA,COVEFF,SIGEFF,30,0)
C CALCULATE THE DAMAGE VALUE
      WRITE(6,229) KK3(IDAM,1),KK3(IDAM,2),KK3(IDAM,1),KK3(IDAM,2)
  229 FORMAT(//72('-')//' DAMAGE PARAMETERS AS THE RESULTS OF:'//
     1' ',2A4,'(I) =  ACT(I)/SIGEFF(I), I=NUMBER OF THE REACTION'//
     1'  I  REACTION     VALUE FOR    UNCERTAINTY      SIGEFF(I)'/
     1'     CODE         ',2A4//)
      DO 110 I=1,KA
      DO 110 J=1,KA
 110  COVEFF(I,J)=COVA(I,J)+COVEFF(I,J)
      DO 120 I=1,KA
      DXH1=SIGEFF(I)
      SIGEFF(I)=ACT1(I)/SIGEFF(I)
      DXHILF=DSQRT(DABS(COVEFF(I,I)))*100.0D0
  120 WRITE(6,230) I,IREAC(I,1),IREAC(I,2),SIGEFF(I),DXHILF,DXH1
  230 FORMAT(' ',I2,2X,2A4,3X,1P,E12.4,0P,F12.3,' %',4X,1P,E12.4)
      WRITE(6,300)
  300 FORMAT(//' COVARIANCE VALUES OF THE DAMAGE PARAMATERS:'/)
      CALL PMAX1(KA,COVEFF,SIGEFF,30,0)
      WRITE(6,240)
  240 FORMAT(' '/' WEIGHTED MEAN VALUE:'/)
      DO 250 I=1,KA
      DO 250 J=1,KA
  250 COVEFF(I,J)=COVEFF(I,J)*SIGEFF(I)*SIGEFF(J)
      CALL MATRIX(COVEFF,KA,30)
      DXHILF=0.0D0
      SUMN=0.0D0
      DO 260 I=1,KA
      DO 260 J=1,KA
      DXHILF=DXHILF+COVEFF(I,J)
  260 SUMN=SUMN+COVEFF(I,J)*SIGEFF(J)
      SUMN=SUMN/DXHILF
      DXHILF=100.0D0/(DSQRT(DABS(DXHILF))*SUMN)
      WRITE(6,285) KK3(IDAM,1),KK3(IDAM,2)
  285 FORMAT(' '/' MEAN OF ',2A4)
      WRITE(6,270) SUMN,DXHILF
  270 FORMAT(' MEAN: ',1P,E12.4,' +-',0P,F12.4,' %'//)
C
      DXHILF=0.0D0
      DO 295 I=1,KA
      DO 295 J=1,KA
      DXHILF=DXHILF+(SIGEFF(I)-SUMN)*COVEFF(I,J)*
     1(SIGEFF(J)-SUMN)
  295 CONTINUE
      DXHILF=DXHILF/KA
      WRITE(6,296) DXHILF
  296 FORMAT(' CHI**2 FOR THIS ADJUSTMENT : ',1P,E12.4,
     1' PER DEGREE OF FREEDOM'//
     1' END OF CALCULATION OF THE EFFECTIVE CROSS SECTION'/
     1' AND THE WEIGHTED DAMAGE PARAMETER'/
     1' '/72('*')//
     1' CONTINUE WITH FLUENCE ADJUSTMENT:')
      RETURN
      END
C***********************************************************************
C****************** FOLLOWING THE ROUTINE PLBILD ******
C****************** FOR SCREEN GRAFICS, WHICH MAY BE REPLACED
C****************** BY A DUMMY ROUTINE
      SUBROUTINE
     *PLBILD(X,Y,SIG,NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV)
C
      CHARACTER*20 TEXT,COM
      LOGICAL OD
      DIMENSION X(NP),Y(NP),SIG(NP)
C IZEIG=0 KEIN BILD
C IZEIG=1 BILD WIRD GEZEIGT, EINGABE ERWARTET
C IZEIG=2 BILD WIRD GEZEIGT UND BLEIBT STEHEN
C
C LAY=0 KEIN NEUER RAHMEN
C LAY=1 LIN-LIN
C    =2 LOG-LIN
C    =3 LIN-LOG
C    =4 LOG-LOG
C LAY NEGATIV: F(E)*E GEPLOTTET
C
C MODIN=1 HISTOGRAMMWERTE ALS EINGABE
C      =2 PUNKTWERTE ALS EINGABE
C
C MODPL=1 HISTOGRAMM
C      =2 LINIE
C      =3 PUNKTE
C MODIN NEGATIV: UNSICHERHEITEN GEPLOTTET
      INQUIRE(UNIT=29,OPENED=OD)
      IF(.NOT.OD) THEN
      OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='OLD',ERR=30)
   30 OPEN(29,FILE='PLOTOB',FORM='UNFORMATTED',STATUS='NEW')
      END IF
      WRITE(29) NP,LAY,MODIN,MODPL,FAKT,IZEIG,TEXT,COM,MEV
C
      WRITE(29) X,Y,SIG
      RETURN
      END
